module JCAB.Data (
    forEach, forEachM, forEachM_,
    staticLength,
    orMaybe,
) where

import Data.Array.IArray

-- ForEach-like list functions. Basically, they are like map functions, but they take
-- the list as their first parameter. This allows us to use them much more easily in monads.

forEach   ::            [a] -> (a -> b)   -> [b]
forEachM  :: Monad m => [a] -> (a -> m b) -> m [b]
forEachM_ :: Monad m => [a] -> (a -> m b) -> m ()

forEach   l f = map   f l
forEachM  l f = mapM  f l
forEachM_ l f = mapM_ f l

-- "length" function for statically-sized arrays.

staticLength :: (HasBounds a, Ix i) => a i e -> Int

staticLength = rangeSize . bounds

-- Operator function which takes two maybes and chooses one that is not "Nothing" if there's one.
-- Implement short-circuit semantics. If it takes the first one, the second one is not evaluated.

orMaybe :: Maybe a -> Maybe a -> Maybe a

Nothing  `orMaybe` a = a
(Just r) `orMaybe` _ = Just r

