module Win32.Error where

import Win32.System

import Control.Monad
import Foreign.Ptr
import Foreign.Marshal.Alloc
import Foreign.Storable
import System.IO.Unsafe


getErrorMessageText  :: HRESULT -> String




getErrorMessageText (HRESULT hr) = unsafePerformIO $ alloca $ \ppmsg -> do
    result <- c_FormatMessage 0x1300 nullPtr hr 0x400 ppmsg 16 nullPtr
    when (result == 0) $ do
        err <- c_GetLastError
        putStrLn $ show err
    pstr <- peek ppmsg
    message <- peekPSTRLen (pstr, result)
    c_LocalFree pstr
    return message




foreign import stdcall unsafe "Windows.h FormatMessageW" c_FormatMessage :: DWORD -> PVOID -> DWORD -> DWORD -> Ptr PSTR -> DWORD -> PVOID -> IO DWORD
foreign import stdcall unsafe "Windows.h LocalFree"      c_LocalFree     :: Ptr a -> IO ()
foreign import stdcall unsafe "Windows.h GetLastError"   c_GetLastError  :: IO DWORD



eRROR_SUCCESS = hRESULT_FROM_WIN32 0
eRROR_INVALID_FUNCTION = hRESULT_FROM_WIN32 1
eRROR_FILE_NOT_FOUND = hRESULT_FROM_WIN32 2
eRROR_PATH_NOT_FOUND = hRESULT_FROM_WIN32 3
eRROR_TOO_MANY_OPEN_FILES = hRESULT_FROM_WIN32 4
eRROR_ACCESS_DENIED = hRESULT_FROM_WIN32 5
eRROR_INVALID_HANDLE = hRESULT_FROM_WIN32 6
eRROR_ARENA_TRASHED = hRESULT_FROM_WIN32 7
eRROR_NOT_ENOUGH_MEMORY = hRESULT_FROM_WIN32 8
eRROR_INVALID_BLOCK = hRESULT_FROM_WIN32 9
eRROR_BAD_ENVIRONMENT = hRESULT_FROM_WIN32 10
eRROR_BAD_FORMAT = hRESULT_FROM_WIN32 11
eRROR_INVALID_ACCESS = hRESULT_FROM_WIN32 12
eRROR_INVALID_DATA = hRESULT_FROM_WIN32 13
eRROR_OUTOFMEMORY = hRESULT_FROM_WIN32 14
eRROR_INVALID_DRIVE = hRESULT_FROM_WIN32 15
eRROR_CURRENT_DIRECTORY = hRESULT_FROM_WIN32 16
eRROR_NOT_SAME_DEVICE = hRESULT_FROM_WIN32 17
eRROR_NO_MORE_FILES = hRESULT_FROM_WIN32 18
eRROR_WRITE_PROTECT = hRESULT_FROM_WIN32 19
eRROR_BAD_UNIT = hRESULT_FROM_WIN32 20
eRROR_NOT_READY = hRESULT_FROM_WIN32 21
eRROR_BAD_COMMAND = hRESULT_FROM_WIN32 22
eRROR_CRC = hRESULT_FROM_WIN32 23
eRROR_BAD_LENGTH = hRESULT_FROM_WIN32 24
eRROR_SEEK = hRESULT_FROM_WIN32 25
eRROR_NOT_DOS_DISK = hRESULT_FROM_WIN32 26
eRROR_SECTOR_NOT_FOUND = hRESULT_FROM_WIN32 27
eRROR_OUT_OF_PAPER = hRESULT_FROM_WIN32 28
eRROR_WRITE_FAULT = hRESULT_FROM_WIN32 29
eRROR_READ_FAULT = hRESULT_FROM_WIN32 30
eRROR_GEN_FAILURE = hRESULT_FROM_WIN32 31
eRROR_SHARING_VIOLATION = hRESULT_FROM_WIN32 32
eRROR_LOCK_VIOLATION = hRESULT_FROM_WIN32 33
eRROR_WRONG_DISK = hRESULT_FROM_WIN32 34
eRROR_SHARING_BUFFER_EXCEEDED = hRESULT_FROM_WIN32 36
eRROR_HANDLE_EOF = hRESULT_FROM_WIN32 38
eRROR_HANDLE_DISK_FULL = hRESULT_FROM_WIN32 39
eRROR_NOT_SUPPORTED = hRESULT_FROM_WIN32 50
eRROR_REM_NOT_LIST = hRESULT_FROM_WIN32 51
eRROR_DUP_NAME = hRESULT_FROM_WIN32 52
eRROR_BAD_NETPATH = hRESULT_FROM_WIN32 53
eRROR_NETWORK_BUSY = hRESULT_FROM_WIN32 54
eRROR_DEV_NOT_EXIST = hRESULT_FROM_WIN32 55
eRROR_TOO_MANY_CMDS = hRESULT_FROM_WIN32 56
eRROR_ADAP_HDW_ERR = hRESULT_FROM_WIN32 57
eRROR_BAD_NET_RESP = hRESULT_FROM_WIN32 58
eRROR_UNEXP_NET_ERR = hRESULT_FROM_WIN32 59
eRROR_BAD_REM_ADAP = hRESULT_FROM_WIN32 60
eRROR_PRINTQ_FULL = hRESULT_FROM_WIN32 61
eRROR_NO_SPOOL_SPACE = hRESULT_FROM_WIN32 62
eRROR_PRINT_CANCELLED = hRESULT_FROM_WIN32 63
eRROR_NETNAME_DELETED = hRESULT_FROM_WIN32 64
eRROR_NETWORK_ACCESS_DENIED = hRESULT_FROM_WIN32 65
eRROR_BAD_DEV_TYPE = hRESULT_FROM_WIN32 66
eRROR_BAD_NET_NAME = hRESULT_FROM_WIN32 67
eRROR_TOO_MANY_NAMES = hRESULT_FROM_WIN32 68
eRROR_TOO_MANY_SESS = hRESULT_FROM_WIN32 69
eRROR_SHARING_PAUSED = hRESULT_FROM_WIN32 70
eRROR_REQ_NOT_ACCEP = hRESULT_FROM_WIN32 71
eRROR_REDIR_PAUSED = hRESULT_FROM_WIN32 72
eRROR_FILE_EXISTS = hRESULT_FROM_WIN32 80
eRROR_CANNOT_MAKE = hRESULT_FROM_WIN32 82
eRROR_FAIL_I24 = hRESULT_FROM_WIN32 83
eRROR_OUT_OF_STRUCTURES = hRESULT_FROM_WIN32 84
eRROR_ALREADY_ASSIGNED = hRESULT_FROM_WIN32 85
eRROR_INVALID_PASSWORD = hRESULT_FROM_WIN32 86
eRROR_INVALID_PARAMETER = hRESULT_FROM_WIN32 87
eRROR_NET_WRITE_FAULT = hRESULT_FROM_WIN32 88
eRROR_NO_PROC_SLOTS = hRESULT_FROM_WIN32 89
eRROR_TOO_MANY_SEMAPHORES = hRESULT_FROM_WIN32 100
eRROR_EXCL_SEM_ALREADY_OWNED = hRESULT_FROM_WIN32 101
eRROR_SEM_IS_SET = hRESULT_FROM_WIN32 102
eRROR_TOO_MANY_SEM_REQUESTS = hRESULT_FROM_WIN32 103
eRROR_INVALID_AT_INTERRUPT_TIME = hRESULT_FROM_WIN32 104
eRROR_SEM_OWNER_DIED = hRESULT_FROM_WIN32 105
eRROR_SEM_USER_LIMIT = hRESULT_FROM_WIN32 106
eRROR_DISK_CHANGE = hRESULT_FROM_WIN32 107
eRROR_DRIVE_LOCKED = hRESULT_FROM_WIN32 108
eRROR_BROKEN_PIPE = hRESULT_FROM_WIN32 109
eRROR_OPEN_FAILED = hRESULT_FROM_WIN32 110
eRROR_BUFFER_OVERFLOW = hRESULT_FROM_WIN32 111
eRROR_DISK_FULL = hRESULT_FROM_WIN32 112
eRROR_NO_MORE_SEARCH_HANDLES = hRESULT_FROM_WIN32 113
eRROR_INVALID_TARGET_HANDLE = hRESULT_FROM_WIN32 114
eRROR_INVALID_CATEGORY = hRESULT_FROM_WIN32 117
eRROR_INVALID_VERIFY_SWITCH = hRESULT_FROM_WIN32 118
eRROR_BAD_DRIVER_LEVEL = hRESULT_FROM_WIN32 119
eRROR_CALL_NOT_IMPLEMENTED = hRESULT_FROM_WIN32 120
eRROR_SEM_TIMEOUT = hRESULT_FROM_WIN32 121
eRROR_INSUFFICIENT_BUFFER = hRESULT_FROM_WIN32 122
eRROR_INVALID_NAME = hRESULT_FROM_WIN32 123
eRROR_INVALID_LEVEL = hRESULT_FROM_WIN32 124
eRROR_NO_VOLUME_LABEL = hRESULT_FROM_WIN32 125
eRROR_MOD_NOT_FOUND = hRESULT_FROM_WIN32 126
eRROR_PROC_NOT_FOUND = hRESULT_FROM_WIN32 127
eRROR_WAIT_NO_CHILDREN = hRESULT_FROM_WIN32 128
eRROR_CHILD_NOT_COMPLETE = hRESULT_FROM_WIN32 129
eRROR_DIRECT_ACCESS_HANDLE = hRESULT_FROM_WIN32 130
eRROR_NEGATIVE_SEEK = hRESULT_FROM_WIN32 131
eRROR_SEEK_ON_DEVICE = hRESULT_FROM_WIN32 132
eRROR_IS_JOIN_TARGET = hRESULT_FROM_WIN32 133
eRROR_IS_JOINED = hRESULT_FROM_WIN32 134
eRROR_IS_SUBSTED = hRESULT_FROM_WIN32 135
eRROR_NOT_JOINED = hRESULT_FROM_WIN32 136
eRROR_NOT_SUBSTED = hRESULT_FROM_WIN32 137
eRROR_JOIN_TO_JOIN = hRESULT_FROM_WIN32 138
eRROR_SUBST_TO_SUBST = hRESULT_FROM_WIN32 139
eRROR_JOIN_TO_SUBST = hRESULT_FROM_WIN32 140
eRROR_SUBST_TO_JOIN = hRESULT_FROM_WIN32 141
eRROR_BUSY_DRIVE = hRESULT_FROM_WIN32 142
eRROR_SAME_DRIVE = hRESULT_FROM_WIN32 143
eRROR_DIR_NOT_ROOT = hRESULT_FROM_WIN32 144
eRROR_DIR_NOT_EMPTY = hRESULT_FROM_WIN32 145
eRROR_IS_SUBST_PATH = hRESULT_FROM_WIN32 146
eRROR_IS_JOIN_PATH = hRESULT_FROM_WIN32 147
eRROR_PATH_BUSY = hRESULT_FROM_WIN32 148
eRROR_IS_SUBST_TARGET = hRESULT_FROM_WIN32 149
eRROR_SYSTEM_TRACE = hRESULT_FROM_WIN32 150
eRROR_INVALID_EVENT_COUNT = hRESULT_FROM_WIN32 151
eRROR_TOO_MANY_MUXWAITERS = hRESULT_FROM_WIN32 152
eRROR_INVALID_LIST_FORMAT = hRESULT_FROM_WIN32 153
eRROR_LABEL_TOO_LONG = hRESULT_FROM_WIN32 154
eRROR_TOO_MANY_TCBS = hRESULT_FROM_WIN32 155
eRROR_SIGNAL_REFUSED = hRESULT_FROM_WIN32 156
eRROR_DISCARDED = hRESULT_FROM_WIN32 157
eRROR_NOT_LOCKED = hRESULT_FROM_WIN32 158
eRROR_BAD_THREADID_ADDR = hRESULT_FROM_WIN32 159
eRROR_BAD_ARGUMENTS = hRESULT_FROM_WIN32 160
eRROR_BAD_PATHNAME = hRESULT_FROM_WIN32 161
eRROR_SIGNAL_PENDING = hRESULT_FROM_WIN32 162
eRROR_MAX_THRDS_REACHED = hRESULT_FROM_WIN32 164
eRROR_LOCK_FAILED = hRESULT_FROM_WIN32 167
eRROR_BUSY = hRESULT_FROM_WIN32 170
eRROR_CANCEL_VIOLATION = hRESULT_FROM_WIN32 173
eRROR_ATOMIC_LOCKS_NOT_SUPPORTED = hRESULT_FROM_WIN32 174
eRROR_INVALID_SEGMENT_NUMBER = hRESULT_FROM_WIN32 180
eRROR_INVALID_ORDINAL = hRESULT_FROM_WIN32 182
eRROR_ALREADY_EXISTS = hRESULT_FROM_WIN32 183
eRROR_INVALID_FLAG_NUMBER = hRESULT_FROM_WIN32 186
eRROR_SEM_NOT_FOUND = hRESULT_FROM_WIN32 187
eRROR_INVALID_STARTING_CODESEG = hRESULT_FROM_WIN32 188
eRROR_INVALID_STACKSEG = hRESULT_FROM_WIN32 189
eRROR_INVALID_MODULETYPE = hRESULT_FROM_WIN32 190
eRROR_INVALID_EXE_SIGNATURE = hRESULT_FROM_WIN32 191
eRROR_EXE_MARKED_INVALID = hRESULT_FROM_WIN32 192
eRROR_BAD_EXE_FORMAT = hRESULT_FROM_WIN32 193
eRROR_ITERATED_DATA_EXCEEDS_64k = hRESULT_FROM_WIN32 194
eRROR_INVALID_MINALLOCSIZE = hRESULT_FROM_WIN32 195
eRROR_DYNLINK_FROM_INVALID_RING = hRESULT_FROM_WIN32 196
eRROR_IOPL_NOT_ENABLED = hRESULT_FROM_WIN32 197
eRROR_INVALID_SEGDPL = hRESULT_FROM_WIN32 198
eRROR_AUTODATASEG_EXCEEDS_64k = hRESULT_FROM_WIN32 199
eRROR_RING2SEG_MUST_BE_MOVABLE = hRESULT_FROM_WIN32 200
eRROR_RELOC_CHAIN_XEEDS_SEGLIM = hRESULT_FROM_WIN32 201
eRROR_INFLOOP_IN_RELOC_CHAIN = hRESULT_FROM_WIN32 202
eRROR_ENVVAR_NOT_FOUND = hRESULT_FROM_WIN32 203
eRROR_NO_SIGNAL_SENT = hRESULT_FROM_WIN32 205
eRROR_FILENAME_EXCED_RANGE = hRESULT_FROM_WIN32 206
eRROR_RING2_STACK_IN_USE = hRESULT_FROM_WIN32 207
eRROR_META_EXPANSION_TOO_LONG = hRESULT_FROM_WIN32 208
eRROR_INVALID_SIGNAL_NUMBER = hRESULT_FROM_WIN32 209
eRROR_THREAD_1_INACTIVE = hRESULT_FROM_WIN32 210
eRROR_LOCKED = hRESULT_FROM_WIN32 212
eRROR_TOO_MANY_MODULES = hRESULT_FROM_WIN32 214
eRROR_NESTING_NOT_ALLOWED = hRESULT_FROM_WIN32 215
eRROR_EXE_MACHINE_TYPE_MISMATCH = hRESULT_FROM_WIN32 216
eRROR_EXE_CANNOT_MODIFY_SIGNED_BINARY = hRESULT_FROM_WIN32 217
eRRO_EXE_CANNOT_MODIFY_STRONG_SIGNED_BINARY = hRESULT_FROM_WIN32 218
eRROR_BAD_PIPE = hRESULT_FROM_WIN32 230
eRROR_PIPE_BUSY = hRESULT_FROM_WIN32 231
eRROR_NO_DATA = hRESULT_FROM_WIN32 232
eRROR_PIPE_NOT_CONNECTED = hRESULT_FROM_WIN32 233
eRROR_MORE_DATA = hRESULT_FROM_WIN32 234
eRROR_VC_DISCONNECTED = hRESULT_FROM_WIN32 240
eRROR_INVALID_EA_NAME = hRESULT_FROM_WIN32 254
eRROR_EA_LIST_INCONSISTENT = hRESULT_FROM_WIN32 255
wAIT_TIMEOUT = hRESULT_FROM_WIN32 258
eRROR_NO_MORE_ITEMS = hRESULT_FROM_WIN32 259
eRROR_CANNOT_COPY = hRESULT_FROM_WIN32 266
eRROR_DIRECTORY = hRESULT_FROM_WIN32 267
eRROR_EAS_DIDNT_FIT = hRESULT_FROM_WIN32 275
eRROR_EA_FILE_CORRUPT = hRESULT_FROM_WIN32 276
eRROR_EA_TABLE_FULL = hRESULT_FROM_WIN32 277
eRROR_INVALID_EA_HANDLE = hRESULT_FROM_WIN32 278
eRROR_EAS_NOT_SUPPORTED = hRESULT_FROM_WIN32 282
eRROR_NOT_OWNER = hRESULT_FROM_WIN32 288
eRROR_TOO_MANY_POSTS = hRESULT_FROM_WIN32 298
eRROR_PARTIAL_COPY = hRESULT_FROM_WIN32 299
eRROR_OPLOCK_NOT_GRANTED = hRESULT_FROM_WIN32 300
eRROR_INVALID_OPLOCK_PROTOCOL = hRESULT_FROM_WIN32 301
eRROR_DISK_TOO_FRAGMENTED = hRESULT_FROM_WIN32 302
eRROR_DELETE_PENDING = hRESULT_FROM_WIN32 303
eRROR_MR_MID_NOT_FOUND = hRESULT_FROM_WIN32 317
eRROR_SCOPE_NOT_FOUND = hRESULT_FROM_WIN32 318
eRROR_INVALID_ADDRESS = hRESULT_FROM_WIN32 487
eRROR_ARITHMETIC_OVERFLOW = hRESULT_FROM_WIN32 534
eRROR_PIPE_CONNECTED = hRESULT_FROM_WIN32 535
eRROR_PIPE_LISTENING = hRESULT_FROM_WIN32 536
eRROR_EA_ACCESS_DENIED = hRESULT_FROM_WIN32 994
eRROR_OPERATION_ABORTED = hRESULT_FROM_WIN32 995
eRROR_IO_INCOMPLETE = hRESULT_FROM_WIN32 996
eRROR_IO_PENDING = hRESULT_FROM_WIN32 997
eRROR_NOACCESS = hRESULT_FROM_WIN32 998
eRROR_SWAPERROR = hRESULT_FROM_WIN32 999
eRROR_STACK_OVERFLOW = hRESULT_FROM_WIN32 1001
eRROR_INVALID_MESSAGE = hRESULT_FROM_WIN32 1002
eRROR_CAN_NOT_COMPLETE = hRESULT_FROM_WIN32 1003
eRROR_INVALID_FLAGS = hRESULT_FROM_WIN32 1004
eRROR_UNRECOGNIZED_VOLUME = hRESULT_FROM_WIN32 1005
eRROR_FILE_INVALID = hRESULT_FROM_WIN32 1006
eRROR_FULLSCREEN_MODE = hRESULT_FROM_WIN32 1007
eRROR_NO_TOKEN = hRESULT_FROM_WIN32 1008
eRROR_BADDB = hRESULT_FROM_WIN32 1009
eRROR_BADKEY = hRESULT_FROM_WIN32 1010
eRROR_CANTOPEN = hRESULT_FROM_WIN32 1011
eRROR_CANTREAD = hRESULT_FROM_WIN32 1012
eRROR_CANTWRITE = hRESULT_FROM_WIN32 1013
eRROR_REGISTRY_RECOVERED = hRESULT_FROM_WIN32 1014
eRROR_REGISTRY_CORRUPT = hRESULT_FROM_WIN32 1015
eRROR_REGISTRY_IO_FAILED = hRESULT_FROM_WIN32 1016
eRROR_NOT_REGISTRY_FILE = hRESULT_FROM_WIN32 1017
eRROR_KEY_DELETED = hRESULT_FROM_WIN32 1018
eRROR_NO_LOG_SPACE = hRESULT_FROM_WIN32 1019
eRROR_KEY_HAS_CHILDREN = hRESULT_FROM_WIN32 1020
eRROR_CHILD_MUST_BE_VOLATILE = hRESULT_FROM_WIN32 1021
eRROR_NOTIFY_ENUM_DIR = hRESULT_FROM_WIN32 1022
eRROR_DEPENDENT_SERVICES_RUNNING = hRESULT_FROM_WIN32 1051
eRROR_INVALID_SERVICE_CONTROL = hRESULT_FROM_WIN32 1052
eRROR_SERVICE_REQUEST_TIMEOUT = hRESULT_FROM_WIN32 1053
eRROR_SERVICE_NO_THREAD = hRESULT_FROM_WIN32 1054
eRROR_SERVICE_DATABASE_LOCKED = hRESULT_FROM_WIN32 1055
eRROR_SERVICE_ALREADY_RUNNING = hRESULT_FROM_WIN32 1056
eRROR_INVALID_SERVICE_ACCOUNT = hRESULT_FROM_WIN32 1057
eRROR_SERVICE_DISABLED = hRESULT_FROM_WIN32 1058
eRROR_CIRCULAR_DEPENDENCY = hRESULT_FROM_WIN32 1059
eRROR_SERVICE_DOES_NOT_EXIST = hRESULT_FROM_WIN32 1060
eRROR_SERVICE_CANNOT_ACCEPT_CTRL = hRESULT_FROM_WIN32 1061
eRROR_SERVICE_NOT_ACTIVE = hRESULT_FROM_WIN32 1062
eRROR_FAILED_SERVICE_CONTROLLER_CONNECT = hRESULT_FROM_WIN32 1063
eRROR_EXCEPTION_IN_SERVICE = hRESULT_FROM_WIN32 1064
eRROR_DATABASE_DOES_NOT_EXIST = hRESULT_FROM_WIN32 1065
eRROR_SERVICE_SPECIFIC_ERROR = hRESULT_FROM_WIN32 1066
eRROR_PROCESS_ABORTED = hRESULT_FROM_WIN32 1067
eRROR_SERVICE_DEPENDENCY_FAIL = hRESULT_FROM_WIN32 1068
eRROR_SERVICE_LOGON_FAILED = hRESULT_FROM_WIN32 1069
eRROR_SERVICE_START_HANG = hRESULT_FROM_WIN32 1070
eRROR_INVALID_SERVICE_LOCK = hRESULT_FROM_WIN32 1071
eRROR_SERVICE_MARKED_FOR_DELETE = hRESULT_FROM_WIN32 1072
eRROR_SERVICE_EXISTS = hRESULT_FROM_WIN32 1073
eRROR_ALREADY_RUNNING_LKG = hRESULT_FROM_WIN32 1074
eRROR_SERVICE_DEPENDENCY_DELETED = hRESULT_FROM_WIN32 1075
eRROR_BOOT_ALREADY_ACCEPTED = hRESULT_FROM_WIN32 1076
eRROR_SERVICE_NEVER_STARTED = hRESULT_FROM_WIN32 1077
eRROR_DUPLICATE_SERVICE_NAME = hRESULT_FROM_WIN32 1078
eRROR_DIFFERENT_SERVICE_ACCOUNT = hRESULT_FROM_WIN32 1079
eRROR_CANNOT_DETECT_DRIVER_FAILURE = hRESULT_FROM_WIN32 1080
eRROR_CANNOT_DETECT_PROCESS_ABORT = hRESULT_FROM_WIN32 1081
eRROR_NO_RECOVERY_PROGRAM = hRESULT_FROM_WIN32 1082
eRROR_SERVICE_NOT_IN_EXE = hRESULT_FROM_WIN32 1083
eRROR_NOT_SAFEBOOT_SERVICE = hRESULT_FROM_WIN32 1084
eRROR_END_OF_MEDIA = hRESULT_FROM_WIN32 1100
eRROR_FILEMARK_DETECTED = hRESULT_FROM_WIN32 1101
eRROR_BEGINNING_OF_MEDIA = hRESULT_FROM_WIN32 1102
eRROR_SETMARK_DETECTED = hRESULT_FROM_WIN32 1103
eRROR_NO_DATA_DETECTED = hRESULT_FROM_WIN32 1104
eRROR_PARTITION_FAILURE = hRESULT_FROM_WIN32 1105
eRROR_INVALID_BLOCK_LENGTH = hRESULT_FROM_WIN32 1106
eRROR_DEVICE_NOT_PARTITIONED = hRESULT_FROM_WIN32 1107
eRROR_UNABLE_TO_LOCK_MEDIA = hRESULT_FROM_WIN32 1108
eRROR_UNABLE_TO_UNLOAD_MEDIA = hRESULT_FROM_WIN32 1109
eRROR_MEDIA_CHANGED = hRESULT_FROM_WIN32 1110
eRROR_BUS_RESET = hRESULT_FROM_WIN32 1111
eRROR_NO_MEDIA_IN_DRIVE = hRESULT_FROM_WIN32 1112
eRROR_NO_UNICODE_TRANSLATION = hRESULT_FROM_WIN32 1113
eRROR_DLL_INIT_FAILED = hRESULT_FROM_WIN32 1114
eRROR_SHUTDOWN_IN_PROGRESS = hRESULT_FROM_WIN32 1115
eRROR_NO_SHUTDOWN_IN_PROGRESS = hRESULT_FROM_WIN32 1116
eRROR_IO_DEVICE = hRESULT_FROM_WIN32 1117
eRROR_SERIAL_NO_DEVICE = hRESULT_FROM_WIN32 1118
eRROR_IRQ_BUSY = hRESULT_FROM_WIN32 1119
eRROR_MORE_WRITES = hRESULT_FROM_WIN32 1120
eRROR_COUNTER_TIMEOUT = hRESULT_FROM_WIN32 1121
eRROR_FLOPPY_ID_MARK_NOT_FOUND = hRESULT_FROM_WIN32 1122
eRROR_FLOPPY_WRONG_CYLINDER = hRESULT_FROM_WIN32 1123
eRROR_FLOPPY_UNKNOWN_ERROR = hRESULT_FROM_WIN32 1124
eRROR_FLOPPY_BAD_REGISTERS = hRESULT_FROM_WIN32 1125
eRROR_DISK_RECALIBRATE_FAILED = hRESULT_FROM_WIN32 1126
eRROR_DISK_OPERATION_FAILED = hRESULT_FROM_WIN32 1127
eRROR_DISK_RESET_FAILED = hRESULT_FROM_WIN32 1128
eRROR_EOM_OVERFLOW = hRESULT_FROM_WIN32 1129
eRROR_NOT_ENOUGH_SERVER_MEMORY = hRESULT_FROM_WIN32 1130
eRROR_POSSIBLE_DEADLOCK = hRESULT_FROM_WIN32 1131
eRROR_MAPPED_ALIGNMENT = hRESULT_FROM_WIN32 1132
eRROR_SET_POWER_STATE_VETOED = hRESULT_FROM_WIN32 1140
eRROR_SET_POWER_STATE_FAILED = hRESULT_FROM_WIN32 1141
eRROR_TOO_MANY_LINKS = hRESULT_FROM_WIN32 1142
eRROR_OLD_WIN_VERSION = hRESULT_FROM_WIN32 1150
eRROR_APP_WRONG_OS = hRESULT_FROM_WIN32 1151
eRROR_SINGLE_INSTANCE_APP = hRESULT_FROM_WIN32 1152
eRROR_RMODE_APP = hRESULT_FROM_WIN32 1153
eRROR_INVALID_DLL = hRESULT_FROM_WIN32 1154
eRROR_NO_ASSOCIATION = hRESULT_FROM_WIN32 1155
eRROR_DDE_FAIL = hRESULT_FROM_WIN32 1156
eRROR_DLL_NOT_FOUND = hRESULT_FROM_WIN32 1157
eRROR_NO_MORE_USER_HANDLES = hRESULT_FROM_WIN32 1158
eRROR_MESSAGE_SYNC_ONLY = hRESULT_FROM_WIN32 1159
eRROR_SOURCE_ELEMENT_EMPTY = hRESULT_FROM_WIN32 1160
eRROR_DESTINATION_ELEMENT_FULL = hRESULT_FROM_WIN32 1161
eRROR_ILLEGAL_ELEMENT_ADDRESS = hRESULT_FROM_WIN32 1162
eRROR_MAGAZINE_NOT_PRESENT = hRESULT_FROM_WIN32 1163
eRROR_DEVICE_REINITIALIZATION_NEEDED = hRESULT_FROM_WIN32 1164
eRROR_DEVICE_REQUIRES_CLEANING = hRESULT_FROM_WIN32 1165
eRROR_DEVICE_DOOR_OPEN = hRESULT_FROM_WIN32 1166
eRROR_DEVICE_NOT_CONNECTED = hRESULT_FROM_WIN32 1167
eRROR_NOT_FOUND = hRESULT_FROM_WIN32 1168
eRROR_NO_MATCH = hRESULT_FROM_WIN32 1169
eRROR_SET_NOT_FOUND = hRESULT_FROM_WIN32 1170
eRROR_POINT_NOT_FOUND = hRESULT_FROM_WIN32 1171
eRROR_NO_TRACKING_SERVICE = hRESULT_FROM_WIN32 1172
eRROR_NO_VOLUME_ID = hRESULT_FROM_WIN32 1173
eRROR_UNABLE_TO_REMOVE_REPLACED = hRESULT_FROM_WIN32 1175
eRROR_UNABLE_TO_MOVE_REPLACEMENT = hRESULT_FROM_WIN32 1176
eRROR_UNABLE_TO_MOVE_REPLACEMENT_2 = hRESULT_FROM_WIN32 1177
eRROR_JOURNAL_DELETE_IN_PROGRESS = hRESULT_FROM_WIN32 1178
eRROR_JOURNAL_NOT_ACTIVE = hRESULT_FROM_WIN32 1179
eRROR_POTENTIAL_FILE_FOUND = hRESULT_FROM_WIN32 1180
eRROR_JOURNAL_ENTRY_DELETED = hRESULT_FROM_WIN32 1181
eRROR_BAD_DEVICE = hRESULT_FROM_WIN32 1200
eRROR_CONNECTION_UNAVAIL = hRESULT_FROM_WIN32 1201
eRROR_DEVICE_ALREADY_REMEMBERED = hRESULT_FROM_WIN32 1202
eRROR_NO_NET_OR_BAD_PATH = hRESULT_FROM_WIN32 1203
eRROR_BAD_PROVIDER = hRESULT_FROM_WIN32 1204
eRROR_CANNOT_OPEN_PROFILE = hRESULT_FROM_WIN32 1205
eRROR_BAD_PROFILE = hRESULT_FROM_WIN32 1206
eRROR_NOT_CONTAINER = hRESULT_FROM_WIN32 1207
eRROR_EXTENDED_ERROR = hRESULT_FROM_WIN32 1208
eRROR_INVALID_GROUPNAME = hRESULT_FROM_WIN32 1209
eRROR_INVALID_COMPUTERNAME = hRESULT_FROM_WIN32 1210
eRROR_INVALID_EVENTNAME = hRESULT_FROM_WIN32 1211
eRROR_INVALID_DOMAINNAME = hRESULT_FROM_WIN32 1212
eRROR_INVALID_SERVICENAME = hRESULT_FROM_WIN32 1213
eRROR_INVALID_NETNAME = hRESULT_FROM_WIN32 1214
eRROR_INVALID_SHARENAME = hRESULT_FROM_WIN32 1215
eRROR_INVALID_PASSWORDNAME = hRESULT_FROM_WIN32 1216
eRROR_INVALID_MESSAGENAME = hRESULT_FROM_WIN32 1217
eRROR_INVALID_MESSAGEDEST = hRESULT_FROM_WIN32 1218
eRROR_SESSION_CREDENTIAL_CONFLICT = hRESULT_FROM_WIN32 1219
eRROR_REMOTE_SESSION_LIMIT_EXCEEDED = hRESULT_FROM_WIN32 1220
eRROR_DUP_DOMAINNAME = hRESULT_FROM_WIN32 1221
eRROR_NO_NETWORK = hRESULT_FROM_WIN32 1222
eRROR_CANCELLED = hRESULT_FROM_WIN32 1223
eRROR_USER_MAPPED_FILE = hRESULT_FROM_WIN32 1224
eRROR_CONNECTION_REFUSED = hRESULT_FROM_WIN32 1225
eRROR_GRACEFUL_DISCONNECT = hRESULT_FROM_WIN32 1226
eRROR_ADDRESS_ALREADY_ASSOCIATED = hRESULT_FROM_WIN32 1227
eRROR_ADDRESS_NOT_ASSOCIATED = hRESULT_FROM_WIN32 1228
eRROR_CONNECTION_INVALID = hRESULT_FROM_WIN32 1229
eRROR_CONNECTION_ACTIVE = hRESULT_FROM_WIN32 1230
eRROR_NETWORK_UNREACHABLE = hRESULT_FROM_WIN32 1231
eRROR_HOST_UNREACHABLE = hRESULT_FROM_WIN32 1232
eRROR_PROTOCOL_UNREACHABLE = hRESULT_FROM_WIN32 1233
eRROR_PORT_UNREACHABLE = hRESULT_FROM_WIN32 1234
eRROR_REQUEST_ABORTED = hRESULT_FROM_WIN32 1235
eRROR_CONNECTION_ABORTED = hRESULT_FROM_WIN32 1236
eRROR_RETRY = hRESULT_FROM_WIN32 1237
eRROR_CONNECTION_COUNT_LIMIT = hRESULT_FROM_WIN32 1238
eRROR_LOGIN_TIME_RESTRICTION = hRESULT_FROM_WIN32 1239
eRROR_LOGIN_WKSTA_RESTRICTION = hRESULT_FROM_WIN32 1240
eRROR_INCORRECT_ADDRESS = hRESULT_FROM_WIN32 1241
eRROR_ALREADY_REGISTERED = hRESULT_FROM_WIN32 1242
eRROR_SERVICE_NOT_FOUND = hRESULT_FROM_WIN32 1243
eRROR_NOT_AUTHENTICATED = hRESULT_FROM_WIN32 1244
eRROR_NOT_LOGGED_ON = hRESULT_FROM_WIN32 1245
eRROR_CONTINUE = hRESULT_FROM_WIN32 1246
eRROR_ALREADY_INITIALIZED = hRESULT_FROM_WIN32 1247
eRROR_NO_MORE_DEVICES = hRESULT_FROM_WIN32 1248
eRROR_NO_SUCH_SITE = hRESULT_FROM_WIN32 1249
eRROR_DOMAIN_CONTROLLER_EXISTS = hRESULT_FROM_WIN32 1250
eRROR_ONLY_IF_CONNECTED = hRESULT_FROM_WIN32 1251
eRROR_OVERRIDE_NOCHANGES = hRESULT_FROM_WIN32 1252
eRROR_BAD_USER_PROFILE = hRESULT_FROM_WIN32 1253
eRROR_NOT_SUPPORTED_ON_SBS = hRESULT_FROM_WIN32 1254
eRROR_SERVER_SHUTDOWN_IN_PROGRESS = hRESULT_FROM_WIN32 1255
eRROR_HOST_DOWN = hRESULT_FROM_WIN32 1256
eRROR_NON_ACCOUNT_SID = hRESULT_FROM_WIN32 1257
eRROR_NON_DOMAIN_SID = hRESULT_FROM_WIN32 1258
eRROR_APPHELP_BLOCK = hRESULT_FROM_WIN32 1259
eRROR_ACCESS_DISABLED_BY_POLICY = hRESULT_FROM_WIN32 1260
eRROR_REG_NAT_CONSUMPTION = hRESULT_FROM_WIN32 1261
eRROR_CSCSHARE_OFFLINE = hRESULT_FROM_WIN32 1262
eRROR_PKINIT_FAILURE = hRESULT_FROM_WIN32 1263
eRROR_SMARTCARD_SUBSYSTEM_FAILURE = hRESULT_FROM_WIN32 1264
eRROR_DOWNGRADE_DETECTED = hRESULT_FROM_WIN32 1265
sEC_E_SMARTCARD_CERT_REVOKED = hRESULT_FROM_WIN32 1266
sEC_E_ISSUING_CA_UNTRUSTED = hRESULT_FROM_WIN32 1267
sEC_E_REVOCATION_OFFLINE_C = hRESULT_FROM_WIN32 1268
sEC_E_PKINIT_CLIENT_FAILUR = hRESULT_FROM_WIN32 1269
sEC_E_SMARTCARD_CERT_EXPIRED = hRESULT_FROM_WIN32 1270
eRROR_MACHINE_LOCKED = hRESULT_FROM_WIN32 1271
eRROR_CALLBACK_SUPPLIED_INVALID_DATA = hRESULT_FROM_WIN32 1273
eRROR_SYNC_FOREGROUND_REFRESH_REQUIRED = hRESULT_FROM_WIN32 1274
eRROR_DRIVER_BLOCKED = hRESULT_FROM_WIN32 1275
eRROR_INVALID_IMPORT_OF_NON_DLL = hRESULT_FROM_WIN32 1276
eRROR_ACCESS_DISABLED_WEBBLADE = hRESULT_FROM_WIN32 1277
eRROR_ACCESS_DISABLED_WEBBLADE_TAMPER = hRESULT_FROM_WIN32 1278
eRROR_RECOVERY_FAILURE = hRESULT_FROM_WIN32 1279
eRROR_ALREADY_FIBER = hRESULT_FROM_WIN32 1280
eRROR_ALREADY_THREAD = hRESULT_FROM_WIN32 1281
eRROR_STACK_BUFFER_OVERRUN = hRESULT_FROM_WIN32 1282
eRROR_PARAMETER_QUOTA_EXCEEDED = hRESULT_FROM_WIN32 1283
eRROR_DEBUGGER_INACTIVE = hRESULT_FROM_WIN32 1284
eRROR_NOT_ALL_ASSIGNED = hRESULT_FROM_WIN32 1300
eRROR_SOME_NOT_MAPPED = hRESULT_FROM_WIN32 1301
eRROR_NO_QUOTAS_FOR_ACCOUNT = hRESULT_FROM_WIN32 1302
eRROR_LOCAL_USER_SESSION_KEY = hRESULT_FROM_WIN32 1303
eRROR_NULL_LM_PASSWORD = hRESULT_FROM_WIN32 1304
eRROR_UNKNOWN_REVISION = hRESULT_FROM_WIN32 1305
eRROR_REVISION_MISMATCH = hRESULT_FROM_WIN32 1306
eRROR_INVALID_OWNER = hRESULT_FROM_WIN32 1307
eRROR_INVALID_PRIMARY_GROUP = hRESULT_FROM_WIN32 1308
eRROR_NO_IMPERSONATION_TOKEN = hRESULT_FROM_WIN32 1309
eRROR_CANT_DISABLE_MANDATORY = hRESULT_FROM_WIN32 1310
eRROR_NO_LOGON_SERVERS = hRESULT_FROM_WIN32 1311
eRROR_NO_SUCH_LOGON_SESSION = hRESULT_FROM_WIN32 1312
eRROR_NO_SUCH_PRIVILEGE = hRESULT_FROM_WIN32 1313
eRROR_PRIVILEGE_NOT_HELD = hRESULT_FROM_WIN32 1314
eRROR_INVALID_ACCOUNT_NAME = hRESULT_FROM_WIN32 1315
eRROR_USER_EXISTS = hRESULT_FROM_WIN32 1316
eRROR_NO_SUCH_USER = hRESULT_FROM_WIN32 1317
eRROR_GROUP_EXISTS = hRESULT_FROM_WIN32 1318
eRROR_NO_SUCH_GROUP = hRESULT_FROM_WIN32 1319
eRROR_MEMBER_IN_GROUP = hRESULT_FROM_WIN32 1320
eRROR_MEMBER_NOT_IN_GROUP = hRESULT_FROM_WIN32 1321
eRROR_LAST_ADMIN = hRESULT_FROM_WIN32 1322
eRROR_WRONG_PASSWORD = hRESULT_FROM_WIN32 1323
eRROR_ILL_FORMED_PASSWORD = hRESULT_FROM_WIN32 1324
eRROR_PASSWORD_RESTRICTION = hRESULT_FROM_WIN32 1325
eRROR_LOGON_FAILURE = hRESULT_FROM_WIN32 1326
eRROR_ACCOUNT_RESTRICTION = hRESULT_FROM_WIN32 1327
eRROR_INVALID_LOGON_HOURS = hRESULT_FROM_WIN32 1328
eRROR_INVALID_WORKSTATION = hRESULT_FROM_WIN32 1329
eRROR_PASSWORD_EXPIRED = hRESULT_FROM_WIN32 1330
eRROR_ACCOUNT_DISABLED = hRESULT_FROM_WIN32 1331
eRROR_NONE_MAPPED = hRESULT_FROM_WIN32 1332
eRROR_TOO_MANY_LUIDS_REQUESTED = hRESULT_FROM_WIN32 1333
eRROR_LUIDS_EXHAUSTED = hRESULT_FROM_WIN32 1334
eRROR_INVALID_SUB_AUTHORITY = hRESULT_FROM_WIN32 1335
eRROR_INVALID_ACL = hRESULT_FROM_WIN32 1336
eRROR_INVALID_SID = hRESULT_FROM_WIN32 1337
eRROR_INVALID_SECURITY_DESCR = hRESULT_FROM_WIN32 1338
eRROR_BAD_INHERITANCE_ACL = hRESULT_FROM_WIN32 1340
eRROR_SERVER_DISABLED = hRESULT_FROM_WIN32 1341
eRROR_SERVER_NOT_DISABLED = hRESULT_FROM_WIN32 1342
eRROR_INVALID_ID_AUTHORITY = hRESULT_FROM_WIN32 1343
eRROR_ALLOTTED_SPACE_EXCEEDED = hRESULT_FROM_WIN32 1344
eRROR_INVALID_GROUP_ATTRIBUTES = hRESULT_FROM_WIN32 1345
eRROR_BAD_IMPERSONATION_LEVEL = hRESULT_FROM_WIN32 1346
eRROR_CANT_OPEN_ANONYMOUS = hRESULT_FROM_WIN32 1347
eRROR_BAD_VALIDATION_CLASS = hRESULT_FROM_WIN32 1348
eRROR_BAD_TOKEN_TYPE = hRESULT_FROM_WIN32 1349
eRROR_NO_SECURITY_ON_OBJECT = hRESULT_FROM_WIN32 1350
eRROR_CANT_ACCESS_DOMAIN_INFO = hRESULT_FROM_WIN32 1351
eRROR_INVALID_SERVER_STATE = hRESULT_FROM_WIN32 1352
eRROR_INVALID_DOMAIN_STATE = hRESULT_FROM_WIN32 1353
eRROR_INVALID_DOMAIN_ROLE = hRESULT_FROM_WIN32 1354
eRROR_NO_SUCH_DOMAIN = hRESULT_FROM_WIN32 1355
eRROR_DOMAIN_EXISTS = hRESULT_FROM_WIN32 1356
eRROR_DOMAIN_LIMIT_EXCEEDED = hRESULT_FROM_WIN32 1357
eRROR_INTERNAL_DB_CORRUPTION = hRESULT_FROM_WIN32 1358
eRROR_INTERNAL_ERROR = hRESULT_FROM_WIN32 1359
eRROR_GENERIC_NOT_MAPPED = hRESULT_FROM_WIN32 1360
eRROR_BAD_DESCRIPTOR_FORMAT = hRESULT_FROM_WIN32 1361
eRROR_NOT_LOGON_PROCESS = hRESULT_FROM_WIN32 1362
eRROR_LOGON_SESSION_EXISTS = hRESULT_FROM_WIN32 1363
eRROR_NO_SUCH_PACKAGE = hRESULT_FROM_WIN32 1364
eRROR_BAD_LOGON_SESSION_STATE = hRESULT_FROM_WIN32 1365
eRROR_LOGON_SESSION_COLLISION = hRESULT_FROM_WIN32 1366
eRROR_INVALID_LOGON_TYPE = hRESULT_FROM_WIN32 1367
eRROR_CANNOT_IMPERSONATE = hRESULT_FROM_WIN32 1368
eRROR_RXACT_INVALID_STATE = hRESULT_FROM_WIN32 1369
eRROR_RXACT_COMMIT_FAILURE = hRESULT_FROM_WIN32 1370
eRROR_SPECIAL_ACCOUNT = hRESULT_FROM_WIN32 1371
eRROR_SPECIAL_GROUP = hRESULT_FROM_WIN32 1372
eRROR_SPECIAL_USER = hRESULT_FROM_WIN32 1373
eRROR_MEMBERS_PRIMARY_GROUP = hRESULT_FROM_WIN32 1374
eRROR_TOKEN_ALREADY_IN_USE = hRESULT_FROM_WIN32 1375
eRROR_NO_SUCH_ALIAS = hRESULT_FROM_WIN32 1376
eRROR_MEMBER_NOT_IN_ALIAS = hRESULT_FROM_WIN32 1377
eRROR_MEMBER_IN_ALIAS = hRESULT_FROM_WIN32 1378
eRROR_ALIAS_EXISTS = hRESULT_FROM_WIN32 1379
eRROR_LOGON_NOT_GRANTED = hRESULT_FROM_WIN32 1380
eRROR_TOO_MANY_SECRETS = hRESULT_FROM_WIN32 1381
eRROR_SECRET_TOO_LONG = hRESULT_FROM_WIN32 1382
eRROR_INTERNAL_DB_ERROR = hRESULT_FROM_WIN32 1383
eRROR_TOO_MANY_CONTEXT_IDS = hRESULT_FROM_WIN32 1384
eRROR_LOGON_TYPE_NOT_GRANTED = hRESULT_FROM_WIN32 1385
eRROR_NT_CROSS_ENCRYPTION_REQUIRED = hRESULT_FROM_WIN32 1386
eRROR_NO_SUCH_MEMBER = hRESULT_FROM_WIN32 1387
eRROR_INVALID_MEMBER = hRESULT_FROM_WIN32 1388
eRROR_TOO_MANY_SIDS = hRESULT_FROM_WIN32 1389
eRROR_LM_CROSS_ENCRYPTION_REQUIRED = hRESULT_FROM_WIN32 1390
eRROR_NO_INHERITANCE = hRESULT_FROM_WIN32 1391
eRROR_FILE_CORRUPT = hRESULT_FROM_WIN32 1392
eRROR_DISK_CORRUPT = hRESULT_FROM_WIN32 1393
eRROR_NO_USER_SESSION_KEY = hRESULT_FROM_WIN32 1394
eRROR_LICENSE_QUOTA_EXCEEDED = hRESULT_FROM_WIN32 1395
eRROR_WRONG_TARGET_NAME = hRESULT_FROM_WIN32 1396
eRROR_MUTUAL_AUTH_FAILED = hRESULT_FROM_WIN32 1397
eRROR_TIME_SKEW = hRESULT_FROM_WIN32 1398
eRROR_CURRENT_DOMAIN_NOT_ALLOWED = hRESULT_FROM_WIN32 1399
eRROR_INVALID_WINDOW_HANDLE = hRESULT_FROM_WIN32 1400
eRROR_INVALID_MENU_HANDLE = hRESULT_FROM_WIN32 1401
eRROR_INVALID_CURSOR_HANDLE = hRESULT_FROM_WIN32 1402
eRROR_INVALID_ACCEL_HANDLE = hRESULT_FROM_WIN32 1403
eRROR_INVALID_HOOK_HANDLE = hRESULT_FROM_WIN32 1404
eRROR_INVALID_DWP_HANDLE = hRESULT_FROM_WIN32 1405
eRROR_TLW_WITH_WSCHILD = hRESULT_FROM_WIN32 1406
eRROR_CANNOT_FIND_WND_CLASS = hRESULT_FROM_WIN32 1407
eRROR_WINDOW_OF_OTHER_THREAD = hRESULT_FROM_WIN32 1408
eRROR_HOTKEY_ALREADY_REGISTERED = hRESULT_FROM_WIN32 1409
eRROR_CLASS_ALREADY_EXISTS = hRESULT_FROM_WIN32 1410
eRROR_CLASS_DOES_NOT_EXIST = hRESULT_FROM_WIN32 1411
eRROR_CLASS_HAS_WINDOWS = hRESULT_FROM_WIN32 1412
eRROR_INVALID_INDEX = hRESULT_FROM_WIN32 1413
eRROR_INVALID_ICON_HANDLE = hRESULT_FROM_WIN32 1414
eRROR_PRIVATE_DIALOG_INDEX = hRESULT_FROM_WIN32 1415
eRROR_LISTBOX_ID_NOT_FOUND = hRESULT_FROM_WIN32 1416
eRROR_NO_WILDCARD_CHARACTERS = hRESULT_FROM_WIN32 1417
eRROR_CLIPBOARD_NOT_OPEN = hRESULT_FROM_WIN32 1418
eRROR_HOTKEY_NOT_REGISTERED = hRESULT_FROM_WIN32 1419
eRROR_WINDOW_NOT_DIALOG = hRESULT_FROM_WIN32 1420
eRROR_CONTROL_ID_NOT_FOUND = hRESULT_FROM_WIN32 1421
eRROR_INVALID_COMBOBOX_MESSAGE = hRESULT_FROM_WIN32 1422
eRROR_WINDOW_NOT_COMBOBOX = hRESULT_FROM_WIN32 1423
eRROR_INVALID_EDIT_HEIGHT = hRESULT_FROM_WIN32 1424
eRROR_DC_NOT_FOUND = hRESULT_FROM_WIN32 1425
eRROR_INVALID_HOOK_FILTER = hRESULT_FROM_WIN32 1426
eRROR_INVALID_FILTER_PROC = hRESULT_FROM_WIN32 1427
eRROR_HOOK_NEEDS_HMOD = hRESULT_FROM_WIN32 1428
eRROR_GLOBAL_ONLY_HOOK = hRESULT_FROM_WIN32 1429
eRROR_JOURNAL_HOOK_SET = hRESULT_FROM_WIN32 1430
eRROR_HOOK_NOT_INSTALLED = hRESULT_FROM_WIN32 1431
eRROR_INVALID_LB_MESSAGE = hRESULT_FROM_WIN32 1432
eRROR_SETCOUNT_ON_BAD_LB = hRESULT_FROM_WIN32 1433
eRROR_LB_WITHOUT_TABSTOPS = hRESULT_FROM_WIN32 1434
eRROR_DESTROY_OBJECT_OF_OTHER_THREAD = hRESULT_FROM_WIN32 1435
eRROR_CHILD_WINDOW_MENU = hRESULT_FROM_WIN32 1436
eRROR_NO_SYSTEM_MENU = hRESULT_FROM_WIN32 1437
eRROR_INVALID_MSGBOX_STYLE = hRESULT_FROM_WIN32 1438
eRROR_INVALID_SPI_VALUE = hRESULT_FROM_WIN32 1439
eRROR_SCREEN_ALREADY_LOCKED = hRESULT_FROM_WIN32 1440
eRROR_HWNDS_HAVE_DIFF_PARENT = hRESULT_FROM_WIN32 1441
eRROR_NOT_CHILD_WINDOW = hRESULT_FROM_WIN32 1442
eRROR_INVALID_GW_COMMAND = hRESULT_FROM_WIN32 1443
eRROR_INVALID_THREAD_ID = hRESULT_FROM_WIN32 1444
eRROR_NON_MDICHILD_WINDOW = hRESULT_FROM_WIN32 1445
eRROR_POPUP_ALREADY_ACTIVE = hRESULT_FROM_WIN32 1446
eRROR_NO_SCROLLBARS = hRESULT_FROM_WIN32 1447
eRROR_INVALID_SCROLLBAR_RANGE = hRESULT_FROM_WIN32 1448
eRROR_INVALID_SHOWWIN_COMMAND = hRESULT_FROM_WIN32 1449
eRROR_NO_SYSTEM_RESOURCES = hRESULT_FROM_WIN32 1450
eRROR_NONPAGED_SYSTEM_RESOURCES = hRESULT_FROM_WIN32 1451
eRROR_PAGED_SYSTEM_RESOURCES = hRESULT_FROM_WIN32 1452
eRROR_WORKING_SET_QUOTA = hRESULT_FROM_WIN32 1453
eRROR_PAGEFILE_QUOTA = hRESULT_FROM_WIN32 1454
eRROR_COMMITMENT_LIMIT = hRESULT_FROM_WIN32 1455
eRROR_MENU_ITEM_NOT_FOUND = hRESULT_FROM_WIN32 1456
eRROR_INVALID_KEYBOARD_HANDLE = hRESULT_FROM_WIN32 1457
eRROR_HOOK_TYPE_NOT_ALLOWED = hRESULT_FROM_WIN32 1458
eRROR_REQUIRES_INTERACTIVE_WINDOWSTATION = hRESULT_FROM_WIN32 1459
eRROR_TIMEOUT = hRESULT_FROM_WIN32 1460
eRROR_INVALID_MONITOR_HANDLE = hRESULT_FROM_WIN32 1461
eRROR_EVENTLOG_FILE_CORRUPT = hRESULT_FROM_WIN32 1500
eRROR_EVENTLOG_CANT_START = hRESULT_FROM_WIN32 1501
eRROR_LOG_FILE_FULL = hRESULT_FROM_WIN32 1502
eRROR_EVENTLOG_FILE_CHANGED = hRESULT_FROM_WIN32 1503
eRROR_INSTALL_SERVICE_FAILURE = hRESULT_FROM_WIN32 1601
eRROR_INSTALL_USEREXIT = hRESULT_FROM_WIN32 1602
eRROR_INSTALL_FAILURE = hRESULT_FROM_WIN32 1603
eRROR_INSTALL_SUSPEND = hRESULT_FROM_WIN32 1604
eRROR_UNKNOWN_PRODUCT = hRESULT_FROM_WIN32 1605
eRROR_UNKNOWN_FEATURE = hRESULT_FROM_WIN32 1606
eRROR_UNKNOWN_COMPONENT = hRESULT_FROM_WIN32 1607
eRROR_UNKNOWN_PROPERTY = hRESULT_FROM_WIN32 1608
eRROR_INVALID_HANDLE_STATE = hRESULT_FROM_WIN32 1609
eRROR_BAD_CONFIGURATION = hRESULT_FROM_WIN32 1610
eRROR_INDEX_ABSENT = hRESULT_FROM_WIN32 1611
eRROR_INSTALL_SOURCE_ABSENT = hRESULT_FROM_WIN32 1612
eRROR_INSTALL_PACKAGE_VERSION = hRESULT_FROM_WIN32 1613
eRROR_PRODUCT_UNINSTALLED = hRESULT_FROM_WIN32 1614
eRROR_BAD_QUERY_SYNTAX = hRESULT_FROM_WIN32 1615
eRROR_INVALID_FIELD = hRESULT_FROM_WIN32 1616
eRROR_DEVICE_REMOVED = hRESULT_FROM_WIN32 1617
eRROR_INSTALL_ALREADY_RUNNING = hRESULT_FROM_WIN32 1618
eRROR_INSTALL_PACKAGE_OPEN_FAILED = hRESULT_FROM_WIN32 1619
eRROR_INSTALL_PACKAGE_INVALID = hRESULT_FROM_WIN32 1620
eRROR_INSTALL_UI_FAILURE = hRESULT_FROM_WIN32 1621
eRROR_INSTALL_LOG_FAILURE = hRESULT_FROM_WIN32 1622
eRROR_INSTALL_LANGUAGE_UNSUPPORTED = hRESULT_FROM_WIN32 1623
eRROR_INSTALL_TRANSFORM_FAILURE = hRESULT_FROM_WIN32 1624
eRROR_INSTALL_PACKAGE_REJECTED = hRESULT_FROM_WIN32 1625
eRROR_FUNCTION_NOT_CALLED = hRESULT_FROM_WIN32 1626
eRROR_FUNCTION_FAILED = hRESULT_FROM_WIN32 1627
eRROR_INVALID_TABLE = hRESULT_FROM_WIN32 1628
eRROR_DATATYPE_MISMATCH = hRESULT_FROM_WIN32 1629
eRROR_UNSUPPORTED_TYPE = hRESULT_FROM_WIN32 1630
eRROR_CREATE_FAILED = hRESULT_FROM_WIN32 1631
eRROR_INSTALL_TEMP_UNWRITABLE = hRESULT_FROM_WIN32 1632
eRROR_INSTALL_PLATFORM_UNSUPPORTED = hRESULT_FROM_WIN32 1633
eRROR_INSTALL_NOTUSED = hRESULT_FROM_WIN32 1634
eRROR_PATCH_PACKAGE_OPEN_FAILED = hRESULT_FROM_WIN32 1635
eRROR_PATCH_PACKAGE_INVALID = hRESULT_FROM_WIN32 1636
eRROR_PATCH_PACKAGE_UNSUPPORTED = hRESULT_FROM_WIN32 1637
eRROR_PRODUCT_VERSION = hRESULT_FROM_WIN32 1638
eRROR_INVALID_COMMAND_LINE = hRESULT_FROM_WIN32 1639
eRROR_INSTALL_REMOTE_DISALLOWED = hRESULT_FROM_WIN32 1640
eRROR_SUCCESS_REBOOT_INITIATED = hRESULT_FROM_WIN32 1641
eRROR_PATCH_TARGET_NOT_FOUND = hRESULT_FROM_WIN32 1642
eRROR_PATCH_PACKAGE_REJECTED = hRESULT_FROM_WIN32 1643
eRROR_INSTALL_TRANSFORM_REJECTED = hRESULT_FROM_WIN32 1644
eRROR_INSTALL_REMOTE_PROHIBITED = hRESULT_FROM_WIN32 1645
rPC_S_INVALID_STRING_BINDING = hRESULT_FROM_WIN32 1700
rPC_S_WRONG_KIND_OF_BINDING = hRESULT_FROM_WIN32 1701
rPC_S_INVALID_BINDING = hRESULT_FROM_WIN32 1702
rPC_S_PROTSEQ_NOT_SUPPORTED = hRESULT_FROM_WIN32 1703
rPC_S_INVALID_RPC_PROTSEQ = hRESULT_FROM_WIN32 1704
rPC_S_INVALID_STRING_UUID = hRESULT_FROM_WIN32 1705
rPC_S_INVALID_ENDPOINT_FORMAT = hRESULT_FROM_WIN32 1706
rPC_S_INVALID_NET_ADDR = hRESULT_FROM_WIN32 1707
rPC_S_NO_ENDPOINT_FOUND = hRESULT_FROM_WIN32 1708
rPC_S_INVALID_TIMEOUT = hRESULT_FROM_WIN32 1709
rPC_S_OBJECT_NOT_FOUND = hRESULT_FROM_WIN32 1710
rPC_S_ALREADY_REGISTERED = hRESULT_FROM_WIN32 1711
rPC_S_TYPE_ALREADY_REGISTERED = hRESULT_FROM_WIN32 1712
rPC_S_ALREADY_LISTENING = hRESULT_FROM_WIN32 1713
rPC_S_NO_PROTSEQS_REGISTERED = hRESULT_FROM_WIN32 1714
rPC_S_NOT_LISTENING = hRESULT_FROM_WIN32 1715
rPC_S_UNKNOWN_MGR_TYPE = hRESULT_FROM_WIN32 1716
rPC_S_UNKNOWN_IF = hRESULT_FROM_WIN32 1717
rPC_S_NO_BINDINGS = hRESULT_FROM_WIN32 1718
rPC_S_NO_PROTSEQS = hRESULT_FROM_WIN32 1719
rPC_S_CANT_CREATE_ENDPOINT = hRESULT_FROM_WIN32 1720
rPC_S_OUT_OF_RESOURCES = hRESULT_FROM_WIN32 1721
rPC_S_SERVER_UNAVAILABLE = hRESULT_FROM_WIN32 1722
rPC_S_SERVER_TOO_BUSY = hRESULT_FROM_WIN32 1723
rPC_S_INVALID_NETWORK_OPTIONS = hRESULT_FROM_WIN32 1724
rPC_S_NO_CALL_ACTIVE = hRESULT_FROM_WIN32 1725
rPC_S_CALL_FAILED = hRESULT_FROM_WIN32 1726
rPC_S_CALL_FAILED_DNE = hRESULT_FROM_WIN32 1727
rPC_S_PROTOCOL_ERROR = hRESULT_FROM_WIN32 1728
rPC_S_UNSUPPORTED_TRANS_SYN = hRESULT_FROM_WIN32 1730
rPC_S_UNSUPPORTED_TYPE = hRESULT_FROM_WIN32 1732
rPC_S_INVALID_TAG = hRESULT_FROM_WIN32 1733
rPC_S_INVALID_BOUND = hRESULT_FROM_WIN32 1734
rPC_S_NO_ENTRY_NAME = hRESULT_FROM_WIN32 1735
rPC_S_INVALID_NAME_SYNTAX = hRESULT_FROM_WIN32 1736
rPC_S_UNSUPPORTED_NAME_SYNTAX = hRESULT_FROM_WIN32 1737
rPC_S_UUID_NO_ADDRESS = hRESULT_FROM_WIN32 1739
rPC_S_DUPLICATE_ENDPOINT = hRESULT_FROM_WIN32 1740
rPC_S_UNKNOWN_AUTHN_TYPE = hRESULT_FROM_WIN32 1741
rPC_S_MAX_CALLS_TOO_SMALL = hRESULT_FROM_WIN32 1742
rPC_S_STRING_TOO_LONG = hRESULT_FROM_WIN32 1743
rPC_S_PROTSEQ_NOT_FOUND = hRESULT_FROM_WIN32 1744
rPC_S_PROCNUM_OUT_OF_RANGE = hRESULT_FROM_WIN32 1745
rPC_S_BINDING_HAS_NO_AUTH = hRESULT_FROM_WIN32 1746
rPC_S_UNKNOWN_AUTHN_SERVICE = hRESULT_FROM_WIN32 1747
rPC_S_UNKNOWN_AUTHN_LEVEL = hRESULT_FROM_WIN32 1748
rPC_S_INVALID_AUTH_IDENTITY = hRESULT_FROM_WIN32 1749
rPC_S_UNKNOWN_AUTHZ_SERVICE = hRESULT_FROM_WIN32 1750
ePT_S_INVALID_ENTRY = hRESULT_FROM_WIN32 1751
ePT_S_CANT_PERFORM_OP = hRESULT_FROM_WIN32 1752
ePT_S_NOT_REGISTERED = hRESULT_FROM_WIN32 1753
rPC_S_NOTHING_TO_EXPORT = hRESULT_FROM_WIN32 1754
rPC_S_INCOMPLETE_NAME = hRESULT_FROM_WIN32 1755
rPC_S_INVALID_VERS_OPTION = hRESULT_FROM_WIN32 1756
rPC_S_NO_MORE_MEMBERS = hRESULT_FROM_WIN32 1757
rPC_S_NOT_ALL_OBJS_UNEXPORTED = hRESULT_FROM_WIN32 1758
rPC_S_INTERFACE_NOT_FOUND = hRESULT_FROM_WIN32 1759
rPC_S_ENTRY_ALREADY_EXISTS = hRESULT_FROM_WIN32 1760
rPC_S_ENTRY_NOT_FOUND = hRESULT_FROM_WIN32 1761
rPC_S_NAME_SERVICE_UNAVAILABLE = hRESULT_FROM_WIN32 1762
rPC_S_INVALID_NAF_ID = hRESULT_FROM_WIN32 1763
rPC_S_CANNOT_SUPPORT = hRESULT_FROM_WIN32 1764
rPC_S_NO_CONTEXT_AVAILABLE = hRESULT_FROM_WIN32 1765
rPC_S_INTERNAL_ERROR = hRESULT_FROM_WIN32 1766
rPC_S_ZERO_DIVIDE = hRESULT_FROM_WIN32 1767
rPC_S_ADDRESS_ERROR = hRESULT_FROM_WIN32 1768
rPC_S_FP_DIV_ZERO = hRESULT_FROM_WIN32 1769
rPC_S_FP_UNDERFLOW = hRESULT_FROM_WIN32 1770
rPC_S_FP_OVERFLOW = hRESULT_FROM_WIN32 1771
rPC_X_NO_MORE_ENTRIES = hRESULT_FROM_WIN32 1772
rPC_X_SS_CHAR_TRANS_OPEN_FAIL = hRESULT_FROM_WIN32 1773
rPC_X_SS_CHAR_TRANS_SHORT_FILE = hRESULT_FROM_WIN32 1774
rPC_X_SS_IN_NULL_CONTEXT = hRESULT_FROM_WIN32 1775
rPC_X_SS_CONTEXT_DAMAGED = hRESULT_FROM_WIN32 1777
rPC_X_SS_HANDLES_MISMATCH = hRESULT_FROM_WIN32 1778
rPC_X_SS_CANNOT_GET_CALL_HANDLE = hRESULT_FROM_WIN32 1779
rPC_X_NULL_REF_POINTER = hRESULT_FROM_WIN32 1780
rPC_X_ENUM_VALUE_OUT_OF_RANGE = hRESULT_FROM_WIN32 1781
rPC_X_BYTE_COUNT_TOO_SMALL = hRESULT_FROM_WIN32 1782
rPC_X_BAD_STUB_DATA = hRESULT_FROM_WIN32 1783
eRROR_INVALID_USER_BUFFER = hRESULT_FROM_WIN32 1784
eRROR_UNRECOGNIZED_MEDIA = hRESULT_FROM_WIN32 1785
eRROR_NO_TRUST_LSA_SECRET = hRESULT_FROM_WIN32 1786
eRROR_NO_TRUST_SAM_ACCOUNT = hRESULT_FROM_WIN32 1787
eRROR_TRUSTED_DOMAIN_FAILURE = hRESULT_FROM_WIN32 1788
eRROR_TRUSTED_RELATIONSHIP_FAILURE = hRESULT_FROM_WIN32 1789
eRROR_TRUST_FAILURE = hRESULT_FROM_WIN32 1790
rPC_S_CALL_IN_PROGRESS = hRESULT_FROM_WIN32 1791
eRROR_NETLOGON_NOT_STARTED = hRESULT_FROM_WIN32 1792
eRROR_ACCOUNT_EXPIRED = hRESULT_FROM_WIN32 1793
eRROR_REDIRECTOR_HAS_OPEN_HANDLES = hRESULT_FROM_WIN32 1794
eRROR_PRINTER_DRIVER_ALREADY_INSTALLED = hRESULT_FROM_WIN32 1795
eRROR_UNKNOWN_PORT = hRESULT_FROM_WIN32 1796
eRROR_UNKNOWN_PRINTER_DRIVER = hRESULT_FROM_WIN32 1797
eRROR_UNKNOWN_PRINTPROCESSOR = hRESULT_FROM_WIN32 1798
eRROR_INVALID_SEPARATOR_FILE = hRESULT_FROM_WIN32 1799
eRROR_INVALID_PRIORITY = hRESULT_FROM_WIN32 1800
eRROR_INVALID_PRINTER_NAME = hRESULT_FROM_WIN32 1801
eRROR_PRINTER_ALREADY_EXISTS = hRESULT_FROM_WIN32 1802
eRROR_INVALID_PRINTER_COMMAND = hRESULT_FROM_WIN32 1803
eRROR_INVALID_DATATYPE = hRESULT_FROM_WIN32 1804
eRROR_INVALID_ENVIRONMENT = hRESULT_FROM_WIN32 1805
rPC_S_NO_MORE_BINDINGS = hRESULT_FROM_WIN32 1806
eRROR_NOLOGON_INTERDOMAIN_TRUST_ACCOUNT = hRESULT_FROM_WIN32 1807
eRROR_NOLOGON_WORKSTATION_TRUST_ACCOUNT = hRESULT_FROM_WIN32 1808
eRROR_NOLOGON_SERVER_TRUST_ACCOUNT = hRESULT_FROM_WIN32 1809
eRROR_DOMAIN_TRUST_INCONSISTENT = hRESULT_FROM_WIN32 1810
eRROR_SERVER_HAS_OPEN_HANDLES = hRESULT_FROM_WIN32 1811
eRROR_RESOURCE_DATA_NOT_FOUND = hRESULT_FROM_WIN32 1812
eRROR_RESOURCE_TYPE_NOT_FOUND = hRESULT_FROM_WIN32 1813
eRROR_RESOURCE_NAME_NOT_FOUND = hRESULT_FROM_WIN32 1814
eRROR_RESOURCE_LANG_NOT_FOUND = hRESULT_FROM_WIN32 1815
eRROR_NOT_ENOUGH_QUOTA = hRESULT_FROM_WIN32 1816
rPC_S_NO_INTERFACES = hRESULT_FROM_WIN32 1817
rPC_S_CALL_CANCELLED = hRESULT_FROM_WIN32 1818
rPC_S_BINDING_INCOMPLETE = hRESULT_FROM_WIN32 1819
rPC_S_COMM_FAILURE = hRESULT_FROM_WIN32 1820
rPC_S_UNSUPPORTED_AUTHN_LEVEL = hRESULT_FROM_WIN32 1821
rPC_S_NO_PRINC_NAME = hRESULT_FROM_WIN32 1822
rPC_S_NOT_RPC_ERROR = hRESULT_FROM_WIN32 1823
rPC_S_UUID_LOCAL_ONLY = hRESULT_FROM_WIN32 1824
rPC_S_SEC_PKG_ERROR = hRESULT_FROM_WIN32 1825
rPC_S_NOT_CANCELLED = hRESULT_FROM_WIN32 1826
rPC_X_INVALID_ES_ACTION = hRESULT_FROM_WIN32 1827
rPC_X_WRONG_ES_VERSION = hRESULT_FROM_WIN32 1828
rPC_X_WRONG_STUB_VERSION = hRESULT_FROM_WIN32 1829
rPC_X_INVALID_PIPE_OBJECT = hRESULT_FROM_WIN32 1830
rPC_X_WRONG_PIPE_ORDER = hRESULT_FROM_WIN32 1831
rPC_X_WRONG_PIPE_VERSION = hRESULT_FROM_WIN32 1832
rPC_S_GROUP_MEMBER_NOT_FOUND = hRESULT_FROM_WIN32 1898
ePT_S_CANT_CREATE = hRESULT_FROM_WIN32 1899
rPC_S_INVALID_OBJECT = hRESULT_FROM_WIN32 1900
eRROR_INVALID_TIME = hRESULT_FROM_WIN32 1901
eRROR_INVALID_FORM_NAME = hRESULT_FROM_WIN32 1902
eRROR_INVALID_FORM_SIZE = hRESULT_FROM_WIN32 1903
eRROR_ALREADY_WAITING = hRESULT_FROM_WIN32 1904
eRROR_PRINTER_DELETED = hRESULT_FROM_WIN32 1905
eRROR_INVALID_PRINTER_STATE = hRESULT_FROM_WIN32 1906
eRROR_PASSWORD_MUST_CHANGE = hRESULT_FROM_WIN32 1907
eRROR_DOMAIN_CONTROLLER_NOT_FOUND = hRESULT_FROM_WIN32 1908
eRROR_ACCOUNT_LOCKED_OUT = hRESULT_FROM_WIN32 1909
oR_INVALID_OXID = hRESULT_FROM_WIN32 1910
oR_INVALID_OID = hRESULT_FROM_WIN32 1911
oR_INVALID_SET = hRESULT_FROM_WIN32 1912
rPC_S_SEND_INCOMPLETE = hRESULT_FROM_WIN32 1913
rPC_S_INVALID_ASYNC_HANDLE = hRESULT_FROM_WIN32 1914
rPC_S_INVALID_ASYNC_CALL = hRESULT_FROM_WIN32 1915
rPC_X_PIPE_CLOSED = hRESULT_FROM_WIN32 1916
rPC_X_PIPE_DISCIPLINE_ERROR = hRESULT_FROM_WIN32 1917
rPC_X_PIPE_EMPTY = hRESULT_FROM_WIN32 1918
eRROR_NO_SITENAME = hRESULT_FROM_WIN32 1919
eRROR_CANT_ACCESS_FILE = hRESULT_FROM_WIN32 1920
eRROR_CANT_RESOLVE_FILENAME = hRESULT_FROM_WIN32 1921
rPC_S_ENTRY_TYPE_MISMATCH = hRESULT_FROM_WIN32 1922
rPC_S_NOT_ALL_OBJS_EXPORTED = hRESULT_FROM_WIN32 1923
rPC_S_INTERFACE_NOT_EXPORTED = hRESULT_FROM_WIN32 1924
rPC_S_PROFILE_NOT_ADDED = hRESULT_FROM_WIN32 1925
rPC_S_PRF_ELT_NOT_ADDED = hRESULT_FROM_WIN32 1926
rPC_S_PRF_ELT_NOT_REMOVED = hRESULT_FROM_WIN32 1927
rPC_S_GRP_ELT_NOT_ADDED = hRESULT_FROM_WIN32 1928
rPC_S_GRP_ELT_NOT_REMOVED = hRESULT_FROM_WIN32 1929
eRROR_KM_DRIVER_BLOCKED = hRESULT_FROM_WIN32 1930
eRROR_CONTEXT_EXPIRED = hRESULT_FROM_WIN32 1931
eRROR_PER_USER_TRUST_QUOTA_EXCEEDED = hRESULT_FROM_WIN32 1932
eRROR_ALL_USER_TRUST_QUOTA_EXCEEDED = hRESULT_FROM_WIN32 1933
eRROR_USER_DELETE_TRUST_QUOTA_EXCEEDED = hRESULT_FROM_WIN32 1934
eRROR_INVALID_PIXEL_FORMAT = hRESULT_FROM_WIN32 2000
eRROR_BAD_DRIVER = hRESULT_FROM_WIN32 2001
eRROR_INVALID_WINDOW_STYLE = hRESULT_FROM_WIN32 2002
eRROR_METAFILE_NOT_SUPPORTED = hRESULT_FROM_WIN32 2003
eRROR_TRANSFORM_NOT_SUPPORTED = hRESULT_FROM_WIN32 2004
eRROR_CLIPPING_NOT_SUPPORTED = hRESULT_FROM_WIN32 2005
eRROR_INVALID_CMM = hRESULT_FROM_WIN32 2010
eRROR_INVALID_PROFILE = hRESULT_FROM_WIN32 2011
eRROR_TAG_NOT_FOUND = hRESULT_FROM_WIN32 2012
eRROR_TAG_NOT_PRESENT = hRESULT_FROM_WIN32 2013
eRROR_DUPLICATE_TAG = hRESULT_FROM_WIN32 2014
eRROR_PROFILE_NOT_ASSOCIATED_WITH_DEVICE = hRESULT_FROM_WIN32 2015
eRROR_PROFILE_NOT_FOUND = hRESULT_FROM_WIN32 2016
eRROR_INVALID_COLORSPACE = hRESULT_FROM_WIN32 2017
eRROR_ICM_NOT_ENABLED = hRESULT_FROM_WIN32 2018
eRROR_DELETING_ICM_XFORM = hRESULT_FROM_WIN32 2019
eRROR_INVALID_TRANSFORM = hRESULT_FROM_WIN32 2020
eRROR_COLORSPACE_MISMATCH = hRESULT_FROM_WIN32 2021
eRROR_INVALID_COLORINDEX = hRESULT_FROM_WIN32 2022
eRROR_CONNECTED_OTHER_PASSWORD = hRESULT_FROM_WIN32 2108
eRROR_CONNECTED_OTHER_PASSWORD_DEFAULT = hRESULT_FROM_WIN32 2109
eRROR_BAD_USERNAME = hRESULT_FROM_WIN32 2202
eRROR_NOT_CONNECTED = hRESULT_FROM_WIN32 2250
eRROR_OPEN_FILES = hRESULT_FROM_WIN32 2401
eRROR_ACTIVE_CONNECTIONS = hRESULT_FROM_WIN32 2402
eRROR_DEVICE_IN_USE = hRESULT_FROM_WIN32 2404
eRROR_UNKNOWN_PRINT_MONITOR = hRESULT_FROM_WIN32 3000
eRROR_PRINTER_DRIVER_IN_USE = hRESULT_FROM_WIN32 3001
eRROR_SPOOL_FILE_NOT_FOUND = hRESULT_FROM_WIN32 3002
eRROR_SPL_NO_STARTDOC = hRESULT_FROM_WIN32 3003
eRROR_SPL_NO_ADDJOB = hRESULT_FROM_WIN32 3004
eRROR_PRINT_PROCESSOR_ALREADY_INSTALLED = hRESULT_FROM_WIN32 3005
eRROR_PRINT_MONITOR_ALREADY_INSTALLED = hRESULT_FROM_WIN32 3006
eRROR_INVALID_PRINT_MONITOR = hRESULT_FROM_WIN32 3007
eRROR_PRINT_MONITOR_IN_USE = hRESULT_FROM_WIN32 3008
eRROR_PRINTER_HAS_JOBS_QUEUED = hRESULT_FROM_WIN32 3009
eRROR_SUCCESS_REBOOT_REQUIRED = hRESULT_FROM_WIN32 3010
eRROR_SUCCESS_RESTART_REQUIRED = hRESULT_FROM_WIN32 3011
eRROR_PRINTER_NOT_FOUND = hRESULT_FROM_WIN32 3012
eRROR_PRINTER_DRIVER_WARNED = hRESULT_FROM_WIN32 3013
eRROR_PRINTER_DRIVER_BLOCKED = hRESULT_FROM_WIN32 3014
eRROR_WINS_INTERNAL = hRESULT_FROM_WIN32 4000
eRROR_CAN_NOT_DEL_LOCAL_WINS = hRESULT_FROM_WIN32 4001
eRROR_STATIC_INIT = hRESULT_FROM_WIN32 4002
eRROR_INC_BACKUP = hRESULT_FROM_WIN32 4003
eRROR_FULL_BACKUP = hRESULT_FROM_WIN32 4004
eRROR_REC_NON_EXISTENT = hRESULT_FROM_WIN32 4005
eRROR_RPL_NOT_ALLOWED = hRESULT_FROM_WIN32 4006
eRROR_DHCP_ADDRESS_CONFLICT = hRESULT_FROM_WIN32 4100
eRROR_WMI_GUID_NOT_FOUND = hRESULT_FROM_WIN32 4200
eRROR_WMI_INSTANCE_NOT_FOUND = hRESULT_FROM_WIN32 4201
eRROR_WMI_ITEMID_NOT_FOUND = hRESULT_FROM_WIN32 4202
eRROR_WMI_TRY_AGAIN = hRESULT_FROM_WIN32 4203
eRROR_WMI_DP_NOT_FOUND = hRESULT_FROM_WIN32 4204
eRROR_WMI_UNRESOLVED_INSTANCE_REF = hRESULT_FROM_WIN32 4205
eRROR_WMI_ALREADY_ENABLED = hRESULT_FROM_WIN32 4206
eRROR_WMI_GUID_DISCONNECTED = hRESULT_FROM_WIN32 4207
eRROR_WMI_SERVER_UNAVAILABLE = hRESULT_FROM_WIN32 4208
eRROR_WMI_DP_FAILED = hRESULT_FROM_WIN32 4209
eRROR_WMI_INVALID_MOF = hRESULT_FROM_WIN32 4210
eRROR_WMI_INVALID_REGINFO = hRESULT_FROM_WIN32 4211
eRROR_WMI_ALREADY_DISABLED = hRESULT_FROM_WIN32 4212
eRROR_WMI_READ_ONLY = hRESULT_FROM_WIN32 4213
eRROR_WMI_SET_FAILURE = hRESULT_FROM_WIN32 4214
eRROR_INVALID_MEDIA = hRESULT_FROM_WIN32 4300
eRROR_INVALID_LIBRARY = hRESULT_FROM_WIN32 4301
eRROR_INVALID_MEDIA_POOL = hRESULT_FROM_WIN32 4302
eRROR_DRIVE_MEDIA_MISMATCH = hRESULT_FROM_WIN32 4303
eRROR_MEDIA_OFFLINE = hRESULT_FROM_WIN32 4304
eRROR_LIBRARY_OFFLINE = hRESULT_FROM_WIN32 4305
eRROR_EMPTY = hRESULT_FROM_WIN32 4306
eRROR_NOT_EMPTY = hRESULT_FROM_WIN32 4307
eRROR_MEDIA_UNAVAILABLE = hRESULT_FROM_WIN32 4308
eRROR_RESOURCE_DISABLED = hRESULT_FROM_WIN32 4309
eRROR_INVALID_CLEANER = hRESULT_FROM_WIN32 4310
eRROR_UNABLE_TO_CLEAN = hRESULT_FROM_WIN32 4311
eRROR_OBJECT_NOT_FOUND = hRESULT_FROM_WIN32 4312
eRROR_DATABASE_FAILURE = hRESULT_FROM_WIN32 4313
eRROR_DATABASE_FULL = hRESULT_FROM_WIN32 4314
eRROR_MEDIA_INCOMPATIBLE = hRESULT_FROM_WIN32 4315
eRROR_RESOURCE_NOT_PRESENT = hRESULT_FROM_WIN32 4316
eRROR_INVALID_OPERATION = hRESULT_FROM_WIN32 4317
eRROR_MEDIA_NOT_AVAILABLE = hRESULT_FROM_WIN32 4318
eRROR_DEVICE_NOT_AVAILABLE = hRESULT_FROM_WIN32 4319
eRROR_REQUEST_REFUSED = hRESULT_FROM_WIN32 4320
eRROR_INVALID_DRIVE_OBJECT = hRESULT_FROM_WIN32 4321
eRROR_LIBRARY_FULL = hRESULT_FROM_WIN32 4322
eRROR_MEDIUM_NOT_ACCESSIBLE = hRESULT_FROM_WIN32 4323
eRROR_UNABLE_TO_LOAD_MEDIUM = hRESULT_FROM_WIN32 4324
eRROR_UNABLE_TO_INVENTORY_DRIVE = hRESULT_FROM_WIN32 4325
eRROR_UNABLE_TO_INVENTORY_SLOT = hRESULT_FROM_WIN32 4326
eRROR_UNABLE_TO_INVENTORY_TRANSPORT = hRESULT_FROM_WIN32 4327
eRROR_TRANSPORT_FULL = hRESULT_FROM_WIN32 4328
eRROR_CONTROLLING_IEPORT = hRESULT_FROM_WIN32 4329
eRROR_UNABLE_TO_EJECT_MOUNTED_MEDIA = hRESULT_FROM_WIN32 4330
eRROR_CLEANER_SLOT_SET = hRESULT_FROM_WIN32 4331
eRROR_CLEANER_SLOT_NOT_SET = hRESULT_FROM_WIN32 4332
eRROR_CLEANER_CARTRIDGE_SPENT = hRESULT_FROM_WIN32 4333
eRROR_UNEXPECTED_OMID = hRESULT_FROM_WIN32 4334
eRROR_CANT_DELETE_LAST_ITEM = hRESULT_FROM_WIN32 4335
eRROR_MESSAGE_EXCEEDS_MAX_SIZE = hRESULT_FROM_WIN32 4336
eRROR_VOLUME_CONTAINS_SYS_FILES = hRESULT_FROM_WIN32 4337
eRROR_INDIGENOUS_TYPE = hRESULT_FROM_WIN32 4338
eRROR_NO_SUPPORTING_DRIVES = hRESULT_FROM_WIN32 4339
eRROR_CLEANER_CARTRIDGE_INSTALLED = hRESULT_FROM_WIN32 4340
eRROR_FILE_OFFLINE = hRESULT_FROM_WIN32 4350
eRROR_REMOTE_STORAGE_NOT_ACTIVE = hRESULT_FROM_WIN32 4351
eRROR_REMOTE_STORAGE_MEDIA_ERROR = hRESULT_FROM_WIN32 4352
eRROR_NOT_A_REPARSE_POINT = hRESULT_FROM_WIN32 4390
eRROR_REPARSE_ATTRIBUTE_CONFLICT = hRESULT_FROM_WIN32 4391
eRROR_INVALID_REPARSE_DATA = hRESULT_FROM_WIN32 4392
eRROR_REPARSE_TAG_INVALID = hRESULT_FROM_WIN32 4393
eRROR_REPARSE_TAG_MISMATCH = hRESULT_FROM_WIN32 4394
eRROR_VOLUME_NOT_SIS_ENABLED = hRESULT_FROM_WIN32 4500
eRROR_DEPENDENT_RESOURCE_EXISTS = hRESULT_FROM_WIN32 5001
eRROR_DEPENDENCY_NOT_FOUND = hRESULT_FROM_WIN32 5002
eRROR_DEPENDENCY_ALREADY_EXISTS = hRESULT_FROM_WIN32 5003
eRROR_RESOURCE_NOT_ONLINE = hRESULT_FROM_WIN32 5004
eRROR_HOST_NODE_NOT_AVAILABLE = hRESULT_FROM_WIN32 5005
eRROR_RESOURCE_NOT_AVAILABLE = hRESULT_FROM_WIN32 5006
eRROR_RESOURCE_NOT_FOUND = hRESULT_FROM_WIN32 5007
eRROR_SHUTDOWN_CLUSTER = hRESULT_FROM_WIN32 5008
eRROR_CANT_EVICT_ACTIVE_NODE = hRESULT_FROM_WIN32 5009
eRROR_OBJECT_ALREADY_EXISTS = hRESULT_FROM_WIN32 5010
eRROR_OBJECT_IN_LIST = hRESULT_FROM_WIN32 5011
eRROR_GROUP_NOT_AVAILABLE = hRESULT_FROM_WIN32 5012
eRROR_GROUP_NOT_FOUND = hRESULT_FROM_WIN32 5013
eRROR_GROUP_NOT_ONLINE = hRESULT_FROM_WIN32 5014
eRROR_HOST_NODE_NOT_RESOURCE_OWNER = hRESULT_FROM_WIN32 5015
eRROR_HOST_NODE_NOT_GROUP_OWNER = hRESULT_FROM_WIN32 5016
eRROR_RESMON_CREATE_FAILED = hRESULT_FROM_WIN32 5017
eRROR_RESMON_ONLINE_FAILED = hRESULT_FROM_WIN32 5018
eRROR_RESOURCE_ONLINE = hRESULT_FROM_WIN32 5019
eRROR_QUORUM_RESOURCE = hRESULT_FROM_WIN32 5020
eRROR_NOT_QUORUM_CAPABLE = hRESULT_FROM_WIN32 5021
eRROR_CLUSTER_SHUTTING_DOWN = hRESULT_FROM_WIN32 5022
eRROR_INVALID_STATE = hRESULT_FROM_WIN32 5023
eRROR_RESOURCE_PROPERTIES_STORED = hRESULT_FROM_WIN32 5024
eRROR_NOT_QUORUM_CLASS = hRESULT_FROM_WIN32 5025
eRROR_CORE_RESOURCE = hRESULT_FROM_WIN32 5026
eRROR_QUORUM_RESOURCE_ONLINE_FAILED = hRESULT_FROM_WIN32 5027
eRROR_QUORUMLOG_OPEN_FAILED = hRESULT_FROM_WIN32 5028
eRROR_CLUSTERLOG_CORRUPT = hRESULT_FROM_WIN32 5029
eRROR_CLUSTERLOG_RECORD_EXCEEDS_MAXSIZE = hRESULT_FROM_WIN32 5030
eRROR_CLUSTERLOG_EXCEEDS_MAXSIZE = hRESULT_FROM_WIN32 5031
eRROR_CLUSTERLOG_CHKPOINT_NOT_FOUND = hRESULT_FROM_WIN32 5032
eRROR_CLUSTERLOG_NOT_ENOUGH_SPACE = hRESULT_FROM_WIN32 5033
eRROR_QUORUM_OWNER_ALIVE = hRESULT_FROM_WIN32 5034
eRROR_NETWORK_NOT_AVAILABLE = hRESULT_FROM_WIN32 5035
eRROR_NODE_NOT_AVAILABLE = hRESULT_FROM_WIN32 5036
eRROR_ALL_NODES_NOT_AVAILABLE = hRESULT_FROM_WIN32 5037
eRROR_RESOURCE_FAILED = hRESULT_FROM_WIN32 5038
eRROR_CLUSTER_INVALID_NODE = hRESULT_FROM_WIN32 5039
eRROR_CLUSTER_NODE_EXISTS = hRESULT_FROM_WIN32 5040
eRROR_CLUSTER_JOIN_IN_PROGRESS = hRESULT_FROM_WIN32 5041
eRROR_CLUSTER_NODE_NOT_FOUND = hRESULT_FROM_WIN32 5042
eRROR_CLUSTER_LOCAL_NODE_NOT_FOUND = hRESULT_FROM_WIN32 5043
eRROR_CLUSTER_NETWORK_EXISTS = hRESULT_FROM_WIN32 5044
eRROR_CLUSTER_NETWORK_NOT_FOUND = hRESULT_FROM_WIN32 5045
eRROR_CLUSTER_NETINTERFACE_EXISTS = hRESULT_FROM_WIN32 5046
eRROR_CLUSTER_NETINTERFACE_NOT_FOUND = hRESULT_FROM_WIN32 5047
eRROR_CLUSTER_INVALID_REQUEST = hRESULT_FROM_WIN32 5048
eRROR_CLUSTER_INVALID_NETWORK_PROVIDER = hRESULT_FROM_WIN32 5049
eRROR_CLUSTER_NODE_DOWN = hRESULT_FROM_WIN32 5050
eRROR_CLUSTER_NODE_UNREACHABLE = hRESULT_FROM_WIN32 5051
eRROR_CLUSTER_NODE_NOT_MEMBER = hRESULT_FROM_WIN32 5052
eRROR_CLUSTER_JOIN_NOT_IN_PROGRESS = hRESULT_FROM_WIN32 5053
eRROR_CLUSTER_INVALID_NETWORK = hRESULT_FROM_WIN32 5054
eRROR_CLUSTER_NODE_UP = hRESULT_FROM_WIN32 5056
eRROR_CLUSTER_IPADDR_IN_USE = hRESULT_FROM_WIN32 5057
eRROR_CLUSTER_NODE_NOT_PAUSED = hRESULT_FROM_WIN32 5058
eRROR_CLUSTER_NO_SECURITY_CONTEXT = hRESULT_FROM_WIN32 5059
eRROR_CLUSTER_NETWORK_NOT_INTERNAL = hRESULT_FROM_WIN32 5060
eRROR_CLUSTER_NODE_ALREADY_UP = hRESULT_FROM_WIN32 5061
eRROR_CLUSTER_NODE_ALREADY_DOWN = hRESULT_FROM_WIN32 5062
eRROR_CLUSTER_NETWORK_ALREADY_ONLINE = hRESULT_FROM_WIN32 5063
eRROR_CLUSTER_NETWORK_ALREADY_OFFLINE = hRESULT_FROM_WIN32 5064
eRROR_CLUSTER_NODE_ALREADY_MEMBER = hRESULT_FROM_WIN32 5065
eRROR_CLUSTER_LAST_INTERNAL_NETWORK = hRESULT_FROM_WIN32 5066
eRROR_CLUSTER_NETWORK_HAS_DEPENDENTS = hRESULT_FROM_WIN32 5067
eRROR_INVALID_OPERATION_ON_QUORUM = hRESULT_FROM_WIN32 5068
eRROR_DEPENDENCY_NOT_ALLOWED = hRESULT_FROM_WIN32 5069
eRROR_CLUSTER_NODE_PAUSED = hRESULT_FROM_WIN32 5070
eRROR_NODE_CANT_HOST_RESOURCE = hRESULT_FROM_WIN32 5071
eRROR_CLUSTER_NODE_NOT_READY = hRESULT_FROM_WIN32 5072
eRROR_CLUSTER_NODE_SHUTTING_DOWN = hRESULT_FROM_WIN32 5073
eRROR_CLUSTER_JOIN_ABORTED = hRESULT_FROM_WIN32 5074
eRROR_CLUSTER_INCOMPATIBLE_VERSIONS = hRESULT_FROM_WIN32 5075
eRROR_CLUSTER_MAXNUM_OF_RESOURCES_EXCEEDED = hRESULT_FROM_WIN32 5076
eRROR_CLUSTER_SYSTEM_CONFIG_CHANGED = hRESULT_FROM_WIN32 5077
eRROR_CLUSTER_RESOURCE_TYPE_NOT_FOUND = hRESULT_FROM_WIN32 5078
eRROR_CLUSTER_RESTYPE_NOT_SUPPORTED = hRESULT_FROM_WIN32 5079
eRROR_CLUSTER_RESNAME_NOT_FOUND = hRESULT_FROM_WIN32 5080
eRROR_CLUSTER_NO_RPC_PACKAGES_REGISTERED = hRESULT_FROM_WIN32 5081
eRROR_CLUSTER_OWNER_NOT_IN_PREFLIST = hRESULT_FROM_WIN32 5082
eRROR_CLUSTER_DATABASE_SEQMISMATCH = hRESULT_FROM_WIN32 5083
eRROR_RESMON_INVALID_STATE = hRESULT_FROM_WIN32 5084
eRROR_CLUSTER_GUM_NOT_LOCKER = hRESULT_FROM_WIN32 5085
eRROR_QUORUM_DISK_NOT_FOUND = hRESULT_FROM_WIN32 5086
eRROR_DATABASE_BACKUP_CORRUPT = hRESULT_FROM_WIN32 5087
eRROR_CLUSTER_NODE_ALREADY_HAS_DFS_ROOT = hRESULT_FROM_WIN32 5088
eRROR_RESOURCE_PROPERTY_UNCHANGEABLE = hRESULT_FROM_WIN32 5089
eRROR_CLUSTER_MEMBERSHIP_INVALID_STATE = hRESULT_FROM_WIN32 5890
eRROR_CLUSTER_QUORUMLOG_NOT_FOUND = hRESULT_FROM_WIN32 5891
eRROR_CLUSTER_MEMBERSHIP_HALT = hRESULT_FROM_WIN32 5892
eRROR_CLUSTER_INSTANCE_ID_MISMATCH = hRESULT_FROM_WIN32 5893
eRROR_CLUSTER_NETWORK_NOT_FOUND_FOR_IP = hRESULT_FROM_WIN32 5894
eRROR_CLUSTER_PROPERTY_DATA_TYPE_MISMATCH = hRESULT_FROM_WIN32 5895
eRROR_CLUSTER_EVICT_WITHOUT_CLEANUP = hRESULT_FROM_WIN32 5896
eRROR_CLUSTER_PARAMETER_MISMATCH = hRESULT_FROM_WIN32 5897
eRROR_NODE_CANNOT_BE_CLUSTERED = hRESULT_FROM_WIN32 5898
eRROR_CLUSTER_WRONG_OS_VERSION = hRESULT_FROM_WIN32 5899
eRROR_CLUSTER_CANT_CREATE_DUP_CLUSTER_NAME = hRESULT_FROM_WIN32 5900
eRROR_CLUSCFG_ALREADY_COMMITTED = hRESULT_FROM_WIN32 5901
eRROR_CLUSCFG_ROLLBACK_FAILED = hRESULT_FROM_WIN32 5902
eRROR_CLUSCFG_SYSTEM_DISK_DRIVE_LETTER_CONFLICT = hRESULT_FROM_WIN32 5903
eRROR_CLUSTER_OLD_VERSION = hRESULT_FROM_WIN32 5904
eRROR_CLUSTER_MISMATCHED_COMPUTER_ACCT_NAME = hRESULT_FROM_WIN32 5905
eRROR_ENCRYPTION_FAILED = hRESULT_FROM_WIN32 6000
eRROR_DECRYPTION_FAILED = hRESULT_FROM_WIN32 6001
eRROR_FILE_ENCRYPTED = hRESULT_FROM_WIN32 6002
eRROR_NO_RECOVERY_POLICY = hRESULT_FROM_WIN32 6003
eRROR_NO_EFS = hRESULT_FROM_WIN32 6004
eRROR_WRONG_EFS = hRESULT_FROM_WIN32 6005
eRROR_NO_USER_KEYS = hRESULT_FROM_WIN32 6006
eRROR_FILE_NOT_ENCRYPTED = hRESULT_FROM_WIN32 6007
eRROR_NOT_EXPORT_FORMAT = hRESULT_FROM_WIN32 6008
eRROR_FILE_READ_ONLY = hRESULT_FROM_WIN32 6009
eRROR_DIR_EFS_DISALLOWED = hRESULT_FROM_WIN32 6010
eRROR_EFS_SERVER_NOT_TRUSTED = hRESULT_FROM_WIN32 6011
eRROR_BAD_RECOVERY_POLICY = hRESULT_FROM_WIN32 6012
eRROR_EFS_ALG_BLOB_TOO_BIG = hRESULT_FROM_WIN32 6013
eRROR_VOLUME_NOT_SUPPORT_EFS = hRESULT_FROM_WIN32 6014
eRROR_EFS_DISABLED = hRESULT_FROM_WIN32 6015
eRROR_EFS_VERSION_NOT_SUPPORT = hRESULT_FROM_WIN32 6016
eRROR_NO_BROWSER_SERVERS_FOUND = hRESULT_FROM_WIN32 6118
sCHED_E_SERVICE_NOT_LOCALSYSTEM = hRESULT_FROM_WIN32 6200
eRROR_CTX_WINSTATION_NAME_INVALID = hRESULT_FROM_WIN32 7001
eRROR_CTX_INVALID_PD = hRESULT_FROM_WIN32 7002
eRROR_CTX_PD_NOT_FOUND = hRESULT_FROM_WIN32 7003
eRROR_CTX_WD_NOT_FOUND = hRESULT_FROM_WIN32 7004
eRROR_CTX_CANNOT_MAKE_EVENTLOG_ENTRY = hRESULT_FROM_WIN32 7005
eRROR_CTX_SERVICE_NAME_COLLISION = hRESULT_FROM_WIN32 7006
eRROR_CTX_CLOSE_PENDING = hRESULT_FROM_WIN32 7007
eRROR_CTX_NO_OUTBUF = hRESULT_FROM_WIN32 7008
eRROR_CTX_MODEM_INF_NOT_FOUND = hRESULT_FROM_WIN32 7009
eRROR_CTX_INVALID_MODEMNAME = hRESULT_FROM_WIN32 7010
eRROR_CTX_MODEM_RESPONSE_ERROR = hRESULT_FROM_WIN32 7011
eRROR_CTX_MODEM_RESPONSE_TIMEOUT = hRESULT_FROM_WIN32 7012
eRROR_CTX_MODEM_RESPONSE_NO_CARRIER = hRESULT_FROM_WIN32 7013
eRROR_CTX_MODEM_RESPONSE_NO_DIALTONE = hRESULT_FROM_WIN32 7014
eRROR_CTX_MODEM_RESPONSE_BUSY = hRESULT_FROM_WIN32 7015
eRROR_CTX_MODEM_RESPONSE_VOICE = hRESULT_FROM_WIN32 7016
eRROR_CTX_TD_ERROR = hRESULT_FROM_WIN32 7017
eRROR_CTX_WINSTATION_NOT_FOUND = hRESULT_FROM_WIN32 7022
eRROR_CTX_WINSTATION_ALREADY_EXISTS = hRESULT_FROM_WIN32 7023
eRROR_CTX_WINSTATION_BUSY = hRESULT_FROM_WIN32 7024
eRROR_CTX_BAD_VIDEO_MODE = hRESULT_FROM_WIN32 7025
eRROR_CTX_GRAPHICS_INVALID = hRESULT_FROM_WIN32 7035
eRROR_CTX_LOGON_DISABLED = hRESULT_FROM_WIN32 7037
eRROR_CTX_NOT_CONSOLE = hRESULT_FROM_WIN32 7038
eRROR_CTX_CLIENT_QUERY_TIMEOUT = hRESULT_FROM_WIN32 7040
eRROR_CTX_CONSOLE_DISCONNECT = hRESULT_FROM_WIN32 7041
eRROR_CTX_CONSOLE_CONNECT = hRESULT_FROM_WIN32 7042
eRROR_CTX_SHADOW_DENIED = hRESULT_FROM_WIN32 7044
eRROR_CTX_WINSTATION_ACCESS_DENIED = hRESULT_FROM_WIN32 7045
eRROR_CTX_INVALID_WD = hRESULT_FROM_WIN32 7049
eRROR_CTX_SHADOW_INVALID = hRESULT_FROM_WIN32 7050
eRROR_CTX_SHADOW_DISABLED = hRESULT_FROM_WIN32 7051
eRROR_CTX_CLIENT_LICENSE_IN_USE = hRESULT_FROM_WIN32 7052
eRROR_CTX_CLIENT_LICENSE_NOT_SET = hRESULT_FROM_WIN32 7053
eRROR_CTX_LICENSE_NOT_AVAILABLE = hRESULT_FROM_WIN32 7054
eRROR_CTX_LICENSE_CLIENT_INVALID = hRESULT_FROM_WIN32 7055
eRROR_CTX_LICENSE_EXPIRED = hRESULT_FROM_WIN32 7056
eRROR_CTX_SHADOW_NOT_RUNNING = hRESULT_FROM_WIN32 7057
eRROR_CTX_SHADOW_ENDED_BY_MODE_CHANGE = hRESULT_FROM_WIN32 7058
eRROR_ACTIVATION_COUNT_EXCEEDED = hRESULT_FROM_WIN32 7059
fRS_ERR_INVALID_API_SEQUENCE = hRESULT_FROM_WIN32 8001
fRS_ERR_STARTING_SERVICE = hRESULT_FROM_WIN32 8002
fRS_ERR_STOPPING_SERVICE = hRESULT_FROM_WIN32 8003
fRS_ERR_INTERNAL_API = hRESULT_FROM_WIN32 8004
fRS_ERR_INTERNAL = hRESULT_FROM_WIN32 8005
fRS_ERR_SERVICE_COMM = hRESULT_FROM_WIN32 8006
fRS_ERR_INSUFFICIENT_PRIV = hRESULT_FROM_WIN32 8007
fRS_ERR_AUTHENTICATION = hRESULT_FROM_WIN32 8008
fRS_ERR_PARENT_INSUFFICIENT_PRIV = hRESULT_FROM_WIN32 8009
fRS_ERR_PARENT_AUTHENTICATION = hRESULT_FROM_WIN32 8010
fRS_ERR_CHILD_TO_PARENT_COMM = hRESULT_FROM_WIN32 8011
fRS_ERR_PARENT_TO_CHILD_COMM = hRESULT_FROM_WIN32 8012
fRS_ERR_SYSVOL_POPULATE = hRESULT_FROM_WIN32 8013
fRS_ERR_SYSVOL_POPULATE_TIMEOUT = hRESULT_FROM_WIN32 8014
fRS_ERR_SYSVOL_IS_BUSY = hRESULT_FROM_WIN32 8015
fRS_ERR_SYSVOL_DEMOTE = hRESULT_FROM_WIN32 8016
fRS_ERR_INVALID_SERVICE_PARAMETER = hRESULT_FROM_WIN32 8017
eRROR_DS_NOT_INSTALLED = hRESULT_FROM_WIN32 8200
eRROR_DS_MEMBERSHIP_EVALUATED_LOCALLY = hRESULT_FROM_WIN32 8201
eRROR_DS_NO_ATTRIBUTE_OR_VALUE = hRESULT_FROM_WIN32 8202
eRROR_DS_INVALID_ATTRIBUTE_SYNTAX = hRESULT_FROM_WIN32 8203
eRROR_DS_ATTRIBUTE_TYPE_UNDEFINED = hRESULT_FROM_WIN32 8204
eRROR_DS_ATTRIBUTE_OR_VALUE_EXISTS = hRESULT_FROM_WIN32 8205
eRROR_DS_BUSY = hRESULT_FROM_WIN32 8206
eRROR_DS_UNAVAILABLE = hRESULT_FROM_WIN32 8207
eRROR_DS_NO_RIDS_ALLOCATED = hRESULT_FROM_WIN32 8208
eRROR_DS_NO_MORE_RIDS = hRESULT_FROM_WIN32 8209
eRROR_DS_INCORRECT_ROLE_OWNER = hRESULT_FROM_WIN32 8210
eRROR_DS_RIDMGR_INIT_ERROR = hRESULT_FROM_WIN32 8211
eRROR_DS_OBJ_CLASS_VIOLATION = hRESULT_FROM_WIN32 8212
eRROR_DS_CANT_ON_NON_LEAF = hRESULT_FROM_WIN32 8213
eRROR_DS_CANT_ON_RDN = hRESULT_FROM_WIN32 8214
eRROR_DS_CANT_MOD_OBJ_CLASS = hRESULT_FROM_WIN32 8215
eRROR_DS_CROSS_DOM_MOVE_ERROR = hRESULT_FROM_WIN32 8216
eRROR_DS_GC_NOT_AVAILABLE = hRESULT_FROM_WIN32 8217
eRROR_SHARED_POLICY = hRESULT_FROM_WIN32 8218
eRROR_POLICY_OBJECT_NOT_FOUND = hRESULT_FROM_WIN32 8219
eRROR_POLICY_ONLY_IN_DS = hRESULT_FROM_WIN32 8220
eRROR_PROMOTION_ACTIVE = hRESULT_FROM_WIN32 8221
eRROR_NO_PROMOTION_ACTIVE = hRESULT_FROM_WIN32 8222
eRROR_DS_OPERATIONS_ERROR = hRESULT_FROM_WIN32 8224
eRROR_DS_PROTOCOL_ERROR = hRESULT_FROM_WIN32 8225
eRROR_DS_TIMELIMIT_EXCEEDED = hRESULT_FROM_WIN32 8226
eRROR_DS_SIZELIMIT_EXCEEDED = hRESULT_FROM_WIN32 8227
eRROR_DS_ADMIN_LIMIT_EXCEEDED = hRESULT_FROM_WIN32 8228
eRROR_DS_COMPARE_FALSE = hRESULT_FROM_WIN32 8229
eRROR_DS_COMPARE_TRUE = hRESULT_FROM_WIN32 8230
eRROR_DS_AUTH_METHOD_NOT_SUPPORTED = hRESULT_FROM_WIN32 8231
eRROR_DS_STRONG_AUTH_REQUIRED = hRESULT_FROM_WIN32 8232
eRROR_DS_INAPPROPRIATE_AUTH = hRESULT_FROM_WIN32 8233
eRROR_DS_AUTH_UNKNOWN = hRESULT_FROM_WIN32 8234
eRROR_DS_REFERRAL = hRESULT_FROM_WIN32 8235
eRROR_DS_UNAVAILABLE_CRIT_EXTENSION = hRESULT_FROM_WIN32 8236
eRROR_DS_CONFIDENTIALITY_REQUIRED = hRESULT_FROM_WIN32 8237
eRROR_DS_INAPPROPRIATE_MATCHING = hRESULT_FROM_WIN32 8238
eRROR_DS_CONSTRAINT_VIOLATION = hRESULT_FROM_WIN32 8239
eRROR_DS_NO_SUCH_OBJECT = hRESULT_FROM_WIN32 8240
eRROR_DS_ALIAS_PROBLEM = hRESULT_FROM_WIN32 8241
eRROR_DS_INVALID_DN_SYNTAX = hRESULT_FROM_WIN32 8242
eRROR_DS_IS_LEAF = hRESULT_FROM_WIN32 8243
eRROR_DS_ALIAS_DEREF_PROBLEM = hRESULT_FROM_WIN32 8244
eRROR_DS_UNWILLING_TO_PERFORM = hRESULT_FROM_WIN32 8245
eRROR_DS_LOOP_DETECT = hRESULT_FROM_WIN32 8246
eRROR_DS_NAMING_VIOLATION = hRESULT_FROM_WIN32 8247
eRROR_DS_OBJECT_RESULTS_TOO_LARGE = hRESULT_FROM_WIN32 8248
eRROR_DS_AFFECTS_MULTIPLE_DSAS = hRESULT_FROM_WIN32 8249
eRROR_DS_SERVER_DOWN = hRESULT_FROM_WIN32 8250
eRROR_DS_LOCAL_ERROR = hRESULT_FROM_WIN32 8251
eRROR_DS_ENCODING_ERROR = hRESULT_FROM_WIN32 8252
eRROR_DS_DECODING_ERROR = hRESULT_FROM_WIN32 8253
eRROR_DS_FILTER_UNKNOWN = hRESULT_FROM_WIN32 8254
eRROR_DS_PARAM_ERROR = hRESULT_FROM_WIN32 8255
eRROR_DS_NOT_SUPPORTED = hRESULT_FROM_WIN32 8256
eRROR_DS_NO_RESULTS_RETURNED = hRESULT_FROM_WIN32 8257
eRROR_DS_CONTROL_NOT_FOUND = hRESULT_FROM_WIN32 8258
eRROR_DS_CLIENT_LOOP = hRESULT_FROM_WIN32 8259
eRROR_DS_REFERRAL_LIMIT_EXCEEDED = hRESULT_FROM_WIN32 8260
eRROR_DS_SORT_CONTROL_MISSING = hRESULT_FROM_WIN32 8261
eRROR_DS_OFFSET_RANGE_ERROR = hRESULT_FROM_WIN32 8262
eRROR_DS_ROOT_MUST_BE_NC = hRESULT_FROM_WIN32 8301
eRROR_DS_ADD_REPLICA_INHIBITED = hRESULT_FROM_WIN32 8302
eRROR_DS_ATT_NOT_DEF_IN_SCHEMA = hRESULT_FROM_WIN32 8303
eRROR_DS_MAX_OBJ_SIZE_EXCEEDED = hRESULT_FROM_WIN32 8304
eRROR_DS_OBJ_STRING_NAME_EXISTS = hRESULT_FROM_WIN32 8305
eRROR_DS_NO_RDN_DEFINED_IN_SCHEMA = hRESULT_FROM_WIN32 8306
eRROR_DS_RDN_DOESNT_MATCH_SCHEMA = hRESULT_FROM_WIN32 8307
eRROR_DS_NO_REQUESTED_ATTS_FOUND = hRESULT_FROM_WIN32 8308
eRROR_DS_USER_BUFFER_TO_SMALL = hRESULT_FROM_WIN32 8309
eRROR_DS_ATT_IS_NOT_ON_OBJ = hRESULT_FROM_WIN32 8310
eRROR_DS_ILLEGAL_MOD_OPERATION = hRESULT_FROM_WIN32 8311
eRROR_DS_OBJ_TOO_LARGE = hRESULT_FROM_WIN32 8312
eRROR_DS_BAD_INSTANCE_TYPE = hRESULT_FROM_WIN32 8313
eRROR_DS_MASTERDSA_REQUIRED = hRESULT_FROM_WIN32 8314
eRROR_DS_OBJECT_CLASS_REQUIRED = hRESULT_FROM_WIN32 8315
eRROR_DS_MISSING_REQUIRED_ATT = hRESULT_FROM_WIN32 8316
eRROR_DS_ATT_NOT_DEF_FOR_CLASS = hRESULT_FROM_WIN32 8317
eRROR_DS_ATT_ALREADY_EXISTS = hRESULT_FROM_WIN32 8318
eRROR_DS_CANT_ADD_ATT_VALUES = hRESULT_FROM_WIN32 8320
eRROR_DS_SINGLE_VALUE_CONSTRAINT = hRESULT_FROM_WIN32 8321
eRROR_DS_RANGE_CONSTRAINT = hRESULT_FROM_WIN32 8322
eRROR_DS_ATT_VAL_ALREADY_EXISTS = hRESULT_FROM_WIN32 8323
eRROR_DS_CANT_REM_MISSING_ATT = hRESULT_FROM_WIN32 8324
eRROR_DS_CANT_REM_MISSING_ATT_VAL = hRESULT_FROM_WIN32 8325
eRROR_DS_ROOT_CANT_BE_SUBREF = hRESULT_FROM_WIN32 8326
eRROR_DS_NO_CHAINING = hRESULT_FROM_WIN32 8327
eRROR_DS_NO_CHAINED_EVAL = hRESULT_FROM_WIN32 8328
eRROR_DS_NO_PARENT_OBJECT = hRESULT_FROM_WIN32 8329
eRROR_DS_PARENT_IS_AN_ALIAS = hRESULT_FROM_WIN32 8330
eRROR_DS_CANT_MIX_MASTER_AND_REPS = hRESULT_FROM_WIN32 8331
eRROR_DS_CHILDREN_EXIST = hRESULT_FROM_WIN32 8332
eRROR_DS_OBJ_NOT_FOUND = hRESULT_FROM_WIN32 8333
eRROR_DS_ALIASED_OBJ_MISSING = hRESULT_FROM_WIN32 8334
eRROR_DS_BAD_NAME_SYNTAX = hRESULT_FROM_WIN32 8335
eRROR_DS_ALIAS_POINTS_TO_ALIAS = hRESULT_FROM_WIN32 8336
eRROR_DS_CANT_DEREF_ALIAS = hRESULT_FROM_WIN32 8337
eRROR_DS_OUT_OF_SCOPE = hRESULT_FROM_WIN32 8338
eRROR_DS_OBJECT_BEING_REMOVED = hRESULT_FROM_WIN32 8339
eRROR_DS_CANT_DELETE_DSA_OBJ = hRESULT_FROM_WIN32 8340
eRROR_DS_GENERIC_ERROR = hRESULT_FROM_WIN32 8341
eRROR_DS_DSA_MUST_BE_INT_MASTER = hRESULT_FROM_WIN32 8342
eRROR_DS_CLASS_NOT_DSA = hRESULT_FROM_WIN32 8343
eRROR_DS_INSUFF_ACCESS_RIGHTS = hRESULT_FROM_WIN32 8344
eRROR_DS_ILLEGAL_SUPERIOR = hRESULT_FROM_WIN32 8345
eRROR_DS_ATTRIBUTE_OWNED_BY_SAM = hRESULT_FROM_WIN32 8346
eRROR_DS_NAME_TOO_MANY_PARTS = hRESULT_FROM_WIN32 8347
eRROR_DS_NAME_TOO_LONG = hRESULT_FROM_WIN32 8348
eRROR_DS_NAME_VALUE_TOO_LONG = hRESULT_FROM_WIN32 8349
eRROR_DS_NAME_UNPARSEABLE = hRESULT_FROM_WIN32 8350
eRROR_DS_NAME_TYPE_UNKNOWN = hRESULT_FROM_WIN32 8351
eRROR_DS_NOT_AN_OBJECT = hRESULT_FROM_WIN32 8352
eRROR_DS_SEC_DESC_TOO_SHORT = hRESULT_FROM_WIN32 8353
eRROR_DS_SEC_DESC_INVALID = hRESULT_FROM_WIN32 8354
eRROR_DS_NO_DELETED_NAME = hRESULT_FROM_WIN32 8355
eRROR_DS_SUBREF_MUST_HAVE_PARENT = hRESULT_FROM_WIN32 8356
eRROR_DS_NCNAME_MUST_BE_NC = hRESULT_FROM_WIN32 8357
eRROR_DS_CANT_ADD_SYSTEM_ONLY = hRESULT_FROM_WIN32 8358
eRROR_DS_CLASS_MUST_BE_CONCRETE = hRESULT_FROM_WIN32 8359
eRROR_DS_INVALID_DMD = hRESULT_FROM_WIN32 8360
eRROR_DS_OBJ_GUID_EXISTS = hRESULT_FROM_WIN32 8361
eRROR_DS_NOT_ON_BACKLINK = hRESULT_FROM_WIN32 8362
eRROR_DS_NO_CROSSREF_FOR_NC = hRESULT_FROM_WIN32 8363
eRROR_DS_SHUTTING_DOWN = hRESULT_FROM_WIN32 8364
eRROR_DS_UNKNOWN_OPERATION = hRESULT_FROM_WIN32 8365
eRROR_DS_INVALID_ROLE_OWNER = hRESULT_FROM_WIN32 8366
eRROR_DS_COULDNT_CONTACT_FSMO = hRESULT_FROM_WIN32 8367
eRROR_DS_CROSS_NC_DN_RENAME = hRESULT_FROM_WIN32 8368
eRROR_DS_CANT_MOD_SYSTEM_ONLY = hRESULT_FROM_WIN32 8369
eRROR_DS_REPLICATOR_ONLY = hRESULT_FROM_WIN32 8370
eRROR_DS_OBJ_CLASS_NOT_DEFINED = hRESULT_FROM_WIN32 8371
eRROR_DS_OBJ_CLASS_NOT_SUBCLASS = hRESULT_FROM_WIN32 8372
eRROR_DS_NAME_REFERENCE_INVALID = hRESULT_FROM_WIN32 8373
eRROR_DS_CROSS_REF_EXISTS = hRESULT_FROM_WIN32 8374
eRROR_DS_CANT_DEL_MASTER_CROSSREF = hRESULT_FROM_WIN32 8375
eRROR_DS_SUBTREE_NOTIFY_NOT_NC_HEAD = hRESULT_FROM_WIN32 8376
eRROR_DS_NOTIFY_FILTER_TOO_COMPLEX = hRESULT_FROM_WIN32 8377
eRROR_DS_DUP_RDN = hRESULT_FROM_WIN32 8378
eRROR_DS_DUP_OID = hRESULT_FROM_WIN32 8379
eRROR_DS_DUP_MAPI_ID = hRESULT_FROM_WIN32 8380
eRROR_DS_DUP_SCHEMA_ID_GUID = hRESULT_FROM_WIN32 8381
eRROR_DS_DUP_LDAP_DISPLAY_NAME = hRESULT_FROM_WIN32 8382
eRROR_DS_SEMANTIC_ATT_TEST = hRESULT_FROM_WIN32 8383
eRROR_DS_SYNTAX_MISMATCH = hRESULT_FROM_WIN32 8384
eRROR_DS_EXISTS_IN_MUST_HAVE = hRESULT_FROM_WIN32 8385
eRROR_DS_EXISTS_IN_MAY_HAVE = hRESULT_FROM_WIN32 8386
eRROR_DS_NONEXISTENT_MAY_HAVE = hRESULT_FROM_WIN32 8387
eRROR_DS_NONEXISTENT_MUST_HAVE = hRESULT_FROM_WIN32 8388
eRROR_DS_AUX_CLS_TEST_FAIL = hRESULT_FROM_WIN32 8389
eRROR_DS_NONEXISTENT_POSS_SUP = hRESULT_FROM_WIN32 8390
eRROR_DS_SUB_CLS_TEST_FAIL = hRESULT_FROM_WIN32 8391
eRROR_DS_BAD_RDN_ATT_ID_SYNTAX = hRESULT_FROM_WIN32 8392
eRROR_DS_EXISTS_IN_AUX_CLS = hRESULT_FROM_WIN32 8393
eRROR_DS_EXISTS_IN_SUB_CLS = hRESULT_FROM_WIN32 8394
eRROR_DS_EXISTS_IN_POSS_SUP = hRESULT_FROM_WIN32 8395
eRROR_DS_RECALCSCHEMA_FAILED = hRESULT_FROM_WIN32 8396
eRROR_DS_TREE_DELETE_NOT_FINISHED = hRESULT_FROM_WIN32 8397
eRROR_DS_CANT_DELETE = hRESULT_FROM_WIN32 8398
eRROR_DS_ATT_SCHEMA_REQ_ID = hRESULT_FROM_WIN32 8399
eRROR_DS_BAD_ATT_SCHEMA_SYNTAX = hRESULT_FROM_WIN32 8400
eRROR_DS_CANT_CACHE_ATT = hRESULT_FROM_WIN32 8401
eRROR_DS_CANT_CACHE_CLASS = hRESULT_FROM_WIN32 8402
eRROR_DS_CANT_REMOVE_ATT_CACHE = hRESULT_FROM_WIN32 8403
eRROR_DS_CANT_REMOVE_CLASS_CACHE = hRESULT_FROM_WIN32 8404
eRROR_DS_CANT_RETRIEVE_DN = hRESULT_FROM_WIN32 8405
eRROR_DS_MISSING_SUPREF = hRESULT_FROM_WIN32 8406
eRROR_DS_CANT_RETRIEVE_INSTANCE = hRESULT_FROM_WIN32 8407
eRROR_DS_CODE_INCONSISTENCY = hRESULT_FROM_WIN32 8408
eRROR_DS_DATABASE_ERROR = hRESULT_FROM_WIN32 8409
eRROR_DS_GOVERNSID_MISSING = hRESULT_FROM_WIN32 8410
eRROR_DS_MISSING_EXPECTED_ATT = hRESULT_FROM_WIN32 8411
eRROR_DS_NCNAME_MISSING_CR_REF = hRESULT_FROM_WIN32 8412
eRROR_DS_SECURITY_CHECKING_ERROR = hRESULT_FROM_WIN32 8413
eRROR_DS_SCHEMA_NOT_LOADED = hRESULT_FROM_WIN32 8414
eRROR_DS_SCHEMA_ALLOC_FAILED = hRESULT_FROM_WIN32 8415
eRROR_DS_ATT_SCHEMA_REQ_SYNTAX = hRESULT_FROM_WIN32 8416
eRROR_DS_GCVERIFY_ERROR = hRESULT_FROM_WIN32 8417
eRROR_DS_DRA_SCHEMA_MISMATCH = hRESULT_FROM_WIN32 8418
eRROR_DS_CANT_FIND_DSA_OBJ = hRESULT_FROM_WIN32 8419
eRROR_DS_CANT_FIND_EXPECTED_NC = hRESULT_FROM_WIN32 8420
eRROR_DS_CANT_FIND_NC_IN_CACHE = hRESULT_FROM_WIN32 8421
eRROR_DS_CANT_RETRIEVE_CHILD = hRESULT_FROM_WIN32 8422
eRROR_DS_SECURITY_ILLEGAL_MODIFY = hRESULT_FROM_WIN32 8423
eRROR_DS_CANT_REPLACE_HIDDEN_REC = hRESULT_FROM_WIN32 8424
eRROR_DS_BAD_HIERARCHY_FILE = hRESULT_FROM_WIN32 8425
eRROR_DS_BUILD_HIERARCHY_TABLE_FAILED = hRESULT_FROM_WIN32 8426
eRROR_DS_CONFIG_PARAM_MISSING = hRESULT_FROM_WIN32 8427
eRROR_DS_COUNTING_AB_INDICES_FAILED = hRESULT_FROM_WIN32 8428
eRROR_DS_HIERARCHY_TABLE_MALLOC_FAILED = hRESULT_FROM_WIN32 8429
eRROR_DS_INTERNAL_FAILURE = hRESULT_FROM_WIN32 8430
eRROR_DS_UNKNOWN_ERROR = hRESULT_FROM_WIN32 8431
eRROR_DS_ROOT_REQUIRES_CLASS_TOP = hRESULT_FROM_WIN32 8432
eRROR_DS_REFUSING_FSMO_ROLES = hRESULT_FROM_WIN32 8433
eRROR_DS_MISSING_FSMO_SETTINGS = hRESULT_FROM_WIN32 8434
eRROR_DS_UNABLE_TO_SURRENDER_ROLES = hRESULT_FROM_WIN32 8435
eRROR_DS_DRA_GENERIC = hRESULT_FROM_WIN32 8436
eRROR_DS_DRA_INVALID_PARAMETER = hRESULT_FROM_WIN32 8437
eRROR_DS_DRA_BUSY = hRESULT_FROM_WIN32 8438
eRROR_DS_DRA_BAD_DN = hRESULT_FROM_WIN32 8439
eRROR_DS_DRA_BAD_NC = hRESULT_FROM_WIN32 8440
eRROR_DS_DRA_DN_EXISTS = hRESULT_FROM_WIN32 8441
eRROR_DS_DRA_INTERNAL_ERROR = hRESULT_FROM_WIN32 8442
eRROR_DS_DRA_INCONSISTENT_DIT = hRESULT_FROM_WIN32 8443
eRROR_DS_DRA_CONNECTION_FAILED = hRESULT_FROM_WIN32 8444
eRROR_DS_DRA_BAD_INSTANCE_TYPE = hRESULT_FROM_WIN32 8445
eRROR_DS_DRA_OUT_OF_MEM = hRESULT_FROM_WIN32 8446
eRROR_DS_DRA_MAIL_PROBLEM = hRESULT_FROM_WIN32 8447
eRROR_DS_DRA_REF_ALREADY_EXISTS = hRESULT_FROM_WIN32 8448
eRROR_DS_DRA_REF_NOT_FOUND = hRESULT_FROM_WIN32 8449
eRROR_DS_DRA_OBJ_IS_REP_SOURCE = hRESULT_FROM_WIN32 8450
eRROR_DS_DRA_DB_ERROR = hRESULT_FROM_WIN32 8451
eRROR_DS_DRA_NO_REPLICA = hRESULT_FROM_WIN32 8452
eRROR_DS_DRA_ACCESS_DENIED = hRESULT_FROM_WIN32 8453
eRROR_DS_DRA_NOT_SUPPORTED = hRESULT_FROM_WIN32 8454
eRROR_DS_DRA_RPC_CANCELLED = hRESULT_FROM_WIN32 8455
eRROR_DS_DRA_SOURCE_DISABLED = hRESULT_FROM_WIN32 8456
eRROR_DS_DRA_SINK_DISABLED = hRESULT_FROM_WIN32 8457
eRROR_DS_DRA_NAME_COLLISION = hRESULT_FROM_WIN32 8458
eRROR_DS_DRA_SOURCE_REINSTALLED = hRESULT_FROM_WIN32 8459
eRROR_DS_DRA_MISSING_PARENT = hRESULT_FROM_WIN32 8460
eRROR_DS_DRA_PREEMPTED = hRESULT_FROM_WIN32 8461
eRROR_DS_DRA_ABANDON_SYNC = hRESULT_FROM_WIN32 8462
eRROR_DS_DRA_SHUTDOWN = hRESULT_FROM_WIN32 8463
eRROR_DS_DRA_INCOMPATIBLE_PARTIAL_SET = hRESULT_FROM_WIN32 8464
eRROR_DS_DRA_SOURCE_IS_PARTIAL_REPLICA = hRESULT_FROM_WIN32 8465
eRROR_DS_DRA_EXTN_CONNECTION_FAILED = hRESULT_FROM_WIN32 8466
eRROR_DS_INSTALL_SCHEMA_MISMATCH = hRESULT_FROM_WIN32 8467
eRROR_DS_DUP_LINK_ID = hRESULT_FROM_WIN32 8468
eRROR_DS_NAME_ERROR_RESOLVING = hRESULT_FROM_WIN32 8469
eRROR_DS_NAME_ERROR_NOT_FOUND = hRESULT_FROM_WIN32 8470
eRROR_DS_NAME_ERROR_NOT_UNIQUE = hRESULT_FROM_WIN32 8471
eRROR_DS_NAME_ERROR_NO_MAPPING = hRESULT_FROM_WIN32 8472
eRROR_DS_NAME_ERROR_DOMAIN_ONLY = hRESULT_FROM_WIN32 8473
eRROR_DS_NAME_ERROR_NO_SYNTACTICAL_MAPPING = hRESULT_FROM_WIN32 8474
eRROR_DS_CONSTRUCTED_ATT_MOD = hRESULT_FROM_WIN32 8475
eRROR_DS_WRONG_OM_OBJ_CLASS = hRESULT_FROM_WIN32 8476
eRROR_DS_DRA_REPL_PENDING = hRESULT_FROM_WIN32 8477
eRROR_DS_DS_REQUIRED = hRESULT_FROM_WIN32 8478
eRROR_DS_INVALID_LDAP_DISPLAY_NAME = hRESULT_FROM_WIN32 8479
eRROR_DS_NON_BASE_SEARCH = hRESULT_FROM_WIN32 8480
eRROR_DS_CANT_RETRIEVE_ATTS = hRESULT_FROM_WIN32 8481
eRROR_DS_BACKLINK_WITHOUT_LINK = hRESULT_FROM_WIN32 8482
eRROR_DS_EPOCH_MISMATCH = hRESULT_FROM_WIN32 8483
eRROR_DS_SRC_NAME_MISMATCH = hRESULT_FROM_WIN32 8484
eRROR_DS_SRC_AND_DST_NC_IDENTICAL = hRESULT_FROM_WIN32 8485
eRROR_DS_DST_NC_MISMATCH = hRESULT_FROM_WIN32 8486
eRROR_DS_NOT_AUTHORITIVE_FOR_DST_NC = hRESULT_FROM_WIN32 8487
eRROR_DS_SRC_GUID_MISMATCH = hRESULT_FROM_WIN32 8488
eRROR_DS_CANT_MOVE_DELETED_OBJECT = hRESULT_FROM_WIN32 8489
eRROR_DS_PDC_OPERATION_IN_PROGRESS = hRESULT_FROM_WIN32 8490
eRROR_DS_CROSS_DOMAIN_CLEANUP_REQD = hRESULT_FROM_WIN32 8491
eRROR_DS_ILLEGAL_XDOM_MOVE_OPERATION = hRESULT_FROM_WIN32 8492
eRROR_DS_CANT_WITH_ACCT_GROUP_MEMBERSHPS = hRESULT_FROM_WIN32 8493
eRROR_DS_NC_MUST_HAVE_NC_PARENT = hRESULT_FROM_WIN32 8494
eRROR_DS_CR_IMPOSSIBLE_TO_VALIDATE = hRESULT_FROM_WIN32 8495
eRROR_DS_DST_DOMAIN_NOT_NATIVE = hRESULT_FROM_WIN32 8496
eRROR_DS_MISSING_INFRASTRUCTURE_CONTAINER = hRESULT_FROM_WIN32 8497
eRROR_DS_CANT_MOVE_ACCOUNT_GROUP = hRESULT_FROM_WIN32 8498
eRROR_DS_CANT_MOVE_RESOURCE_GROUP = hRESULT_FROM_WIN32 8499
eRROR_DS_INVALID_SEARCH_FLAG = hRESULT_FROM_WIN32 8500
eRROR_DS_NO_TREE_DELETE_ABOVE_NC = hRESULT_FROM_WIN32 8501
eRROR_DS_COULDNT_LOCK_TREE_FOR_DELETE = hRESULT_FROM_WIN32 8502
eRROR_DS_COULDNT_IDENTIFY_OBJECTS_FOR_TREE_DELETE = hRESULT_FROM_WIN32 8503
eRROR_DS_SAM_INIT_FAILURE = hRESULT_FROM_WIN32 8504
eRROR_DS_SENSITIVE_GROUP_VIOLATION = hRESULT_FROM_WIN32 8505
eRROR_DS_CANT_MOD_PRIMARYGROUPID = hRESULT_FROM_WIN32 8506
eRROR_DS_ILLEGAL_BASE_SCHEMA_MOD = hRESULT_FROM_WIN32 8507
eRROR_DS_NONSAFE_SCHEMA_CHANGE = hRESULT_FROM_WIN32 8508
eRROR_DS_SCHEMA_UPDATE_DISALLOWED = hRESULT_FROM_WIN32 8509
eRROR_DS_CANT_CREATE_UNDER_SCHEMA = hRESULT_FROM_WIN32 8510
eRROR_DS_INSTALL_NO_SRC_SCH_VERSION = hRESULT_FROM_WIN32 8511
eRROR_DS_INSTALL_NO_SCH_VERSION_IN_INIFILE = hRESULT_FROM_WIN32 8512
eRROR_DS_INVALID_GROUP_TYPE = hRESULT_FROM_WIN32 8513
eRROR_DS_NO_NEST_GLOBALGROUP_IN_MIXEDDOMAIN = hRESULT_FROM_WIN32 8514
eRROR_DS_NO_NEST_LOCALGROUP_IN_MIXEDDOMAIN = hRESULT_FROM_WIN32 8515
eRROR_DS_GLOBAL_CANT_HAVE_LOCAL_MEMBER = hRESULT_FROM_WIN32 8516
eRROR_DS_GLOBAL_CANT_HAVE_UNIVERSAL_MEMBER = hRESULT_FROM_WIN32 8517
eRROR_DS_UNIVERSAL_CANT_HAVE_LOCAL_MEMBER = hRESULT_FROM_WIN32 8518
eRROR_DS_GLOBAL_CANT_HAVE_CROSSDOMAIN_MEMBER = hRESULT_FROM_WIN32 8519
eRROR_DS_LOCAL_CANT_HAVE_CROSSDOMAIN_LOCAL_MEMBER = hRESULT_FROM_WIN32 8520
eRROR_DS_HAVE_PRIMARY_MEMBERS = hRESULT_FROM_WIN32 8521
eRROR_DS_STRING_SD_CONVERSION_FAILED = hRESULT_FROM_WIN32 8522
eRROR_DS_NAMING_MASTER_GC = hRESULT_FROM_WIN32 8523
eRROR_DS_LOOKUP_FAILURE = hRESULT_FROM_WIN32 8524
eRROR_DS_COULDNT_UPDATE_SPNS = hRESULT_FROM_WIN32 8525
eRROR_DS_CANT_RETRIEVE_SD = hRESULT_FROM_WIN32 8526
eRROR_DS_KEY_NOT_UNIQUE = hRESULT_FROM_WIN32 8527
eRROR_DS_WRONG_LINKED_ATT_SYNTAX = hRESULT_FROM_WIN32 8528
eRROR_DS_SAM_NEED_BOOTKEY_PASSWORD = hRESULT_FROM_WIN32 8529
eRROR_DS_SAM_NEED_BOOTKEY_FLOPPY = hRESULT_FROM_WIN32 8530
eRROR_DS_CANT_START = hRESULT_FROM_WIN32 8531
eRROR_DS_INIT_FAILURE = hRESULT_FROM_WIN32 8532
eRROR_DS_NO_PKT_PRIVACY_ON_CONNECTION = hRESULT_FROM_WIN32 8533
eRROR_DS_SOURCE_DOMAIN_IN_FOREST = hRESULT_FROM_WIN32 8534
eRROR_DS_DESTINATION_DOMAIN_NOT_IN_FOREST = hRESULT_FROM_WIN32 8535
eRROR_DS_DESTINATION_AUDITING_NOT_ENABLED = hRESULT_FROM_WIN32 8536
eRROR_DS_CANT_FIND_DC_FOR_SRC_DOMAIN = hRESULT_FROM_WIN32 8537
eRROR_DS_SRC_OBJ_NOT_GROUP_OR_USER = hRESULT_FROM_WIN32 8538
eRROR_DS_SRC_SID_EXISTS_IN_FOREST = hRESULT_FROM_WIN32 8539
eRROR_DS_SRC_AND_DST_OBJECT_CLASS_MISMATCH = hRESULT_FROM_WIN32 8540
eRROR_SAM_INIT_FAILURE = hRESULT_FROM_WIN32 8541
eRROR_DS_DRA_SCHEMA_INFO_SHIP = hRESULT_FROM_WIN32 8542
eRROR_DS_DRA_SCHEMA_CONFLICT = hRESULT_FROM_WIN32 8543
eRROR_DS_DRA_EARLIER_SCHEMA_CONLICT = hRESULT_FROM_WIN32 8544
eRROR_DS_DRA_OBJ_NC_MISMATCH = hRESULT_FROM_WIN32 8545
eRROR_DS_NC_STILL_HAS_DSAS = hRESULT_FROM_WIN32 8546
eRROR_DS_GC_REQUIRED = hRESULT_FROM_WIN32 8547
eRROR_DS_LOCAL_MEMBER_OF_LOCAL_ONLY = hRESULT_FROM_WIN32 8548
eRROR_DS_NO_FPO_IN_UNIVERSAL_GROUPS = hRESULT_FROM_WIN32 8549
eRROR_DS_CANT_ADD_TO_GC = hRESULT_FROM_WIN32 8550
eRROR_DS_NO_CHECKPOINT_WITH_PDC = hRESULT_FROM_WIN32 8551
eRROR_DS_SOURCE_AUDITING_NOT_ENABLED = hRESULT_FROM_WIN32 8552
eRROR_DS_CANT_CREATE_IN_NONDOMAIN_NC = hRESULT_FROM_WIN32 8553
eRROR_DS_INVALID_NAME_FOR_SPN = hRESULT_FROM_WIN32 8554
eRROR_DS_FILTER_USES_CONTRUCTED_ATTRS = hRESULT_FROM_WIN32 8555
eRROR_DS_UNICODEPWD_NOT_IN_QUOTES = hRESULT_FROM_WIN32 8556
eRROR_DS_MACHINE_ACCOUNT_QUOTA_EXCEEDED = hRESULT_FROM_WIN32 8557
eRROR_DS_MUST_BE_RUN_ON_DST_DC = hRESULT_FROM_WIN32 8558
eRROR_DS_SRC_DC_MUST_BE_SP4_OR_GREATER = hRESULT_FROM_WIN32 8559
eRROR_DS_CANT_TREE_DELETE_CRITICAL_OBJ = hRESULT_FROM_WIN32 8560
eRROR_DS_INIT_FAILURE_CONSOLE = hRESULT_FROM_WIN32 8561
eRROR_DS_SAM_INIT_FAILURE_CONSOLE = hRESULT_FROM_WIN32 8562
eRROR_DS_FOREST_VERSION_TOO_HIGH = hRESULT_FROM_WIN32 8563
eRROR_DS_DOMAIN_VERSION_TOO_HIGH = hRESULT_FROM_WIN32 8564
eRROR_DS_FOREST_VERSION_TOO_LOW = hRESULT_FROM_WIN32 8565
eRROR_DS_DOMAIN_VERSION_TOO_LOW = hRESULT_FROM_WIN32 8566
eRROR_DS_INCOMPATIBLE_VERSION = hRESULT_FROM_WIN32 8567
eRROR_DS_LOW_DSA_VERSION = hRESULT_FROM_WIN32 8568
eRROR_DS_NO_BEHAVIOR_VERSION_IN_MIXEDDOMAIN = hRESULT_FROM_WIN32 8569
eRROR_DS_NOT_SUPPORTED_SORT_ORDER = hRESULT_FROM_WIN32 8570
eRROR_DS_NAME_NOT_UNIQUE = hRESULT_FROM_WIN32 8571
eRROR_DS_MACHINE_ACCOUNT_CREATED_PRENT4 = hRESULT_FROM_WIN32 8572
eRROR_DS_OUT_OF_VERSION_STORE = hRESULT_FROM_WIN32 8573
eRROR_DS_INCOMPATIBLE_CONTROLS_USED = hRESULT_FROM_WIN32 8574
eRROR_DS_NO_REF_DOMAIN = hRESULT_FROM_WIN32 8575
eRROR_DS_RESERVED_LINK_ID = hRESULT_FROM_WIN32 8576
eRROR_DS_LINK_ID_NOT_AVAILABLE = hRESULT_FROM_WIN32 8577
eRROR_DS_AG_CANT_HAVE_UNIVERSAL_MEMBER = hRESULT_FROM_WIN32 8578
eRROR_DS_MODIFYDN_DISALLOWED_BY_INSTANCE_TYPE = hRESULT_FROM_WIN32 8579
eRROR_DS_NO_OBJECT_MOVE_IN_SCHEMA_NC = hRESULT_FROM_WIN32 8580
eRROR_DS_MODIFYDN_DISALLOWED_BY_FLAG = hRESULT_FROM_WIN32 8581
eRROR_DS_MODIFYDN_WRONG_GRANDPARENT = hRESULT_FROM_WIN32 8582
eRROR_DS_NAME_ERROR_TRUST_REFERRAL = hRESULT_FROM_WIN32 8583
eRROR_NOT_SUPPORTED_ON_STANDARD_SERVER = hRESULT_FROM_WIN32 8584
eRROR_DS_CANT_ACCESS_REMOTE_PART_OF_AD = hRESULT_FROM_WIN32 8585
eRROR_DS_CR_IMPOSSIBLE_TO_VALIDATE_V2 = hRESULT_FROM_WIN32 8586
eRROR_DS_THREAD_LIMIT_EXCEEDED = hRESULT_FROM_WIN32 8587
eRROR_DS_NOT_CLOSEST = hRESULT_FROM_WIN32 8588
eRROR_DS_CANT_DERIVE_SPN_WITHOUT_SERVER_REF = hRESULT_FROM_WIN32 8589
eRROR_DS_SINGLE_USER_MODE_FAILED = hRESULT_FROM_WIN32 8590
eRROR_DS_NTDSCRIPT_SYNTAX_ERROR = hRESULT_FROM_WIN32 8591
eRROR_DS_NTDSCRIPT_PROCESS_ERROR = hRESULT_FROM_WIN32 8592
eRROR_DS_DIFFERENT_REPL_EPOCHS = hRESULT_FROM_WIN32 8593
eRROR_DS_DRS_EXTENSIONS_CHANGED = hRESULT_FROM_WIN32 8594
eRROR_DS_REPLICA_SET_CHANGE_NOT_ALLOWED_ON_DISABLED_CR = hRESULT_FROM_WIN32 8595
eRROR_DS_NO_MSDS_INTID = hRESULT_FROM_WIN32 8596
eRROR_DS_DUP_MSDS_INTID = hRESULT_FROM_WIN32 8597
eRROR_DS_EXISTS_IN_RDNATTID = hRESULT_FROM_WIN32 8598
eRROR_DS_AUTHORIZATION_FAILED = hRESULT_FROM_WIN32 8599
eRROR_DS_INVALID_SCRIPT = hRESULT_FROM_WIN32 8600
eRROR_DS_REMOTE_CROSSREF_OP_FAILED = hRESULT_FROM_WIN32 8601
eRROR_DS_CROSS_REF_BUSY = hRESULT_FROM_WIN32 8602
eRROR_DS_CANT_DERIVE_SPN_FOR_DELETED_DOMAIN = hRESULT_FROM_WIN32 8603
eRROR_DS_CANT_DEMOTE_WITH_WRITEABLE_NC = hRESULT_FROM_WIN32 8604
eRROR_DS_DUPLICATE_ID_FOUND = hRESULT_FROM_WIN32 8605
eRROR_DS_INSUFFICIENT_ATTR_TO_CREATE_OBJECT = hRESULT_FROM_WIN32 8606
eRROR_DS_GROUP_CONVERSION_ERROR = hRESULT_FROM_WIN32 8607
eRROR_DS_CANT_MOVE_APP_BASIC_GROUP = hRESULT_FROM_WIN32 8608
eRROR_DS_CANT_MOVE_APP_QUERY_GROUP = hRESULT_FROM_WIN32 8609
eRROR_DS_ROLE_NOT_VERIFIED = hRESULT_FROM_WIN32 8610
eRROR_DS_WKO_CONTAINER_CANNOT_BE_SPECIAL = hRESULT_FROM_WIN32 8611
eRROR_DS_DOMAIN_RENAME_IN_PROGRESS = hRESULT_FROM_WIN32 8612
eRROR_DS_EXISTING_AD_CHILD_NC = hRESULT_FROM_WIN32 8613
dNS_ERROR_RCODE_FORMAT_ERROR = hRESULT_FROM_WIN32 9001
dNS_ERROR_RCODE_SERVER_FAILURE = hRESULT_FROM_WIN32 9002
dNS_ERROR_RCODE_NAME_ERROR = hRESULT_FROM_WIN32 9003
dNS_ERROR_RCODE_NOT_IMPLEMENTED = hRESULT_FROM_WIN32 9004
dNS_ERROR_RCODE_REFUSED = hRESULT_FROM_WIN32 9005
dNS_ERROR_RCODE_YXDOMAIN = hRESULT_FROM_WIN32 9006
dNS_ERROR_RCODE_YXRRSET = hRESULT_FROM_WIN32 9007
dNS_ERROR_RCODE_NXRRSET = hRESULT_FROM_WIN32 9008
dNS_ERROR_RCODE_NOTAUTH = hRESULT_FROM_WIN32 9009
dNS_ERROR_RCODE_NOTZONE = hRESULT_FROM_WIN32 9010
dNS_ERROR_RCODE_BADSIG = hRESULT_FROM_WIN32 9016
dNS_ERROR_RCODE_BADKEY = hRESULT_FROM_WIN32 9017
dNS_ERROR_RCODE_BADTIME = hRESULT_FROM_WIN32 9018
dNS_INFO_NO_RECORDS = hRESULT_FROM_WIN32 9501
dNS_ERROR_BAD_PACKET = hRESULT_FROM_WIN32 9502
dNS_ERROR_NO_PACKET = hRESULT_FROM_WIN32 9503
dNS_ERROR_RCODE = hRESULT_FROM_WIN32 9504
dNS_ERROR_UNSECURE_PACKET = hRESULT_FROM_WIN32 9505
dNS_ERROR_INVALID_TYPE = hRESULT_FROM_WIN32 9551
dNS_ERROR_INVALID_IP_ADDRESS = hRESULT_FROM_WIN32 9552
dNS_ERROR_INVALID_PROPERTY = hRESULT_FROM_WIN32 9553
dNS_ERROR_TRY_AGAIN_LATER = hRESULT_FROM_WIN32 9554
dNS_ERROR_NOT_UNIQUE = hRESULT_FROM_WIN32 9555
dNS_ERROR_NON_RFC_NAME = hRESULT_FROM_WIN32 9556
dNS_STATUS_FQDN = hRESULT_FROM_WIN32 9557
dNS_STATUS_DOTTED_NAME = hRESULT_FROM_WIN32 9558
dNS_STATUS_SINGLE_PART_NAME = hRESULT_FROM_WIN32 9559
dNS_ERROR_INVALID_NAME_CHAR = hRESULT_FROM_WIN32 9560
dNS_ERROR_NUMERIC_NAME = hRESULT_FROM_WIN32 9561
dNS_ERROR_NOT_ALLOWED_ON_ROOT_SERVER = hRESULT_FROM_WIN32 9562
dNS_ERROR_NOT_ALLOWED_UNDER_DELEGATION = hRESULT_FROM_WIN32 9563
dNS_ERROR_CANNOT_FIND_ROOT_HINTS = hRESULT_FROM_WIN32 9564
dNS_ERROR_INCONSISTENT_ROOT_HINTS = hRESULT_FROM_WIN32 9565
dNS_ERROR_ZONE_DOES_NOT_EXIST = hRESULT_FROM_WIN32 9601
dNS_ERROR_NO_ZONE_INFO = hRESULT_FROM_WIN32 9602
dNS_ERROR_INVALID_ZONE_OPERATION = hRESULT_FROM_WIN32 9603
dNS_ERROR_ZONE_CONFIGURATION_ERROR = hRESULT_FROM_WIN32 9604
dNS_ERROR_ZONE_HAS_NO_SOA_RECORD = hRESULT_FROM_WIN32 9605
dNS_ERROR_ZONE_HAS_NO_NS_RECORDS = hRESULT_FROM_WIN32 9606
dNS_ERROR_ZONE_LOCKED = hRESULT_FROM_WIN32 9607
dNS_ERROR_ZONE_CREATION_FAILED = hRESULT_FROM_WIN32 9608
dNS_ERROR_ZONE_ALREADY_EXISTS = hRESULT_FROM_WIN32 9609
dNS_ERROR_AUTOZONE_ALREADY_EXISTS = hRESULT_FROM_WIN32 9610
dNS_ERROR_INVALID_ZONE_TYPE = hRESULT_FROM_WIN32 9611
dNS_ERROR_SECONDARY_REQUIRES_MASTER_IP = hRESULT_FROM_WIN32 9612
dNS_ERROR_ZONE_NOT_SECONDARY = hRESULT_FROM_WIN32 9613
dNS_ERROR_NEED_SECONDARY_ADDRESSES = hRESULT_FROM_WIN32 9614
dNS_ERROR_WINS_INIT_FAILED = hRESULT_FROM_WIN32 9615
dNS_ERROR_NEED_WINS_SERVERS = hRESULT_FROM_WIN32 9616
dNS_ERROR_NBSTAT_INIT_FAILED = hRESULT_FROM_WIN32 9617
dNS_ERROR_SOA_DELETE_INVALID = hRESULT_FROM_WIN32 9618
dNS_ERROR_FORWARDER_ALREADY_EXISTS = hRESULT_FROM_WIN32 9619
dNS_ERROR_ZONE_REQUIRES_MASTER_IP = hRESULT_FROM_WIN32 9620
dNS_ERROR_ZONE_IS_SHUTDOWN = hRESULT_FROM_WIN32 9621
dNS_ERROR_PRIMARY_REQUIRES_DATAFILE = hRESULT_FROM_WIN32 9651
dNS_ERROR_INVALID_DATAFILE_NAME = hRESULT_FROM_WIN32 9652
dNS_ERROR_DATAFILE_OPEN_FAILURE = hRESULT_FROM_WIN32 9653
dNS_ERROR_FILE_WRITEBACK_FAILED = hRESULT_FROM_WIN32 9654
dNS_ERROR_DATAFILE_PARSING = hRESULT_FROM_WIN32 9655
dNS_ERROR_RECORD_DOES_NOT_EXIST = hRESULT_FROM_WIN32 9701
dNS_ERROR_RECORD_FORMAT = hRESULT_FROM_WIN32 9702
dNS_ERROR_NODE_CREATION_FAILED = hRESULT_FROM_WIN32 9703
dNS_ERROR_UNKNOWN_RECORD_TYPE = hRESULT_FROM_WIN32 9704
dNS_ERROR_RECORD_TIMED_OUT = hRESULT_FROM_WIN32 9705
dNS_ERROR_NAME_NOT_IN_ZONE = hRESULT_FROM_WIN32 9706
dNS_ERROR_CNAME_LOOP = hRESULT_FROM_WIN32 9707
dNS_ERROR_NODE_IS_CNAME = hRESULT_FROM_WIN32 9708
dNS_ERROR_CNAME_COLLISION = hRESULT_FROM_WIN32 9709
dNS_ERROR_RECORD_ONLY_AT_ZONE_ROOT = hRESULT_FROM_WIN32 9710
dNS_ERROR_RECORD_ALREADY_EXISTS = hRESULT_FROM_WIN32 9711
dNS_ERROR_SECONDARY_DATA = hRESULT_FROM_WIN32 9712
dNS_ERROR_NO_CREATE_CACHE_DATA = hRESULT_FROM_WIN32 9713
dNS_ERROR_NAME_DOES_NOT_EXIST = hRESULT_FROM_WIN32 9714
dNS_WARNING_PTR_CREATE_FAILED = hRESULT_FROM_WIN32 9715
dNS_WARNING_DOMAIN_UNDELETED = hRESULT_FROM_WIN32 9716
dNS_ERROR_DS_UNAVAILABLE = hRESULT_FROM_WIN32 9717
dNS_ERROR_DS_ZONE_ALREADY_EXISTS = hRESULT_FROM_WIN32 9718
dNS_ERROR_NO_BOOTFILE_IF_DS_ZONE = hRESULT_FROM_WIN32 9719
dNS_INFO_AXFR_COMPLETE = hRESULT_FROM_WIN32 9751
dNS_ERROR_AXFR = hRESULT_FROM_WIN32 9752
dNS_INFO_ADDED_LOCAL_WINS = hRESULT_FROM_WIN32 9753
dNS_STATUS_CONTINUE_NEEDED = hRESULT_FROM_WIN32 9801
dNS_ERROR_NO_TCPIP = hRESULT_FROM_WIN32 9851
dNS_ERROR_NO_DNS_SERVERS = hRESULT_FROM_WIN32 9852
dNS_ERROR_DP_DOES_NOT_EXIST = hRESULT_FROM_WIN32 9901
dNS_ERROR_DP_ALREADY_EXISTS = hRESULT_FROM_WIN32 9902
dNS_ERROR_DP_NOT_ENLISTED = hRESULT_FROM_WIN32 9903
dNS_ERROR_DP_ALREADY_ENLISTED = hRESULT_FROM_WIN32 9904
dNS_ERROR_DP_NOT_AVAILABLE = hRESULT_FROM_WIN32 9905
wSAEINTR = hRESULT_FROM_WIN32 10004
wSAEBADF = hRESULT_FROM_WIN32 10009
wSAEACCES = hRESULT_FROM_WIN32 10013
wSAEFAULT = hRESULT_FROM_WIN32 10014
wSAEINVAL = hRESULT_FROM_WIN32 10022
wSAEMFILE = hRESULT_FROM_WIN32 10024
wSAEWOULDBLOCK = hRESULT_FROM_WIN32 10035
wSAEINPROGRESS = hRESULT_FROM_WIN32 10036
wSAEALREADY = hRESULT_FROM_WIN32 10037
wSAENOTSOCK = hRESULT_FROM_WIN32 10038
wSAEDESTADDRREQ = hRESULT_FROM_WIN32 10039
wSAEMSGSIZE = hRESULT_FROM_WIN32 10040
wSAEPROTOTYPE = hRESULT_FROM_WIN32 10041
wSAENOPROTOOPT = hRESULT_FROM_WIN32 10042
wSAEPROTONOSUPPORT = hRESULT_FROM_WIN32 10043
wSAESOCKTNOSUPPORT = hRESULT_FROM_WIN32 10044
wSAEOPNOTSUPP = hRESULT_FROM_WIN32 10045
wSAEPFNOSUPPORT = hRESULT_FROM_WIN32 10046
wSAEAFNOSUPPORT = hRESULT_FROM_WIN32 10047
wSAEADDRINUSE = hRESULT_FROM_WIN32 10048
wSAEADDRNOTAVAIL = hRESULT_FROM_WIN32 10049
wSAENETDOWN = hRESULT_FROM_WIN32 10050
wSAENETUNREACH = hRESULT_FROM_WIN32 10051
wSAENETRESET = hRESULT_FROM_WIN32 10052
wSAECONNABORTED = hRESULT_FROM_WIN32 10053
wSAECONNRESET = hRESULT_FROM_WIN32 10054
wSAENOBUFS = hRESULT_FROM_WIN32 10055
wSAEISCONN = hRESULT_FROM_WIN32 10056
wSAENOTCONN = hRESULT_FROM_WIN32 10057
wSAESHUTDOWN = hRESULT_FROM_WIN32 10058
wSAETOOMANYREFS = hRESULT_FROM_WIN32 10059
wSAETIMEDOUT = hRESULT_FROM_WIN32 10060
wSAECONNREFUSED = hRESULT_FROM_WIN32 10061
wSAELOOP = hRESULT_FROM_WIN32 10062
wSAENAMETOOLONG = hRESULT_FROM_WIN32 10063
wSAEHOSTDOWN = hRESULT_FROM_WIN32 10064
wSAEHOSTUNREACH = hRESULT_FROM_WIN32 10065
wSAENOTEMPTY = hRESULT_FROM_WIN32 10066
wSAEPROCLIM = hRESULT_FROM_WIN32 10067
wSAEUSERS = hRESULT_FROM_WIN32 10068
wSAEDQUOT = hRESULT_FROM_WIN32 10069
wSAESTALE = hRESULT_FROM_WIN32 10070
wSAEREMOTE = hRESULT_FROM_WIN32 10071
wSASYSNOTREADY = hRESULT_FROM_WIN32 10091
wSAVERNOTSUPPORTED = hRESULT_FROM_WIN32 10092
wSANOTINITIALISED = hRESULT_FROM_WIN32 10093
wSAEDISCON = hRESULT_FROM_WIN32 10101
wSAENOMORE = hRESULT_FROM_WIN32 10102
wSAECANCELLED = hRESULT_FROM_WIN32 10103
wSAEINVALIDPROCTABLE = hRESULT_FROM_WIN32 10104
wSAEINVALIDPROVIDER = hRESULT_FROM_WIN32 10105
wSAEPROVIDERFAILEDINIT = hRESULT_FROM_WIN32 10106
wSASYSCALLFAILURE = hRESULT_FROM_WIN32 10107
wSASERVICE_NOT_FOUND = hRESULT_FROM_WIN32 10108
wSATYPE_NOT_FOUND = hRESULT_FROM_WIN32 10109
wSA_E_NO_MORE = hRESULT_FROM_WIN32 10110
wSA_E_CANCELLED = hRESULT_FROM_WIN32 10111
wSAEREFUSED = hRESULT_FROM_WIN32 10112
wSAHOST_NOT_FOUND = hRESULT_FROM_WIN32 11001
wSATRY_AGAIN = hRESULT_FROM_WIN32 11002
wSANO_RECOVERY = hRESULT_FROM_WIN32 11003
wSANO_DATA = hRESULT_FROM_WIN32 11004
wSA_QOS_RECEIVERS = hRESULT_FROM_WIN32 11005
wSA_QOS_SENDERS = hRESULT_FROM_WIN32 11006
wSA_QOS_NO_SENDERS = hRESULT_FROM_WIN32 11007
wSA_QOS_NO_RECEIVERS = hRESULT_FROM_WIN32 11008
wSA_QOS_REQUEST_CONFIRMED = hRESULT_FROM_WIN32 11009
wSA_QOS_ADMISSION_FAILURE = hRESULT_FROM_WIN32 11010
wSA_QOS_POLICY_FAILURE = hRESULT_FROM_WIN32 11011
wSA_QOS_BAD_STYLE = hRESULT_FROM_WIN32 11012
wSA_QOS_BAD_OBJECT = hRESULT_FROM_WIN32 11013
wSA_QOS_TRAFFIC_CTRL_ERROR = hRESULT_FROM_WIN32 11014
wSA_QOS_GENERIC_ERROR = hRESULT_FROM_WIN32 11015
wSA_QOS_ESERVICETYPE = hRESULT_FROM_WIN32 11016
wSA_QOS_EFLOWSPEC = hRESULT_FROM_WIN32 11017
wSA_QOS_EPROVSPECBUF = hRESULT_FROM_WIN32 11018
wSA_QOS_EFILTERSTYLE = hRESULT_FROM_WIN32 11019
wSA_QOS_EFILTERTYPE = hRESULT_FROM_WIN32 11020
wSA_QOS_EFILTERCOUNT = hRESULT_FROM_WIN32 11021
wSA_QOS_EOBJLENGTH = hRESULT_FROM_WIN32 11022
wSA_QOS_EFLOWCOUNT = hRESULT_FROM_WIN32 11023
wSA_QOS_EUNKNOWNPSOBJ = hRESULT_FROM_WIN32 11024
wSA_QOS_EPOLICYOBJ = hRESULT_FROM_WIN32 11025
wSA_QOS_EFLOWDESC = hRESULT_FROM_WIN32 11026
wSA_QOS_EPSFLOWSPEC = hRESULT_FROM_WIN32 11027
wSA_QOS_EPSFILTERSPEC = hRESULT_FROM_WIN32 11028
wSA_QOS_ESDMODEOBJ = hRESULT_FROM_WIN32 11029
wSA_QOS_ESHAPERATEOBJ = hRESULT_FROM_WIN32 11030
wSA_QOS_RESERVED_PETYPE = hRESULT_FROM_WIN32 11031
eRROR_IPSEC_QM_POLICY_EXISTS = hRESULT_FROM_WIN32 13000
eRROR_IPSEC_QM_POLICY_NOT_FOUND = hRESULT_FROM_WIN32 13001
eRROR_IPSEC_QM_POLICY_IN_USE = hRESULT_FROM_WIN32 13002
eRROR_IPSEC_MM_POLICY_EXISTS = hRESULT_FROM_WIN32 13003
eRROR_IPSEC_MM_POLICY_NOT_FOUND = hRESULT_FROM_WIN32 13004
eRROR_IPSEC_MM_POLICY_IN_USE = hRESULT_FROM_WIN32 13005
eRROR_IPSEC_MM_FILTER_EXISTS = hRESULT_FROM_WIN32 13006
eRROR_IPSEC_MM_FILTER_NOT_FOUND = hRESULT_FROM_WIN32 13007
eRROR_IPSEC_TRANSPORT_FILTER_EXISTS = hRESULT_FROM_WIN32 13008
eRROR_IPSEC_TRANSPORT_FILTER_NOT_FOUND = hRESULT_FROM_WIN32 13009
eRROR_IPSEC_MM_AUTH_EXISTS = hRESULT_FROM_WIN32 13010
eRROR_IPSEC_MM_AUTH_NOT_FOUND = hRESULT_FROM_WIN32 13011
eRROR_IPSEC_MM_AUTH_IN_USE = hRESULT_FROM_WIN32 13012
eRROR_IPSEC_DEFAULT_MM_POLICY_NOT_FOUND = hRESULT_FROM_WIN32 13013
eRROR_IPSEC_DEFAULT_MM_AUTH_NOT_FOUND = hRESULT_FROM_WIN32 13014
eRROR_IPSEC_DEFAULT_QM_POLICY_NOT_FOUND = hRESULT_FROM_WIN32 13015
eRROR_IPSEC_TUNNEL_FILTER_EXISTS = hRESULT_FROM_WIN32 13016
eRROR_IPSEC_TUNNEL_FILTER_NOT_FOUND = hRESULT_FROM_WIN32 13017
eRROR_IPSEC_MM_FILTER_PENDING_DELETION = hRESULT_FROM_WIN32 13018
eRROR_IPSEC_TRANSPORT_FILTER_PENDING_DELETION = hRESULT_FROM_WIN32 13019
eRROR_IPSEC_TUNNEL_FILTER_PENDING_DELETION = hRESULT_FROM_WIN32 13020
eRROR_IPSEC_MM_POLICY_PENDING_DELETION = hRESULT_FROM_WIN32 13021
eRROR_IPSEC_MM_AUTH_PENDING_DELETION = hRESULT_FROM_WIN32 13022
eRROR_IPSEC_QM_POLICY_PENDING_DELETION = hRESULT_FROM_WIN32 13023
wARNING_IPSEC_MM_POLICY_PRUNED = hRESULT_FROM_WIN32 13024
wARNING_IPSEC_QM_POLICY_PRUNED = hRESULT_FROM_WIN32 13025
eRROR_IPSEC_IKE_AUTH_FAIL = hRESULT_FROM_WIN32 13801
eRROR_IPSEC_IKE_ATTRIB_FAIL = hRESULT_FROM_WIN32 13802
eRROR_IPSEC_IKE_NEGOTIATION_PENDING = hRESULT_FROM_WIN32 13803
eRROR_IPSEC_IKE_GENERAL_PROCESSING_ERROR = hRESULT_FROM_WIN32 13804
eRROR_IPSEC_IKE_TIMED_OUT = hRESULT_FROM_WIN32 13805
eRROR_IPSEC_IKE_NO_CERT = hRESULT_FROM_WIN32 13806
eRROR_IPSEC_IKE_SA_DELETED = hRESULT_FROM_WIN32 13807
eRROR_IPSEC_IKE_SA_REAPED = hRESULT_FROM_WIN32 13808
eRROR_IPSEC_IKE_MM_ACQUIRE_DROP = hRESULT_FROM_WIN32 13809
eRROR_IPSEC_IKE_QM_ACQUIRE_DROP = hRESULT_FROM_WIN32 13810
eRROR_IPSEC_IKE_QUEUE_DROP_MM = hRESULT_FROM_WIN32 13811
eRROR_IPSEC_IKE_QUEUE_DROP_NO_MM = hRESULT_FROM_WIN32 13812
eRROR_IPSEC_IKE_DROP_NO_RESPONSE = hRESULT_FROM_WIN32 13813
eRROR_IPSEC_IKE_MM_DELAY_DROP = hRESULT_FROM_WIN32 13814
eRROR_IPSEC_IKE_QM_DELAY_DROP = hRESULT_FROM_WIN32 13815
eRROR_IPSEC_IKE_ERROR = hRESULT_FROM_WIN32 13816
eRROR_IPSEC_IKE_CRL_FAILED = hRESULT_FROM_WIN32 13817
eRROR_IPSEC_IKE_INVALID_KEY_USAGE = hRESULT_FROM_WIN32 13818
eRROR_IPSEC_IKE_INVALID_CERT_TYPE = hRESULT_FROM_WIN32 13819
eRROR_IPSEC_IKE_NO_PRIVATE_KEY = hRESULT_FROM_WIN32 13820
eRROR_IPSEC_IKE_DH_FAIL = hRESULT_FROM_WIN32 13822
eRROR_IPSEC_IKE_INVALID_HEADER = hRESULT_FROM_WIN32 13824
eRROR_IPSEC_IKE_NO_POLICY = hRESULT_FROM_WIN32 13825
eRROR_IPSEC_IKE_INVALID_SIGNATURE = hRESULT_FROM_WIN32 13826
eRROR_IPSEC_IKE_KERBEROS_ERROR = hRESULT_FROM_WIN32 13827
eRROR_IPSEC_IKE_NO_PUBLIC_KEY = hRESULT_FROM_WIN32 13828
eRROR_IPSEC_IKE_PROCESS_ERR = hRESULT_FROM_WIN32 13829
eRROR_IPSEC_IKE_PROCESS_ERR_SA = hRESULT_FROM_WIN32 13830
eRROR_IPSEC_IKE_PROCESS_ERR_PROP = hRESULT_FROM_WIN32 13831
eRROR_IPSEC_IKE_PROCESS_ERR_TRANS = hRESULT_FROM_WIN32 13832
eRROR_IPSEC_IKE_PROCESS_ERR_KE = hRESULT_FROM_WIN32 13833
eRROR_IPSEC_IKE_PROCESS_ERR_ID = hRESULT_FROM_WIN32 13834
eRROR_IPSEC_IKE_PROCESS_ERR_CERT = hRESULT_FROM_WIN32 13835
eRROR_IPSEC_IKE_PROCESS_ERR_CERT_REQ = hRESULT_FROM_WIN32 13836
eRROR_IPSEC_IKE_PROCESS_ERR_HASH = hRESULT_FROM_WIN32 13837
eRROR_IPSEC_IKE_PROCESS_ERR_SIG = hRESULT_FROM_WIN32 13838
eRROR_IPSEC_IKE_PROCESS_ERR_NONCE = hRESULT_FROM_WIN32 13839
eRROR_IPSEC_IKE_PROCESS_ERR_NOTIFY = hRESULT_FROM_WIN32 13840
eRROR_IPSEC_IKE_PROCESS_ERR_DELETE = hRESULT_FROM_WIN32 13841
eRROR_IPSEC_IKE_PROCESS_ERR_VENDOR = hRESULT_FROM_WIN32 13842
eRROR_IPSEC_IKE_INVALID_PAYLOAD = hRESULT_FROM_WIN32 13843
eRROR_IPSEC_IKE_LOAD_SOFT_SA = hRESULT_FROM_WIN32 13844
eRROR_IPSEC_IKE_SOFT_SA_TORN_DOWN = hRESULT_FROM_WIN32 13845
eRROR_IPSEC_IKE_INVALID_COOKIE = hRESULT_FROM_WIN32 13846
eRROR_IPSEC_IKE_NO_PEER_CERT = hRESULT_FROM_WIN32 13847
eRROR_IPSEC_IKE_PEER_CRL_FAILED = hRESULT_FROM_WIN32 13848
eRROR_IPSEC_IKE_POLICY_CHANGE = hRESULT_FROM_WIN32 13849
eRROR_IPSEC_IKE_NO_MM_POLICY = hRESULT_FROM_WIN32 13850
eRROR_IPSEC_IKE_NOTCBPRIV = hRESULT_FROM_WIN32 13851
eRROR_IPSEC_IKE_SECLOADFAIL = hRESULT_FROM_WIN32 13852
eRROR_IPSEC_IKE_FAILSSPINIT = hRESULT_FROM_WIN32 13853
eRROR_IPSEC_IKE_FAILQUERYSSP = hRESULT_FROM_WIN32 13854
eRROR_IPSEC_IKE_SRVACQFAIL = hRESULT_FROM_WIN32 13855
eRROR_IPSEC_IKE_SRVQUERYCRED = hRESULT_FROM_WIN32 13856
eRROR_IPSEC_IKE_GETSPIFAIL = hRESULT_FROM_WIN32 13857
eRROR_IPSEC_IKE_INVALID_FILTER = hRESULT_FROM_WIN32 13858
eRROR_IPSEC_IKE_OUT_OF_MEMORY = hRESULT_FROM_WIN32 13859
eRROR_IPSEC_IKE_ADD_UPDATE_KEY_FAILED = hRESULT_FROM_WIN32 13860
eRROR_IPSEC_IKE_INVALID_POLICY = hRESULT_FROM_WIN32 13861
eRROR_IPSEC_IKE_UNKNOWN_DOI = hRESULT_FROM_WIN32 13862
eRROR_IPSEC_IKE_INVALID_SITUATION = hRESULT_FROM_WIN32 13863
eRROR_IPSEC_IKE_DH_FAILURE = hRESULT_FROM_WIN32 13864
eRROR_IPSEC_IKE_INVALID_GROUP = hRESULT_FROM_WIN32 13865
eRROR_IPSEC_IKE_ENCRYPT = hRESULT_FROM_WIN32 13866
eRROR_IPSEC_IKE_DECRYPT = hRESULT_FROM_WIN32 13867
eRROR_IPSEC_IKE_POLICY_MATCH = hRESULT_FROM_WIN32 13868
eRROR_IPSEC_IKE_UNSUPPORTED_ID = hRESULT_FROM_WIN32 13869
eRROR_IPSEC_IKE_INVALID_HASH = hRESULT_FROM_WIN32 13870
eRROR_IPSEC_IKE_INVALID_HASH_ALG = hRESULT_FROM_WIN32 13871
eRROR_IPSEC_IKE_INVALID_HASH_SIZE = hRESULT_FROM_WIN32 13872
eRROR_IPSEC_IKE_INVALID_ENCRYPT_ALG = hRESULT_FROM_WIN32 13873
eRROR_IPSEC_IKE_INVALID_AUTH_ALG = hRESULT_FROM_WIN32 13874
eRROR_IPSEC_IKE_INVALID_SIG = hRESULT_FROM_WIN32 13875
eRROR_IPSEC_IKE_LOAD_FAILED = hRESULT_FROM_WIN32 13876
eRROR_IPSEC_IKE_RPC_DELETE = hRESULT_FROM_WIN32 13877
eRROR_IPSEC_IKE_BENIGN_REINIT = hRESULT_FROM_WIN32 13878
eRROR_IPSEC_IKE_INVALID_RESPONDER_LIFETIME_NOTIFY = hRESULT_FROM_WIN32 13879
eRROR_IPSEC_IKE_INVALID_CERT_KEYLEN = hRESULT_FROM_WIN32 13881
eRROR_IPSEC_IKE_MM_LIMIT = hRESULT_FROM_WIN32 13882
eRROR_IPSEC_IKE_NEGOTIATION_DISABLED = hRESULT_FROM_WIN32 13883
eRROR_IPSEC_IKE_NEG_STATUS_END = hRESULT_FROM_WIN32 13884
eRROR_SXS_SECTION_NOT_FOUND = hRESULT_FROM_WIN32 14000
eRROR_SXS_CANT_GEN_ACTCTX = hRESULT_FROM_WIN32 14001
eRROR_SXS_INVALID_ACTCTXDATA_FORMAT = hRESULT_FROM_WIN32 14002
eRROR_SXS_ASSEMBLY_NOT_FOUND = hRESULT_FROM_WIN32 14003
eRROR_SXS_MANIFEST_FORMAT_ERROR = hRESULT_FROM_WIN32 14004
eRROR_SXS_MANIFEST_PARSE_ERROR = hRESULT_FROM_WIN32 14005
eRROR_SXS_ACTIVATION_CONTEXT_DISABLED = hRESULT_FROM_WIN32 14006
eRROR_SXS_KEY_NOT_FOUND = hRESULT_FROM_WIN32 14007
eRROR_SXS_VERSION_CONFLICT = hRESULT_FROM_WIN32 14008
eRROR_SXS_WRONG_SECTION_TYPE = hRESULT_FROM_WIN32 14009
eRROR_SXS_THREAD_QUERIES_DISABLED = hRESULT_FROM_WIN32 14010
eRROR_SXS_PROCESS_DEFAULT_ALREADY_SET = hRESULT_FROM_WIN32 14011
eRROR_SXS_UNKNOWN_ENCODING_GROUP = hRESULT_FROM_WIN32 14012
eRROR_SXS_UNKNOWN_ENCODING = hRESULT_FROM_WIN32 14013
eRROR_SXS_INVALID_XML_NAMESPACE_URI = hRESULT_FROM_WIN32 14014
eRROR_SXS_ROOT_MANIFEST_DEPENDENCY_NOT_INSTALLED = hRESULT_FROM_WIN32 14015
eRROR_SXS_LEAF_MANIFEST_DEPENDENCY_NOT_INSTALLED = hRESULT_FROM_WIN32 14016
eRROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE = hRESULT_FROM_WIN32 14017
eRROR_SXS_MANIFEST_MISSING_REQUIRED_DEFAULT_NAMESPACE = hRESULT_FROM_WIN32 14018
eRROR_SXS_MANIFEST_INVALID_REQUIRED_DEFAULT_NAMESPACE = hRESULT_FROM_WIN32 14019
eRROR_SXS_PRIVATE_MANIFEST_CROSS_PATH_WITH_REPARSE_POINT = hRESULT_FROM_WIN32 14020
eRROR_SXS_DUPLICATE_DLL_NAME = hRESULT_FROM_WIN32 14021
eRROR_SXS_DUPLICATE_WINDOWCLASS_NAME = hRESULT_FROM_WIN32 14022
eRROR_SXS_DUPLICATE_CLSID = hRESULT_FROM_WIN32 14023
eRROR_SXS_DUPLICATE_IID = hRESULT_FROM_WIN32 14024
eRROR_SXS_DUPLICATE_TLBID = hRESULT_FROM_WIN32 14025
eRROR_SXS_DUPLICATE_PROGID = hRESULT_FROM_WIN32 14026
eRROR_SXS_DUPLICATE_ASSEMBLY_NAME = hRESULT_FROM_WIN32 14027
eRROR_SXS_FILE_HASH_MISMATCH = hRESULT_FROM_WIN32 14028
eRROR_SXS_POLICY_PARSE_ERROR = hRESULT_FROM_WIN32 14029
eRROR_SXS_XML_E_MISSINGQUOTE = hRESULT_FROM_WIN32 14030
eRROR_SXS_XML_E_COMMENTSYNTAX = hRESULT_FROM_WIN32 14031
eRROR_SXS_XML_E_BADSTARTNAMECHAR = hRESULT_FROM_WIN32 14032
eRROR_SXS_XML_E_BADNAMECHAR = hRESULT_FROM_WIN32 14033
eRROR_SXS_XML_E_BADCHARINSTRING = hRESULT_FROM_WIN32 14034
eRROR_SXS_XML_E_XMLDECLSYNTAX = hRESULT_FROM_WIN32 14035
eRROR_SXS_XML_E_BADCHARDATA = hRESULT_FROM_WIN32 14036
eRROR_SXS_XML_E_MISSINGWHITESPACE = hRESULT_FROM_WIN32 14037
eRROR_SXS_XML_E_EXPECTINGTAGEND = hRESULT_FROM_WIN32 14038
eRROR_SXS_XML_E_MISSINGSEMICOLON = hRESULT_FROM_WIN32 14039
eRROR_SXS_XML_E_UNBALANCEDPAREN = hRESULT_FROM_WIN32 14040
eRROR_SXS_XML_E_INTERNALERROR = hRESULT_FROM_WIN32 14041
eRROR_SXS_XML_E_UNEXPECTED_WHITESPACE = hRESULT_FROM_WIN32 14042
eRROR_SXS_XML_E_INCOMPLETE_ENCODING = hRESULT_FROM_WIN32 14043
eRROR_SXS_XML_E_MISSING_PAREN = hRESULT_FROM_WIN32 14044
eRROR_SXS_XML_E_EXPECTINGCLOSEQUOTE = hRESULT_FROM_WIN32 14045
eRROR_SXS_XML_E_MULTIPLE_COLONS = hRESULT_FROM_WIN32 14046
eRROR_SXS_XML_E_INVALID_DECIMAL = hRESULT_FROM_WIN32 14047
eRROR_SXS_XML_E_INVALID_HEXIDECIMAL = hRESULT_FROM_WIN32 14048
eRROR_SXS_XML_E_INVALID_UNICODE = hRESULT_FROM_WIN32 14049
eRROR_SXS_XML_E_WHITESPACEORQUESTIONMARK = hRESULT_FROM_WIN32 14050
eRROR_SXS_XML_E_UNEXPECTEDENDTAG = hRESULT_FROM_WIN32 14051
eRROR_SXS_XML_E_UNCLOSEDTAG = hRESULT_FROM_WIN32 14052
eRROR_SXS_XML_E_DUPLICATEATTRIBUTE = hRESULT_FROM_WIN32 14053
eRROR_SXS_XML_E_MULTIPLEROOTS = hRESULT_FROM_WIN32 14054
eRROR_SXS_XML_E_INVALIDATROOTLEVEL = hRESULT_FROM_WIN32 14055
eRROR_SXS_XML_E_BADXMLDECL = hRESULT_FROM_WIN32 14056
eRROR_SXS_XML_E_MISSINGROOT = hRESULT_FROM_WIN32 14057
eRROR_SXS_XML_E_UNEXPECTEDEOF = hRESULT_FROM_WIN32 14058
eRROR_SXS_XML_E_BADPEREFINSUBSET = hRESULT_FROM_WIN32 14059
eRROR_SXS_XML_E_UNCLOSEDSTARTTAG = hRESULT_FROM_WIN32 14060
eRROR_SXS_XML_E_UNCLOSEDENDTAG = hRESULT_FROM_WIN32 14061
eRROR_SXS_XML_E_UNCLOSEDSTRING = hRESULT_FROM_WIN32 14062
eRROR_SXS_XML_E_UNCLOSEDCOMMENT = hRESULT_FROM_WIN32 14063
eRROR_SXS_XML_E_UNCLOSEDDECL = hRESULT_FROM_WIN32 14064
eRROR_SXS_XML_E_UNCLOSEDCDATA = hRESULT_FROM_WIN32 14065
eRROR_SXS_XML_E_RESERVEDNAMESPACE = hRESULT_FROM_WIN32 14066
eRROR_SXS_XML_E_INVALIDENCODING = hRESULT_FROM_WIN32 14067
eRROR_SXS_XML_E_INVALIDSWITCH = hRESULT_FROM_WIN32 14068
eRROR_SXS_XML_E_BADXMLCASE = hRESULT_FROM_WIN32 14069
eRROR_SXS_XML_E_INVALID_STANDALONE = hRESULT_FROM_WIN32 14070
eRROR_SXS_XML_E_UNEXPECTED_STANDALONE = hRESULT_FROM_WIN32 14071
eRROR_SXS_XML_E_INVALID_VERSION = hRESULT_FROM_WIN32 14072
eRROR_SXS_XML_E_MISSINGEQUALS = hRESULT_FROM_WIN32 14073
eRROR_SXS_PROTECTION_RECOVERY_FAILED = hRESULT_FROM_WIN32 14074
eRROR_SXS_PROTECTION_PUBLIC_KEY_TOO_SHORT = hRESULT_FROM_WIN32 14075
eRROR_SXS_PROTECTION_CATALOG_NOT_VALID = hRESULT_FROM_WIN32 14076
eRROR_SXS_UNTRANSLATABLE_HRESULT = hRESULT_FROM_WIN32 14077
eRROR_SXS_PROTECTION_CATALOG_FILE_MISSING = hRESULT_FROM_WIN32 14078
eRROR_SXS_MISSING_ASSEMBLY_IDENTITY_ATTRIBUTE = hRESULT_FROM_WIN32 14079
eRROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE_NAME = hRESULT_FROM_WIN32 14080
