module Win32.IO.Constants where

import Win32.IO.Types
import Win32.IO.Foreign

import Data.Bits
import Foreign.Ptr

-- File handles

nullHFILE            = HFILE nullPtr
iNVALID_HANDLE_VALUE = castToHFILE (-1)

-- Standard file handles

sTD_INPUT_HANDLE  = STDHANDLE (-10)
sTD_OUTPUT_HANDLE = STDHANDLE (-11)
sTD_ERROR_HANDLE  = STDHANDLE (-12)

-- File creation flags

-- TODO: These are more general (not only files, I guess).
fILE_DELETE                   = FILEDESIREDACCESS 0x00010000
fILE_READ_CONTROL             = FILEDESIREDACCESS 0x00020000
fILE_WRITE_DAC                = FILEDESIREDACCESS 0x00040000
fILE_WRITE_OWNER              = FILEDESIREDACCESS 0x00080000
fILE_SYNCHRONIZE              = FILEDESIREDACCESS 0x00100000

fILE_STANDARD_RIGHTS_REQUIRED = FILEDESIREDACCESS 0x000F0000

fILE_STANDARD_RIGHTS_ALL      = FILEDESIREDACCESS 0x001F0000

fILE_SPECIFIC_RIGHTS_ALL      = FILEDESIREDACCESS 0x0000FFFF
-- TODO: until here

fILE_READ_DATA                = FILEDESIREDACCESS 0x00000001    -- file & pipe
fILE_LIST_DIRECTORY           = FILEDESIREDACCESS 0x00000001    -- directory

fILE_WRITE_DATA               = FILEDESIREDACCESS 0x00000002    -- file & pipe
fILE_ADD_FILE                 = FILEDESIREDACCESS 0x00000002    -- directory

fILE_APPEND_DATA              = FILEDESIREDACCESS 0x00000004    -- file
fILE_ADD_SUBDIRECTORY         = FILEDESIREDACCESS 0x00000004    -- directory
fILE_CREATE_PIPE_INSTANCE     = FILEDESIREDACCESS 0x00000004    -- named pipe


fILE_READ_EA                  = FILEDESIREDACCESS 0x00000008    -- file & directory

fILE_WRITE_EA                 = FILEDESIREDACCESS 0x00000010    -- file & directory

fILE_EXECUTE                  = FILEDESIREDACCESS 0x00000020    -- file
fILE_TRAVERSE                 = FILEDESIREDACCESS 0x00000020    -- directory

fILE_DELETE_CHILD             = FILEDESIREDACCESS 0x00000040    -- directory

fILE_READ_ATTRIBUTES          = FILEDESIREDACCESS 0x00000080    -- all

fILE_WRITE_ATTRIBUTES         = FILEDESIREDACCESS 0x00000100    -- all

gENERIC_READ                  = FILEDESIREDACCESS 0x80000000
gENERIC_WRITE                 = FILEDESIREDACCESS 0x40000000
gENERIC_EXECUTE               = FILEDESIREDACCESS 0x20000000
gENERIC_ALL                   = FILEDESIREDACCESS 0x10000000

fILE_STANDARD_RIGHTS_READ     = fILE_READ_CONTROL
fILE_STANDARD_RIGHTS_WRITE    = fILE_READ_CONTROL
fILE_STANDARD_RIGHTS_EXECUTE  = fILE_READ_CONTROL

fILE_ALL_ACCESS      = fILE_STANDARD_RIGHTS_REQUIRED .|. fILE_SYNCHRONIZE .|. FILEDESIREDACCESS 0x1FF
fILE_GENERIC_READ    = fILE_STANDARD_RIGHTS_READ     .|. fILE_SYNCHRONIZE .|. fILE_READ_DATA  .|. fILE_READ_ATTRIBUTES  .|. fILE_READ_EA
fILE_GENERIC_WRITE   = fILE_STANDARD_RIGHTS_WRITE    .|. fILE_SYNCHRONIZE .|. fILE_WRITE_DATA .|. fILE_WRITE_ATTRIBUTES .|. fILE_WRITE_EA .|. fILE_APPEND_DATA
fILE_GENERIC_EXECUTE = fILE_STANDARD_RIGHTS_EXECUTE  .|. fILE_SYNCHRONIZE .|.                     fILE_READ_ATTRIBUTES  .|. fILE_EXECUTE

fILE_SHARE_READ   = FILESHAREMODE 0x00000001
fILE_SHARE_WRITE  = FILESHAREMODE 0x00000002
fILE_SHARE_DELETE = FILESHAREMODE 0x00000004

cREATE_NEW        = FILECREATIONDISPOSITION 1
cREATE_ALWAYS     = FILECREATIONDISPOSITION 2
oPEN_EXISTING     = FILECREATIONDISPOSITION 3
oPEN_ALWAYS       = FILECREATIONDISPOSITION 4
tRUNCATE_EXISTING = FILECREATIONDISPOSITION 5

fILE_ATTRIBUTE_READONLY            = FILEFLAGSANDATTRIBUTES 0x00000001
fILE_ATTRIBUTE_HIDDEN              = FILEFLAGSANDATTRIBUTES 0x00000002
fILE_ATTRIBUTE_SYSTEM              = FILEFLAGSANDATTRIBUTES 0x00000004
fILE_ATTRIBUTE_DIRECTORY           = FILEFLAGSANDATTRIBUTES 0x00000010
fILE_ATTRIBUTE_ARCHIVE             = FILEFLAGSANDATTRIBUTES 0x00000020
fILE_ATTRIBUTE_DEVICE              = FILEFLAGSANDATTRIBUTES 0x00000040
fILE_ATTRIBUTE_NORMAL              = FILEFLAGSANDATTRIBUTES 0x00000080
fILE_ATTRIBUTE_TEMPORARY           = FILEFLAGSANDATTRIBUTES 0x00000100
fILE_ATTRIBUTE_SPARSE_FILE         = FILEFLAGSANDATTRIBUTES 0x00000200
fILE_ATTRIBUTE_REPARSE_POINT       = FILEFLAGSANDATTRIBUTES 0x00000400
fILE_ATTRIBUTE_COMPRESSED          = FILEFLAGSANDATTRIBUTES 0x00000800
fILE_ATTRIBUTE_OFFLINE             = FILEFLAGSANDATTRIBUTES 0x00001000
fILE_ATTRIBUTE_NOT_CONTENT_INDEXED = FILEFLAGSANDATTRIBUTES 0x00002000
fILE_ATTRIBUTE_ENCRYPTED           = FILEFLAGSANDATTRIBUTES 0x00004000

fILE_FLAG_WRITE_THROUGH            = FILEFLAGSANDATTRIBUTES 0x80000000
fILE_FLAG_OVERLAPPED               = FILEFLAGSANDATTRIBUTES 0x40000000
fILE_FLAG_NO_BUFFERING             = FILEFLAGSANDATTRIBUTES 0x20000000
fILE_FLAG_RANDOM_ACCESS            = FILEFLAGSANDATTRIBUTES 0x10000000
fILE_FLAG_SEQUENTIAL_SCAN          = FILEFLAGSANDATTRIBUTES 0x08000000
fILE_FLAG_DELETE_ON_CLOSE          = FILEFLAGSANDATTRIBUTES 0x04000000
fILE_FLAG_BACKUP_SEMANTICS         = FILEFLAGSANDATTRIBUTES 0x02000000
fILE_FLAG_POSIX_SEMANTICS          = FILEFLAGSANDATTRIBUTES 0x01000000
fILE_FLAG_OPEN_REPARSE_POINT       = FILEFLAGSANDATTRIBUTES 0x00200000
fILE_FLAG_OPEN_NO_RECALL           = FILEFLAGSANDATTRIBUTES 0x00100000
fILE_FLAG_FIRST_PIPE_INSTANCE      = FILEFLAGSANDATTRIBUTES 0x00080000
