module Win32.IO.Types where

import Win32.System.Types

import Data.Bits
import Data.Typeable
import Foreign.Ptr
import Foreign.Storable

-- File handles

newtype HFILE = HFILE PVOID deriving (Eq, Show, Storable)

unHFILE (HFILE p) = p


castToHFILE   :: Integral l => l -> HFILE
castFromHFILE :: Integral l => HFILE -> l


castToHFILE l = HFILE (castToPtr l)
castFromHFILE (HFILE p) = castFromPtr p

-- Standard file handles

newtype STDHANDLE = STDHANDLE DWORD deriving (Eq, Ord, Show, Enum, Num, Real, Integral, Bits, Storable, Typeable)

unSTDHANDLE (STDHANDLE v) = v

-- File creation flags

newtype FILEDESIREDACCESS       = FILEDESIREDACCESS       DWORD deriving (Eq, Ord, Show, Enum, Num, Real, Integral, Bits, Storable, Typeable)
newtype FILESHAREMODE           = FILESHAREMODE           DWORD deriving (Eq, Ord, Show, Enum, Num, Real, Integral, Bits, Storable, Typeable)
newtype FILECREATIONDISPOSITION = FILECREATIONDISPOSITION DWORD deriving (Eq, Ord, Show, Enum, Num, Real, Integral, Bits, Storable, Typeable)
newtype FILEFLAGSANDATTRIBUTES  = FILEFLAGSANDATTRIBUTES  DWORD deriving (Eq, Ord, Show, Enum, Num, Real, Integral, Bits, Storable, Typeable)

unFILEDESIREDACCESS       (FILEDESIREDACCESS       v) = v
unFILESHAREMODE           (FILESHAREMODE           v) = v
unFILECREATIONDISPOSITION (FILECREATIONDISPOSITION v) = v
unFILEFLAGSANDATTRIBUTES  (FILEFLAGSANDATTRIBUTES  v) = v

-- Overlapped structure

data OVERLAPPED = OVERLAPPED {
    getOVLInternal      :: QWORD,
    getOVLOffset        :: QWORD,
    getOVLhEvent        :: HEVENT}

type POVERLAPPED = Ptr OVERLAPPED

instance Storable OVERLAPPED where
    sizeOf    m = 20
    alignment m =  8
    peek p      = do internal <- peekByteOff p  0
                     offset   <- peekByteOff p  8
                     hEvent   <- peekByteOff p 16
                     return $ OVERLAPPED internal offset hEvent
    poke p    m = do pokeByteOff p  0 $ getOVLInternal m
                     pokeByteOff p  8 $ getOVLOffset   m
                     pokeByteOff p 16 $ getOVLhEvent   m

-- File IO

class ReadableIO h where
    readFile :: h -> PVOID -> DWORD -> POVERLAPPED -> Maybe DWORD

class WritableIO h where
    writeFile :: h -> PVOID -> DWORD -> POVERLAPPED -> Maybe DWORD
