module Win32.System.Constants where

import Win32.System.Types
import Win32.System.Foreign

import Data.Bits
import Foreign.Ptr



-- Primitive types

nFR_ANSI    = 1 :: LRESULT
nFR_UNICODE = 2 :: LRESULT

-- Result types

s_OK    = HRESULT 0
s_FALSE = HRESULT 1

hRESULT_SEVERITY_SUCCESS = HRESULT 0x00000000
hRESULT_SEVERITY_ERROR   = HRESULT 0x80000000

hRESULT_FACILITY_NULL           = HRESULT 0x00000000
hRESULT_FACILITY_RPC            = HRESULT 0x00010000
hRESULT_FACILITY_DISPATCH       = HRESULT 0x00020000
hRESULT_FACILITY_STORAGE        = HRESULT 0x00030000
hRESULT_FACILITY_ITF            = HRESULT 0x00040000
hRESULT_FACILITY_WIN32          = HRESULT 0x00070000
hRESULT_FACILITY_WINDOWS        = HRESULT 0x00080000
hRESULT_FACILITY_SSPI           = HRESULT 0x00090000
hRESULT_FACILITY_SECURITY       = HRESULT 0x00090000
hRESULT_FACILITY_CONTROL        = HRESULT 0x000A0000
hRESULT_FACILITY_CERT           = HRESULT 0x000B0000
hRESULT_FACILITY_INTERNET       = HRESULT 0x000C0000
hRESULT_FACILITY_MEDIASERVER    = HRESULT 0x000D0000
hRESULT_FACILITY_MSMQ           = HRESULT 0x000E0000
hRESULT_FACILITY_SETUPAPI       = HRESULT 0x000F0000
hRESULT_FACILITY_SCARD          = HRESULT 0x00100000
hRESULT_FACILITY_COMPLUS        = HRESULT 0x00110000
hRESULT_FACILITY_AAF            = HRESULT 0x00120000
hRESULT_FACILITY_URT            = HRESULT 0x00130000
hRESULT_FACILITY_ACS            = HRESULT 0x00140000
hRESULT_FACILITY_DPLAY          = HRESULT 0x00150000
hRESULT_FACILITY_UMI            = HRESULT 0x00160000
hRESULT_FACILITY_SXS            = HRESULT 0x00170000
hRESULT_FACILITY_WINDOWS_CE     = HRESULT 0x00180000
hRESULT_FACILITY_HTTP           = HRESULT 0x00190000
hRESULT_FACILITY_BACKGROUNDCOPY = HRESULT 0x00200000
hRESULT_FACILITY_CONFIGURATION  = HRESULT 0x00210000

hr_SUCCEEDED (HRESULT r) = (r .&. 0x80000000) == 0
hr_FAILED    (HRESULT r) = (r .&. 0x80000000) /= 0

hRESULT_CODE     dw = dw .&. 0x0000FFFF
hRESULT_FACILITY dw = dw .&. 0x7FFF0000
hRESULT_SEVERITY dw = dw .&. 0x80000000

hRESULT_FROM_WIN32 x =
    let dw = fromIntegral x :: DWORD in
    if dw >= 0x80000000 then
            HRESULT dw
        else if dw == 0 then
            s_OK
        else
            HRESULT (dw .&. 0x0000FFFF) .|. hRESULT_FACILITY_WIN32 .|. hRESULT_SEVERITY_ERROR

wIN32_FROM_HRESULT hr =
    if hr_SUCCEEDED hr then
            0
        else if hr >= 0xFFFF8000 then
            unHRESULT hr
        else if hRESULT_FACILITY hr == hRESULT_FACILITY_WIN32 then
            unHRESULT $ hRESULT_CODE hr
        else
            13 -- ERROR_INVALID_DATA - The data is invalid.

-- Time

iNFINITE = MILLISECONDS 0xFFFFFFFF

-- Object handles

nullHINSTANCE = HINSTANCE nullPtr
nullHICON     = HICON     nullPtr
nullHCURSOR   = HCURSOR   nullPtr
nullHMENU     = HMENU     nullPtr

-- Cursors

iDC_ARROW        = IDCURSOR 32512
iDC_IBEAM        = IDCURSOR 32513
iDC_WAIT         = IDCURSOR 32514
iDC_CROSS        = IDCURSOR 32515
iDC_UPARROW      = IDCURSOR 32516
iDC_SIZE         = IDCURSOR 32640  -- OBSOLETE: use iDC_SIZEALL
iDC_ICON         = IDCURSOR 32641  -- OBSOLETE: use iDC_ARROW
iDC_SIZENWSE     = IDCURSOR 32642
iDC_SIZENESW     = IDCURSOR 32643
iDC_SIZEWE       = IDCURSOR 32644
iDC_SIZENS       = IDCURSOR 32645
iDC_SIZEALL      = IDCURSOR 32646
iDC_NO           = IDCURSOR 32648
iDC_HAND         = IDCURSOR 32649
iDC_APPSTARTING  = IDCURSOR 32650
iDC_HELP         = IDCURSOR 32651

-- Message boxes

mB_OK                        = MBTYPE 0x00000000
mB_OKCANCEL                  = MBTYPE 0x00000001
mB_ABORTRETRYIGNORE          = MBTYPE 0x00000002
mB_YESNOCANCEL               = MBTYPE 0x00000003
mB_YESNO                     = MBTYPE 0x00000004
mB_RETRYCANCEL               = MBTYPE 0x00000005
mB_CANCELTRYCONTINUE         = MBTYPE 0x00000006

mB_ICONHAND                  = MBTYPE 0x00000010
mB_ICONQUESTION              = MBTYPE 0x00000020
mB_ICONEXCLAMATION           = MBTYPE 0x00000030
mB_ICONASTERISK              = MBTYPE 0x00000040

mB_USERICON                  = MBTYPE 0x00000080
mB_ICONWARNING               = mB_ICONEXCLAMATION
mB_ICONERROR                 = mB_ICONHAND

mB_ICONINFORMATION           = mB_ICONASTERISK
mB_ICONSTOP                  = mB_ICONHAND

mB_DEFBUTTON1                = MBTYPE 0x00000000
mB_DEFBUTTON2                = MBTYPE 0x00000100
mB_DEFBUTTON3                = MBTYPE 0x00000200
mB_DEFBUTTON4                = MBTYPE 0x00000300

mB_APPLMODAL                 = MBTYPE 0x00000000
mB_SYSTEMMODAL               = MBTYPE 0x00001000
mB_TASKMODAL                 = MBTYPE 0x00002000
mB_HELP                      = MBTYPE 0x00004000 -- Help Button

mB_NOFOCUS                   = MBTYPE 0x00008000
mB_SETFOREGROUND             = MBTYPE 0x00010000
mB_DEFAULT_DESKTOP_ONLY      = MBTYPE 0x00020000

mB_TOPMOST                   = MBTYPE 0x00040000
mB_RIGHT                     = MBTYPE 0x00080000
mB_RTLREADING                = MBTYPE 0x00100000

mB_SERVICE_NOTIFICATION      = MBTYPE 0x00200000

mB_TYPEMASK                  = MBTYPE 0x0000000F
mB_ICONMASK                  = MBTYPE 0x000000F0
mB_DEFMASK                   = MBTYPE 0x00000F00
mB_MODEMASK                  = MBTYPE 0x00003000
mB_MISCMASK                  = MBTYPE 0x0000C000

-- I/O handles

nullHANDLE    = HANDLE nullPtr
invalidHANDLE = castToHANDLE (-1)

-- Strings

nullPSTR = nullPtr :: PSTR
