module Win32.System.Types where

import Data.Bits
import Data.Int
import Data.Word
import Data.Typeable
import Foreign.C.String
import Foreign.C.Types
import Foreign.Ptr
import Foreign.Storable


-- Primitive types

type BOOL      = Bool

type CHAR      = Char

type INT       = Int32
type UINT      = Word32
type LONG      = Int32
type ULONG     = Word32
type LONGLONG  = Int64
type ULONGLONG = Word64

type INT_PTR   = Int32
type UINT_PTR  = Word32
type LONG_PTR  = Int32
type ULONG_PTR = Word32

type BYTE      = Word8
type WORD      = Word16
type DWORD     = Word32
type QWORD     = Word64

type ATOM      = WORD
type LRESULT   = LONG

-- Pointer types

type PBOOL      = Ptr BOOL

type PCHAR      = Ptr CWchar

type PINT       = Ptr INT
type PUINT      = Ptr UINT
type PLONG      = Ptr LONG
type PULONG     = Ptr ULONG
type PLONGLONG  = Ptr LONGLONG
type PULONGLONG = Ptr ULONGLONG

type PINT_PTR   = Ptr INT_PTR
type PUINT_PTR  = Ptr UINT_PTR
type PLONG_PTR  = Ptr LONG_PTR
type PULONG_PTR = Ptr ULONG_PTR

type PBYTE      = Ptr BYTE
type PWORD      = Ptr WORD
type PDWORD     = Ptr DWORD

type PATOM      = Ptr ATOM
type PLRESULT   = Ptr LRESULT

type PVOID = Ptr ()

-- Enumeration types

newtype HRESULT      = HRESULT      DWORD deriving (Eq, Ord, Show, Enum, Num, Real, Integral, Bits, Storable, Typeable)
newtype MILLISECONDS = MILLISECONDS DWORD deriving (Eq, Ord, Show, Enum, Num, Real, Integral, Bits, Storable, Typeable)
newtype MBTYPE       = MBTYPE       UINT  deriving (Eq, Ord, Show, Enum, Num, Real, Integral, Bits, Storable, Typeable)
newtype IDCURSOR     = IDCURSOR     DWORD deriving (Eq, Ord, Show, Enum, Num, Real, Integral, Bits, Storable, Typeable)

unHRESULT      (HRESULT      v) = v
unMILLISECONDS (MILLISECONDS v) = v
unMBTYPE       (MBTYPE       v) = v
unIDCURSOR     (IDCURSOR     v) = v

-- Casting support (sigh)

class ParentCast child base where
    upCast :: Ptr child -> Ptr base
    upCast = castPtr

type StructField s t = (Ptr s, t, Int)

castPtrOffset :: Int -> Ptr a -> Ptr b

getP :: (ParentCast a p, Storable c) => StructField p c -> Ptr a -> IO c
setP :: (ParentCast a p, Storable c) => StructField p c -> Ptr a -> c -> IO ()

castToPtr   :: Integral l => l -> Ptr a
castFromPtr :: Integral l => Ptr a -> l

castToFuncPtr   :: Integral l => l -> FunPtr a
castFromFuncPtr :: Integral l => FunPtr a -> l


instance ParentCast p p where upCast = id

castPtrOffset offs = (`plusPtr` offs)

getP (ptr, typ, offs) p   = if True then peekByteOff (if True then upCast p else ptr) offs else return typ
setP (ptr, typ, offs) p v = pokeByteOff (if True then upCast p else ptr) offs (if True then v else typ)

castToPtr   l = nullPtr `plusPtr` fromIntegral l
castFromPtr p = fromIntegral $ p `minusPtr` nullPtr

castToFuncPtr   = castPtrToFunPtr . castToPtr
castFromFuncPtr = castFromPtr . castFunPtrToPtr

-- Object handles

newtype HINSTANCE = HINSTANCE PVOID deriving (Eq, Show, Storable)
newtype HICON     = HICON     PVOID deriving (Eq, Show, Storable)
newtype HCURSOR   = HCURSOR   PVOID deriving (Eq, Show, Storable)
newtype HMENU     = HMENU     PVOID deriving (Eq, Show, Storable)

unHINSTANCE (HINSTANCE p) = p
unHICON     (HICON     p) = p
unHCURSOR   (HCURSOR   p) = p
unHMENU     (HMENU     p) = p


castToHINSTANCE   :: Integral l => l -> HINSTANCE
castToHICON       :: Integral l => l -> HICON
castToHCURSOR     :: Integral l => l -> HCURSOR
castToHMENU       :: Integral l => l -> HMENU

castFromHINSTANCE :: Integral l => HINSTANCE -> l
castFromHICON     :: Integral l => HICON     -> l
castFromHCURSOR   :: Integral l => HCURSOR   -> l
castFromHMENU     :: Integral l => HMENU     -> l


castToHINSTANCE = HINSTANCE . castToPtr
castToHICON     = HICON     . castToPtr
castToHCURSOR   = HCURSOR   . castToPtr
castToHMENU     = HMENU     . castToPtr

castFromHINSTANCE  = castFromPtr . unHINSTANCE
castFromHICON      = castFromPtr . unHICON
castFromHCURSOR    = castFromPtr . unHCURSOR
castFromHMENU      = castFromPtr . unHMENU

-- Synchronization

newtype HEVENT = HEVENT PVOID deriving (Eq, Show, Storable)

unHEVENT (HEVENT p) = p


castToHEVENT   :: Integral l => l -> HEVENT
castFromHEVENT :: Integral l => HEVENT -> l


castToHEVENT l = HEVENT (castToPtr l)
castFromHEVENT (HEVENT p) = castFromPtr p

-- I/O handles

newtype HANDLE = HANDLE PVOID deriving (Eq, Show, Storable)

unHANDLE (HANDLE p) = p


castToHANDLE   :: Integral l => l -> HANDLE
castFromHANDLE :: Integral l => HANDLE -> l


castToHANDLE l = HANDLE (castToPtr l)
castFromHANDLE (HANDLE p) = castFromPtr p

-- Strings

type PSTR = CWString
