module Win32.Window.Constants where

import Win32.Window.Types

import Win32.System.Types

import Data.Bits
import Foreign.Storable




-- Class styles

cS_DEFAULT          = CSTYLE 0x00000000
cS_VREDRAW          = CSTYLE 0x00000001
cS_HREDRAW          = CSTYLE 0x00000002
cS_DBLCLKS          = CSTYLE 0x00000008
cS_OWNDC            = CSTYLE 0x00000020
cS_CLASSDC          = CSTYLE 0x00000040
cS_PARENTDC         = CSTYLE 0x00000080
cS_NOCLOSE          = CSTYLE 0x00000200
cS_SAVEBITS         = CSTYLE 0x00000800
cS_BYTEALIGNCLIENT  = CSTYLE 0x00001000
cS_BYTEALIGNWINDOW  = CSTYLE 0x00002000
cS_GLOBALCLASS      = CSTYLE 0x00004000

cS_IME              = CSTYLE 0x00010000
cS_DROPSHADOW       = CSTYLE 0x00020000

-- Window styles

wS_OVERLAPPED       = WSTYLE 0x0000000000000000
wS_POPUP            = WSTYLE 0x0000000080000000
wS_CHILD            = WSTYLE 0x0000000040000000
wS_MINIMIZE         = WSTYLE 0x0000000020000000
wS_VISIBLE          = WSTYLE 0x0000000010000000
wS_DISABLED         = WSTYLE 0x0000000008000000
wS_CLIPSIBLINGS     = WSTYLE 0x0000000004000000
wS_CLIPCHILDREN     = WSTYLE 0x0000000002000000
wS_MAXIMIZE         = WSTYLE 0x0000000001000000
wS_BORDER           = WSTYLE 0x0000000000800000
wS_DLGFRAME         = WSTYLE 0x0000000000400000
wS_VSCROLL          = WSTYLE 0x0000000000200000
wS_HSCROLL          = WSTYLE 0x0000000000100000
wS_SYSMENU          = WSTYLE 0x0000000000080000
wS_THICKFRAME       = WSTYLE 0x0000000000040000
wS_GROUP            = WSTYLE 0x0000000000020000
wS_TABSTOP          = WSTYLE 0x0000000000010000

wS_MINIMIZEBOX      = WSTYLE 0x0000000000020000
wS_MAXIMIZEBOX      = WSTYLE 0x0000000000010000

wS_TILED            = wS_OVERLAPPED
wS_ICONIC           = wS_MINIMIZE
wS_SIZEBOX          = wS_THICKFRAME
wS_TILEDWINDOW      = wS_OVERLAPPEDWINDOW

wS_CAPTION          = wS_BORDER .|. wS_DLGFRAME

wS_OVERLAPPEDWINDOW = wS_OVERLAPPED .|. wS_CAPTION .|. wS_SYSMENU .|. wS_THICKFRAME .|. wS_MINIMIZEBOX .|. wS_MAXIMIZEBOX

wS_POPUPWINDOW      = wS_POPUP .|. wS_BORDER .|. wS_SYSMENU

wS_CHILDWINDOW      = wS_CHILD

wS_EX_DLGMODALFRAME     = WSTYLE 0x0000000100000000
wS_EX_NOPARENTNOTIFY    = WSTYLE 0x0000000400000000
wS_EX_TOPMOST           = WSTYLE 0x0000000800000000
wS_EX_ACCEPTFILES       = WSTYLE 0x0000001000000000
wS_EX_TRANSPARENT       = WSTYLE 0x0000002000000000
wS_EX_MDICHILD          = WSTYLE 0x0000004000000000
wS_EX_TOOLWINDOW        = WSTYLE 0x0000008000000000
wS_EX_WINDOWEDGE        = WSTYLE 0x0000010000000000
wS_EX_CLIENTEDGE        = WSTYLE 0x0000020000000000
wS_EX_CONTEXTHELP       = WSTYLE 0x0000040000000000

wS_EX_RIGHT             = WSTYLE 0x0000100000000000
wS_EX_LEFT              = WSTYLE 0x0000000000000000
wS_EX_RTLREADING        = WSTYLE 0x0000200000000000
wS_EX_LTRREADING        = WSTYLE 0x0000000000000000
wS_EX_LEFTSCROLLBAR     = WSTYLE 0x0000400000000000
wS_EX_RIGHTSCROLLBAR    = WSTYLE 0x0000000000000000

wS_EX_CONTROLPARENT     = WSTYLE 0x0001000000000000
wS_EX_STATICEDGE        = WSTYLE 0x0002000000000000
wS_EX_APPWINDOW         = WSTYLE 0x0004000000000000

wS_EX_OVERLAPPEDWINDOW  = wS_EX_WINDOWEDGE .|. wS_EX_CLIENTEDGE
wS_EX_PALETTEWINDOW     = wS_EX_WINDOWEDGE .|. wS_EX_TOOLWINDOW .|. wS_EX_TOPMOST

wS_EX_LAYERED           = WSTYLE 0x0008000000000000

wS_EX_NOINHERITLAYOUT   = WSTYLE 0x0010000000000000 -- Disable inheritence of mirroring by children
wS_EX_LAYOUTRTL         = WSTYLE 0x0040000000000000 -- Right to left mirroring

wS_EX_COMPOSITED        = WSTYLE 0x0200000000000000
wS_EX_NOACTIVATE        = WSTYLE 0x0800000000000000

-- Window message enumerations

wA_INACTIVE     = WindowActivation 0
wA_ACTIVE       = WindowActivation 1
wA_CLICKACTIVE  = WindowActivation 2

eN_SETFOCUS     = CommandID 0x0100
eN_KILLFOCUS    = CommandID 0x0200
eN_CHANGE       = CommandID 0x0300
eN_UPDATE       = CommandID 0x0400
eN_ERRSPACE     = CommandID 0x0500
eN_MAXTEXT      = CommandID 0x0501
eN_HSCROLL      = CommandID 0x0601
eN_VSCROLL      = CommandID 0x0602
eN_ALIGN_LTR_EC = CommandID 0x0700
eN_ALIGN_RTL_EC = CommandID 0x0701

-- Window messages

wM_NULL                         = WMSG 0x0000
wM_CREATE                       = WMSG 0x0001
wM_DESTROY                      = WMSG 0x0002
wM_MOVE                         = WMSG 0x0003
wM_SIZE                         = WMSG 0x0005

wM_ACTIVATE                     = WMSG 0x0006

wM_SETFOCUS                     = WMSG 0x0007
wM_KILLFOCUS                    = WMSG 0x0008
wM_ENABLE                       = WMSG 0x000A
wM_SETREDRAW                    = WMSG 0x000B
wM_SETTEXT                      = WMSG 0x000C
wM_GETTEXT                      = WMSG 0x000D
wM_GETTEXTLENGTH                = WMSG 0x000E
wM_PAINT                        = WMSG 0x000F
wM_CLOSE                        = WMSG 0x0010
wM_QUERYENDSESSION              = WMSG 0x0011
wM_QUERYOPEN                    = WMSG 0x0013
wM_ENDSESSION                   = WMSG 0x0016
wM_QUIT                         = WMSG 0x0012
wM_ERASEBKGND                   = WMSG 0x0014
wM_SYSCOLORCHANGE               = WMSG 0x0015
wM_SHOWWINDOW                   = WMSG 0x0018
wM_WININICHANGE                 = WMSG 0x001A
wM_SETTINGCHANGE                = wM_WININICHANGE

wM_DEVMODECHANGE                = WMSG 0x001B
wM_ACTIVATEAPP                  = WMSG 0x001C
wM_FONTCHANGE                   = WMSG 0x001D
wM_TIMECHANGE                   = WMSG 0x001E
wM_CANCELMODE                   = WMSG 0x001F
wM_SETCURSOR                    = WMSG 0x0020
wM_MOUSEACTIVATE                = WMSG 0x0021
wM_CHILDACTIVATE                = WMSG 0x0022
wM_QUEUESYNC                    = WMSG 0x0023

wM_GETMINMAXINFO                = WMSG 0x0024

wM_PAINTICON                    = WMSG 0x0026
wM_ICONERASEBKGND               = WMSG 0x0027
wM_NEXTDLGCTL                   = WMSG 0x0028
wM_SPOOLERSTATUS                = WMSG 0x002A
wM_DRAWITEM                     = WMSG 0x002B
wM_MEASUREITEM                  = WMSG 0x002C
wM_DELETEITEM                   = WMSG 0x002D
wM_VKEYTOITEM                   = WMSG 0x002E
wM_CHARTOITEM                   = WMSG 0x002F
wM_SETFONT                      = WMSG 0x0030
wM_GETFONT                      = WMSG 0x0031
wM_SETHOTKEY                    = WMSG 0x0032
wM_GETHOTKEY                    = WMSG 0x0033
wM_QUERYDRAGICON                = WMSG 0x0037
wM_COMPAREITEM                  = WMSG 0x0039
wM_GETOBJECT                    = WMSG 0x003D
wM_COMPACTING                   = WMSG 0x0041
wM_WINDOWPOSCHANGING            = WMSG 0x0046
wM_WINDOWPOSCHANGED             = WMSG 0x0047

wM_POWER                        = WMSG 0x0048

wM_COPYDATA                     = WMSG 0x004A
wM_CANCELJOURNAL                = WMSG 0x004B

wM_NOTIFY                       = WMSG 0x004E
wM_INPUTLANGCHANGEREQUEST       = WMSG 0x0050
wM_INPUTLANGCHANGE              = WMSG 0x0051
wM_TCARD                        = WMSG 0x0052
wM_HELP                         = WMSG 0x0053
wM_USERCHANGED                  = WMSG 0x0054
wM_NOTIFYFORMAT                 = WMSG 0x0055

wM_CONTEXTMENU                  = WMSG 0x007B
wM_STYLECHANGING                = WMSG 0x007C
wM_STYLECHANGED                 = WMSG 0x007D
wM_DISPLAYCHANGE                = WMSG 0x007E
wM_GETICON                      = WMSG 0x007F
wM_SETICON                      = WMSG 0x0080

wM_NCCREATE                     = WMSG 0x0081
wM_NCDESTROY                    = WMSG 0x0082
wM_NCCALCSIZE                   = WMSG 0x0083
wM_NCHITTEST                    = WMSG 0x0084
wM_NCPAINT                      = WMSG 0x0085
wM_NCACTIVATE                   = WMSG 0x0086
wM_GETDLGCODE                   = WMSG 0x0087
wM_SYNCPAINT                    = WMSG 0x0088
wM_NCMOUSEMOVE                  = WMSG 0x00A0
wM_NCLBUTTONDOWN                = WMSG 0x00A1
wM_NCLBUTTONUP                  = WMSG 0x00A2
wM_NCLBUTTONDBLCLK              = WMSG 0x00A3
wM_NCRBUTTONDOWN                = WMSG 0x00A4
wM_NCRBUTTONUP                  = WMSG 0x00A5
wM_NCRBUTTONDBLCLK              = WMSG 0x00A6
wM_NCMBUTTONDOWN                = WMSG 0x00A7
wM_NCMBUTTONUP                  = WMSG 0x00A8
wM_NCMBUTTONDBLCLK              = WMSG 0x00A9

wM_NCXBUTTONDOWN                = WMSG 0x00AB
wM_NCXBUTTONUP                  = WMSG 0x00AC
wM_NCXBUTTONDBLCLK              = WMSG 0x00AD

wM_INPUT                        = WMSG 0x00FF

wM_KEYFIRST                     = WMSG 0x0100
wM_KEYDOWN                      = WMSG 0x0100
wM_KEYUP                        = WMSG 0x0101
wM_CHAR                         = WMSG 0x0102
wM_DEADCHAR                     = WMSG 0x0103
wM_SYSKEYDOWN                   = WMSG 0x0104
wM_SYSKEYUP                     = WMSG 0x0105
wM_SYSCHAR                      = WMSG 0x0106
wM_SYSDEADCHAR                  = WMSG 0x0107
wM_UNICHAR                      = WMSG 0x0109
wM_KEYLAST                      = WMSG 0x0109

wM_IME_STARTCOMPOSITION         = WMSG 0x010D
wM_IME_ENDCOMPOSITION           = WMSG 0x010E
wM_IME_COMPOSITION              = WMSG 0x010F
wM_IME_KEYLAST                  = WMSG 0x010F

wM_INITDIALOG                   = WMSG 0x0110
wM_COMMAND                      = WMSG 0x0111
wM_SYSCOMMAND                   = WMSG 0x0112
wM_TIMER                        = WMSG 0x0113
wM_HSCROLL                      = WMSG 0x0114
wM_VSCROLL                      = WMSG 0x0115
wM_INITMENU                     = WMSG 0x0116
wM_INITMENUPOPUP                = WMSG 0x0117
wM_MENUSELECT                   = WMSG 0x011F
wM_MENUCHAR                     = WMSG 0x0120
wM_ENTERIDLE                    = WMSG 0x0121
wM_MENURBUTTONUP                = WMSG 0x0122
wM_MENUDRAG                     = WMSG 0x0123
wM_MENUGETOBJECT                = WMSG 0x0124
wM_UNINITMENUPOPUP              = WMSG 0x0125
wM_MENUCOMMAND                  = WMSG 0x0126

wM_CHANGEUISTATE                = WMSG 0x0127
wM_UPDATEUISTATE                = WMSG 0x0128
wM_QUERYUISTATE                 = WMSG 0x0129

wM_CTLCOLORMSGBOX               = WMSG 0x0132
wM_CTLCOLOREDIT                 = WMSG 0x0133
wM_CTLCOLORLISTBOX              = WMSG 0x0134
wM_CTLCOLORBTN                  = WMSG 0x0135
wM_CTLCOLORDLG                  = WMSG 0x0136
wM_CTLCOLORSCROLLBAR            = WMSG 0x0137
wM_CTLCOLORSTATIC               = WMSG 0x0138

wM_MOUSEFIRST                   = WMSG 0x0200
wM_MOUSEMOVE                    = WMSG 0x0200
wM_LBUTTONDOWN                  = WMSG 0x0201
wM_LBUTTONUP                    = WMSG 0x0202
wM_LBUTTONDBLCLK                = WMSG 0x0203
wM_RBUTTONDOWN                  = WMSG 0x0204
wM_RBUTTONUP                    = WMSG 0x0205
wM_RBUTTONDBLCLK                = WMSG 0x0206
wM_MBUTTONDOWN                  = WMSG 0x0207
wM_MBUTTONUP                    = WMSG 0x0208
wM_MBUTTONDBLCLK                = WMSG 0x0209
wM_MOUSEWHEEL                   = WMSG 0x020A
wM_XBUTTONDOWN                  = WMSG 0x020B
wM_XBUTTONUP                    = WMSG 0x020C
wM_XBUTTONDBLCLK                = WMSG 0x020D
wM_MOUSELAST                    = WMSG 0x020D

wM_PARENTNOTIFY                 = WMSG 0x0210
wM_ENTERMENULOOP                = WMSG 0x0211
wM_EXITMENULOOP                 = WMSG 0x0212

wM_NEXTMENU                     = WMSG 0x0213
wM_SIZING                       = WMSG 0x0214
wM_CAPTURECHANGED               = WMSG 0x0215
wM_MOVING                       = WMSG 0x0216

wM_POWERBROADCAST               = WMSG 0x0218

wM_DEVICECHANGE                 = WMSG 0x0219

wM_MDICREATE                    = WMSG 0x0220
wM_MDIDESTROY                   = WMSG 0x0221
wM_MDIACTIVATE                  = WMSG 0x0222
wM_MDIRESTORE                   = WMSG 0x0223
wM_MDINEXT                      = WMSG 0x0224
wM_MDIMAXIMIZE                  = WMSG 0x0225
wM_MDITILE                      = WMSG 0x0226
wM_MDICASCADE                   = WMSG 0x0227
wM_MDIICONARRANGE               = WMSG 0x0228
wM_MDIGETACTIVE                 = WMSG 0x0229

wM_MDISETMENU                   = WMSG 0x0230
wM_ENTERSIZEMOVE                = WMSG 0x0231
wM_EXITSIZEMOVE                 = WMSG 0x0232
wM_DROPFILES                    = WMSG 0x0233
wM_MDIREFRESHMENU               = WMSG 0x0234

wM_IME_SETCONTEXT               = WMSG 0x0281
wM_IME_NOTIFY                   = WMSG 0x0282
wM_IME_CONTROL                  = WMSG 0x0283
wM_IME_COMPOSITIONFULL          = WMSG 0x0284
wM_IME_SELECT                   = WMSG 0x0285
wM_IME_CHAR                     = WMSG 0x0286
wM_IME_REQUEST                  = WMSG 0x0288
wM_IME_KEYDOWN                  = WMSG 0x0290
wM_IME_KEYUP                    = WMSG 0x0291

wM_MOUSEHOVER                   = WMSG 0x02A1
wM_MOUSELEAVE                   = WMSG 0x02A3
wM_NCMOUSEHOVER                 = WMSG 0x02A0
wM_NCMOUSELEAVE                 = WMSG 0x02A2

wM_WTSSESSION_CHANGE            = WMSG 0x02B1

wM_TABLET_FIRST                 = WMSG 0x02c0
wM_TABLET_LAST                  = WMSG 0x02df

wM_CUT                          = WMSG 0x0300
wM_COPY                         = WMSG 0x0301
wM_PASTE                        = WMSG 0x0302
wM_CLEAR                        = WMSG 0x0303
wM_UNDO                         = WMSG 0x0304
wM_RENDERFORMAT                 = WMSG 0x0305
wM_RENDERALLFORMATS             = WMSG 0x0306
wM_DESTROYCLIPBOARD             = WMSG 0x0307
wM_DRAWCLIPBOARD                = WMSG 0x0308
wM_PAINTCLIPBOARD               = WMSG 0x0309
wM_VSCROLLCLIPBOARD             = WMSG 0x030A
wM_SIZECLIPBOARD                = WMSG 0x030B
wM_ASKCBFORMATNAME              = WMSG 0x030C
wM_CHANGECBCHAIN                = WMSG 0x030D
wM_HSCROLLCLIPBOARD             = WMSG 0x030E
wM_QUERYNEWPALETTE              = WMSG 0x030F
wM_PALETTEISCHANGING            = WMSG 0x0310
wM_PALETTECHANGED               = WMSG 0x0311
wM_HOTKEY                       = WMSG 0x0312

wM_PRINT                        = WMSG 0x0317
wM_PRINTCLIENT                  = WMSG 0x0318

wM_APPCOMMAND                   = WMSG 0x0319

wM_THEMECHANGED                 = WMSG 0x031A

wM_HANDHELDFIRST                = WMSG 0x0358
wM_HANDHELDLAST                 = WMSG 0x035F

wM_AFXFIRST                     = WMSG 0x0360
wM_AFXLAST                      = WMSG 0x037F

wM_PENWINFIRST                  = WMSG 0x0380
wM_PENWINLAST                   = WMSG 0x038F

wM_APP n                        = WMSG (0x8000 + n)

-- Window data

gWL_WNDPROC    = GWL  (-4)
gWL_HINSTANCE  = GWL  (-6)
gWL_HWNDPARENT = GWL  (-8)
gWL_ID         = GWL (-12)
gWL_STYLE      = GWL (-16)
gWL_EXSTYLE    = GWL (-20)
gWL_USERDATA   = GWL (-21)

sWP_NOSIZE          = SWP 0x0001
sWP_NOMOVE          = SWP 0x0002
sWP_NOZORDER        = SWP 0x0004
sWP_NOREDRAW        = SWP 0x0008
sWP_NOACTIVATE      = SWP 0x0010
sWP_FRAMECHANGED    = SWP 0x0020  -- The frame changed: send wM_NCCALCSIZE
sWP_SHOWWINDOW      = SWP 0x0040
sWP_HIDEWINDOW      = SWP 0x0080
sWP_NOCOPYBITS      = SWP 0x0100
sWP_NOOWNERZORDER   = SWP 0x0200  -- Don't do owner Z ordering
sWP_NOSENDCHANGING  = SWP 0x0400  -- Don't send wM_WINDOWPOSCHANGING

sWP_DRAWFRAME       = sWP_FRAMECHANGED
sWP_NOREPOSITION    = sWP_NOOWNERZORDER

sWP_DEFERERASE      = SWP 0x2000
sWP_ASYNCWINDOWPOS  = SWP 0x4000

sW_HIDE             = SW  0
sW_SHOWNORMAL       = SW  1
sW_NORMAL           = SW  1
sW_SHOWMINIMIZED    = SW  2
sW_SHOWMAXIMIZED    = SW  3
sW_MAXIMIZE         = SW  3
sW_SHOWNOACTIVATE   = SW  4
sW_SHOW             = SW  5
sW_MINIMIZE         = SW  6
sW_SHOWMINNOACTIVE  = SW  7
sW_SHOWNA           = SW  8
sW_RESTORE          = SW  9
sW_SHOWDEFAULT      = SW 10
sW_FORCEMINIMIZE    = SW 11
sW_MAX              = SW 11



