module Win32.Window.Message where

import Win32.Window.Types
import Win32.Window.Constants

import Win32.GDI.Types

import Win32.System.Types

import JCAB.IO
import Control.Monad
import Foreign.Storable




peekMessage      :: PMSG -> HWND -> UINT -> UINT -> UINT -> IO BOOL
getMessage       :: PMSG -> HWND -> UINT -> UINT ->         IO BOOL
translateMessage :: PMSG ->                                 IO BOOL
dispatchMessage  :: PMSG ->                                 IO LRESULT
isDialogMessage  :: HWND -> PMSG ->                         IO BOOL

messagePumpLoop     :: IO ()
messagePumpLoopDlg  :: HWND -> IO ()
messagePumpLoopIdle :: IO () -> IO ()

defWindowProc   :: WNDPROC
postQuitMessage :: DWORD -> IO ()

withPaint :: HWND -> (HDC -> PAINTSTRUCT -> IO a) -> IO a



peekMessage msg hwnd filterMin filterMax removeMsg =
    c_PeekMessage msg hwnd filterMin filterMax removeMsg

getMessage msg hwnd filterMin filterMax =
    c_GetMessage msg hwnd filterMin filterMax

translateMessage msg = c_TranslateMessage msg

dispatchMessage msg = c_DispatchMessage msg

isDialogMessage = c_IsDialogMessage

messagePumpLoop = withPMSG loop1
    where

    loop1 msg = do
        getResult <- getMessage msg nullHWND 0 0
        when getResult $ do
            translateMessage msg
            dispatchMessage msg
            loop1 msg

messagePumpLoopDlg mainHWND = withPMSG loop1
    where

    loop1 msg = do
        getResult <- getMessage msg nullHWND 0 0
        when getResult $ do
            isDlg <- isDialogMessage mainHWND msg
            when_ (not isDlg) $ do
                translateMessage msg
                dispatchMessage msg
            loop1 msg

messagePumpLoopIdle idle = withPMSG loop1
    where

    loop1 msg = do
        peekResult <- peekMessage msg nullHWND 0 0 0
        if not peekResult then do
                idle
                loop1 msg
            else do
                result <- getMessage msg nullHWND 0 0
                when result $ do
                    translateMessage msg
                    dispatchMessage msg
                    loop1 msg

defWindowProc   = c_DefWindowProc
postQuitMessage = c_PostQuitMessage

withPaint hwnd action = withPAINTSTRUCT $ \ps_ -> do
    dc <- c_BeginPaint hwnd ps_
    ps <- peek ps_
    result <- action dc ps
    c_EndPaint hwnd ps_
    return result




foreign import stdcall "Windows.h PeekMessageW"         c_PeekMessage         :: PMSG -> HWND -> UINT -> UINT -> UINT -> IO BOOL
foreign import stdcall "Windows.h GetMessageW"          c_GetMessage          :: PMSG -> HWND -> UINT -> UINT -> IO BOOL
foreign import stdcall "Windows.h TranslateMessage"     c_TranslateMessage    :: PMSG -> IO BOOL
foreign import stdcall "Windows.h DispatchMessageW"     c_DispatchMessage     :: PMSG -> IO LRESULT
foreign import stdcall "Windows.h IsDialogMessage"      c_IsDialogMessage     :: HWND -> PMSG -> IO BOOL
foreign import stdcall "Windows.h DefWindowProcW"       c_DefWindowProc       :: WNDPROC
foreign import stdcall "Windows.h PostQuitMessage"      c_PostQuitMessage     :: DWORD -> IO ()
foreign import stdcall "Windows.h BeginPaint"           c_BeginPaint          :: HWND -> PPAINTSTRUCT -> IO HDC
foreign import stdcall "Windows.h EndPaint"             c_EndPaint            :: HWND -> PPAINTSTRUCT -> IO BOOL





