module Win32.Window.Types where

import Win32.GDI.Types

import Win32.System.Types

import Data.Bits
import Data.Typeable
import Foreign.Marshal.Alloc
import Foreign.Ptr
import Foreign.Storable




-- Enumeration types

newtype CHILDID       = CHILDID       UINT      deriving (Eq, Ord, Show, Enum, Num, Real, Integral, Bits, Storable, Typeable)
newtype WMSG          = WMSG          UINT      deriving (Eq, Ord, Show, Enum, Num, Real, Integral, Bits, Storable, Typeable)
newtype WSTYLE        = WSTYLE        ULONGLONG deriving (Eq, Ord, Show, Enum, Num, Real, Integral, Bits, Storable, Typeable)
newtype CSTYLE        = CSTYLE        ULONG     deriving (Eq, Ord, Show, Enum, Num, Real, Integral, Bits, Storable, Typeable)
newtype GWL           = GWL           INT       deriving (Eq, Ord, Show, Enum, Num, Real, Integral, Bits, Storable, Typeable)
newtype SWP           = SWP           UINT      deriving (Eq, Ord, Show, Enum, Num, Real, Integral, Bits, Storable, Typeable)
newtype SW            = SW            INT       deriving (Eq, Ord, Show, Enum, Num, Real, Integral, Bits, Storable, Typeable)
newtype WNOTIFICATION = WNOTIFICATION UINT      deriving (Eq, Ord, Show, Enum, Num, Real, Integral, Bits, Storable, Typeable)
newtype WPARAM        = WPARAM        UINT      deriving (Eq, Ord, Show, Enum, Num, Real, Integral, Bits, Storable, Typeable)
newtype LPARAM        = LPARAM        LONG      deriving (Eq, Ord, Show, Enum, Num, Real, Integral, Bits, Storable, Typeable)

unCHILDID       (CHILDID       v) = v
unWMSG          (WMSG          v) = v
unWSTYLE        (WSTYLE        v) = v
unCSTYLE        (CSTYLE        v) = v
unGWL           (GWL           v) = v
unSWP           (SWP           v) = v
unSW            (SW            v) = v
unWNOTIFICATION (WNOTIFICATION v) = v
unWPARAM        (WPARAM        v) = v
unLPARAM        (LPARAM        v) = v

type PWPARAM    = Ptr WPARAM
type PLPARAM    = Ptr LPARAM

-- Object handles

newtype HWND      = HWND      PVOID deriving (Eq, Show, Storable)

castToHWND      l = HWND      (castToPtr l)

castFromHWND      (HWND      p) = castFromPtr p

nullHWND      = HWND      nullPtr

hwndTOP       = castToHWND   0
hwndBOTTOM    = castToHWND   1
hwndTOPMOST   = castToHWND (-1)
hwndNOTOPMOST = castToHWND (-2)

-- Window class

data WndClass = WndClassName String HINSTANCE
              | WndClassRegistered ATOM HINSTANCE (IO ())

-- Window proc

type WNDPROC = HWND -> WMSG -> WPARAM -> LPARAM -> IO LRESULT

type PWNDPROC = FunPtr WNDPROC

foreign import stdcall "wrapper" mkWNDPROC  :: WNDPROC -> IO PWNDPROC
foreign import stdcall "dynamic" getWNDPROC :: PWNDPROC -> WNDPROC

-- Window message enumerations

newtype WindowActivation = WindowActivation WPARAM deriving (Eq, Ord, Show, Num, Storable)
newtype CommandID = CommandID WORD deriving (Eq, Ord, Show, Enum, Num, Real, Integral, Bits, Storable)

unWindowActivation (WindowActivation v) = v
unCommandID        (CommandID        v) = v

-- Window notifications

data NMHDR; type PNMHDR = Ptr NMHDR

instance Storable NMHDR where { sizeOf m = 12; alignment m = 4; peek = undefined; poke = undefined }

pNMHDRhwndFrom = (undefined, undefined, 0) :: StructField NMHDR HWND
pNMHDRidFrom   = (undefined, undefined, 4) :: StructField NMHDR CHILDID
pNMHDRcode     = (undefined, undefined, 8) :: StructField NMHDR WNOTIFICATION

-- Messages

data MSG ; type PMSG = Ptr MSG

instance Storable MSG where { sizeOf m = 28; alignment m = 4; peek = undefined; poke = undefined }

pMSGhwnd    = (undefined, undefined,  0) :: StructField MSG HWND
pMSGmessage = (undefined, undefined,  4) :: StructField MSG WMSG
pMSGwParam  = (undefined, undefined,  8) :: StructField MSG WPARAM
pMSGlParam  = (undefined, undefined, 12) :: StructField MSG LPARAM
pMSGtime    = (undefined, undefined, 16) :: StructField MSG DWORD
pMSGpt      = (undefined, undefined, 20) :: StructField MSG POINT

withPMSG = alloca :: (PMSG -> IO a) -> IO a
