{-
import Win32.Types
import Win32.Window
import Win32.System
import Win32.GDI
import Win32.COM
import Win32.Commctl
-}
import Win32

import Data.Bits
import Data.Char
import Data.IORef
import Control.Monad
import Debug.Trace
import Foreign
import System.IO




data MainWindowData = MainWindowData {
    thickPen    :: HPEN,
    thinPen     :: HPEN,
    colorBrush  :: COLORREF,
    childWindow :: HWND}

mainWindowProc :: IORef MainWindowData -> WNDPROC

mainWindowProc wdataRef hwnd msg wParam lParam
    | msg == wM_PAINT = do
        withPaint hwnd $ \dc ps -> do
            rect <- getClientRect hwnd
{-
            when (getRECTSize rect /= SIZE 0 0) $ do
                wdata <- readIORef wdataRef
                oldPen <- selectPen dc $ thickPen wdata
                selectBrush dc hBRUSH_DC
                setDCBrushColor dc $ colorBrush wdata
                ellipse dc rect
                selectPen dc oldPen
                selectFont dc hFONT_DEFAULT_GUI
                textOut dc (POINT 0 0) "Hello World"
                return ()
-}
            return 0
        return 0

    | msg == wM_CLOSE = do
        postQuitMessage 0
        return 1

    | msg == wM_SETTEXT = do
        oldtext <- getWindowText hwnd
        text <- peekPSTR $ nullPtr `plusPtr` (fromIntegral lParam)
        putStrLn $ "WM_SETTEXT '" ++ text ++ "' was: '" ++ oldtext ++ "'"
        defWindowProc hwnd msg wParam lParam

    | msg == wM_CREATE = do
        wdata <- readIORef wdataRef
        rect <- getClientRect hwnd
        lvHwnd <- createChildWindow
            wC_LISTVIEW
            "Button"
            (wS_TABSTOP .|. wS_VISIBLE .|. wS_CHILD .|. lVS_NOSORTHEADER .|. lVS_SINGLESEL .|. lVS_REPORT)
            rect
            hwnd
            1
        if lvHwnd == nullHWND then
                return (-1)
            else do
                listView_SetExtendedListViewStyleEx lvHwnd lVS_EX_FULLROWSELECT lVS_EX_FULLROWSELECT
                listView_SetInsertColumnWidthText lvHwnd 0 200 "Traditional"
                listView_SetInsertColumnWidthText lvHwnd 1 200 "Simplified"
                listView_SetInsertColumnWidthText lvHwnd 2 200 "PinYin"
                listView_SetInsertColumnWidthText lvHwnd 3 800 "English"
                writeIORef wdataRef $ wdata { childWindow = lvHwnd }
                defWindowProc hwnd msg wParam lParam

    | msg == wM_SIZE = do
        let w = fromIntegral (lParam .&. 0xFFFF)
        let h = fromIntegral ((lParam `shiftR` 16) .&. 0xFFFF)
        wdata <- readIORef wdataRef
        let childHwnd = childWindow wdata
        when (childHwnd /= nullHWND) $ do
            setWindowPos childHwnd nullHWND (RECT 0 0 w h) (sWP_NOZORDER .|. sWP_NOACTIVATE)
            return ()
        --invalidateRect hwnd (Just $ makeRECTxywh 0 0 w h) True
        --invalidateRect hwnd Nothing True
        defWindowProc hwnd msg wParam lParam

    | msg == wM_CHAR = do
        let ch = chr $ fromIntegral wParam
        case ch of
            '\r' -> do
                wdata <- readIORef wdataRef
                writeIORef wdataRef $ wdata {
                    thickPen = thinPen wdata,
                    thinPen = thickPen wdata}
                invalidateRect hwnd Nothing True
                defWindowProc hwnd msg wParam lParam
            _ | ord ch == 27 -> do
                postMessage hwnd wM_CLOSE 0 0
                return 1
            otherwise -> defWindowProc hwnd msg wParam lParam

    | otherwise =
        defWindowProc hwnd msg wParam lParam

main =
    withCoInitialize cOINIT_APARTMENTTHREADED $ do
        initCommonControls iCC_WIN95_CLASSES
        messageBox nullHWND "Text" "Caption" (mB_OK .|. mB_ICONASTERISK)
        hInst <- getModuleHandle ""
        thickPen    <- createPen pS_SOLID 8 $ rgb 255 0 128
        thinPen     <- createPen pS_SOLID 1 $ rgb 255 0 128
        arrowCursor <- loadSysCursor iDC_ARROW
        wdata <- newIORef MainWindowData {
            thickPen    = thickPen,
            thinPen     = thinPen,
            colorBrush  = rgb 255 128 0,
            childWindow = nullHWND}
        withCreateUniqueWindow
                "MainWindow" cS_DEFAULT
                "Window"
                (mainWindowProc wdata)
                (wS_VISIBLE .|. wS_OVERLAPPEDWINDOW)
                rectDefault
                nullHWND
                nullHMENU
                nullHICON
                nullHICON
                arrowCursor
                hBRUSH_WINDOW
                hInst
            $ \hwnd -> messagePumpLoop
